(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    721110,      13570]
NotebookOptionsPosition[    716479,      13421]
NotebookOutlinePosition[    716854,      13437]
CellTagsIndexPosition[    716811,      13434]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Amazon Full Comment Analysis for Unusual Words (Misspellings, \
etc.)", "Title"],
 "\n\nNOTE: Please evaluate line by line. That is, do not evaluate the whole \
notebook all at once."
}], "Text",
 CellChangeTimes->{{3.653660903250986*^9, 3.6536609256435947`*^9}, {
   3.6540700963126583`*^9, 3.654070146810991*^9}, {3.654127197645582*^9, 
   3.6541272225826845`*^9}, {3.6543323934682837`*^9, 
   3.6543323945695105`*^9}, {3.6544185378661137`*^9, 
   3.6544185487463565`*^9}, {3.6544549703653307`*^9, 3.654454983267989*^9}, {
   3.6544595827417793`*^9, 3.6544595900042777`*^9}, {3.6546472877966003`*^9, 
   3.6546472987748613`*^9}, {3.654653205076269*^9, 3.654653331689361*^9}, {
   3.6546562137332497`*^9, 3.654656250242781*^9}, 3.654684904809736*^9, {
   3.654695880617466*^9, 3.6546961000526834`*^9}, {3.654696627213313*^9, 
   3.654696689969246*^9}, {3.6547647521279526`*^9, 3.6547647841815577`*^9}, 
   3.6548626031996317`*^9}],

Cell[TextData[StyleBox["Import data", "Chapter"]], "Text",
 CellChangeTimes->{{3.65407016127495*^9, 3.6540701671951613`*^9}}],

Cell[BoxData[
 RowBox[{"ExtractArchive", "[", "\"\<aggressive_dedup.json.gz\>\"", 
  "]"}]], "Input",
 CellChangeTimes->{{3.6543731603210773`*^9, 3.6543731620014234`*^9}, 
   3.654651793902708*^9}],

Cell[CellGroupData[{

Cell["Clean/Parse Data", "Chapter",
 CellChangeTimes->{{3.6540702434427633`*^9, 3.654070258010743*^9}, {
  3.6543574924677515`*^9, 3.6543574939130473`*^9}}],

Cell["\<\
There will be error messages from this section. It is ok and expected.\
\>", "Text",
 CellChangeTimes->{{3.6547648416964097`*^9, 3.654764866416503*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"UnixTime", "[", 
   RowBox[{"{", 
    RowBox[{"2009", ",", "1", ",", "1"}], "}"}], "]"}], " ", 
  RowBox[{"(*", 
   RowBox[{
   "Only", " ", "look", " ", "at", " ", "reviews", " ", "from", " ", "2009", 
    " ", "on"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.6543328746377325`*^9, 3.6543328953849773`*^9}, {
  3.654377525294546*^9, 3.654377542695133*^9}}],

Cell[BoxData[
 RowBox[{"reviews", "=", 
  RowBox[{"OpenRead", "[", "\"\<aggressive_dedup.json\>\"", "]"}]}]], "Input",
 CellChangeTimes->{3.654378695363656*^9}],

Cell[BoxData[
 RowBox[{"data", "=", 
  RowBox[{"OpenWrite", "[", "\"\<fulldata\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.654378555980934*^9, 3.6543785739766426`*^9}, {
  3.6543793602314663`*^9, 3.6543793730291033`*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"line", "=", 
     RowBox[{"Read", "[", 
      RowBox[{"reviews", ",", 
       RowBox[{"{", "String", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"i", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"While", "[", 
    RowBox[{
     RowBox[{"StringQ", "[", 
      RowBox[{"line", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"split", "=", 
       RowBox[{"StringSplit", "[", 
        RowBox[{"line", ",", "\"\<\\\": \>\"", ",", "10"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"t", "=", 
       RowBox[{
        RowBox[{"split", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "[", 
        RowBox[{"[", "6", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"text", "=", 
       RowBox[{
        RowBox[{"StringSplit", "[", 
         RowBox[{"t", ",", "\"\<\\\", \\\"\>\"", ",", "2"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"u", "=", 
       RowBox[{
        RowBox[{"split", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "[", 
        RowBox[{"[", "9", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"utc", "=", 
       RowBox[{"ToExpression", "[", 
        RowBox[{
         RowBox[{"StringSplit", "[", 
          RowBox[{"u", ",", "\"\<, \\\"\>\"", ",", "2"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", " ", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"IntegerQ", "[", "utc", "]"}], "&&", 
         RowBox[{"utc", ">=", "1230768000"}]}], ",", 
        RowBox[{"Write", "[", 
         RowBox[{"data", ",", 
          RowBox[{"{", 
           RowBox[{"utc", ",", "text"}], "}"}]}], "]"}]}], "]"}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"line", "=", 
       RowBox[{"Read", "[", 
        RowBox[{"reviews", ",", 
         RowBox[{"{", "String", "}"}]}], "]"}]}], " ", ";", 
      "\[IndentingNewLine]", 
      RowBox[{"i", "=", 
       RowBox[{"i", "+", "1"}]}], ";"}]}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.6541845456298585`*^9, 3.654184550877932*^9}, {
   3.654184626623554*^9, 3.654184730033712*^9}, {3.6541848111664686`*^9, 
   3.65418482232075*^9}, {3.65418491875748*^9, 3.6541849333954773`*^9}, 
   3.654185652378598*^9, {3.6543325978020916`*^9, 3.654332720309157*^9}, {
   3.654332807667031*^9, 3.6543328406027694`*^9}, {3.6543329109301586`*^9, 
   3.6543329185247126`*^9}, {3.654357627279334*^9, 3.6543576408641148`*^9}, 
   3.6543577179678893`*^9, {3.6543749386815357`*^9, 3.6543749587666764`*^9}, {
   3.6543750602065773`*^9, 3.6543750699165792`*^9}, {3.6543751034744935`*^9, 
   3.654375145996256*^9}, {3.6543754024140944`*^9, 3.6543755954898806`*^9}, {
   3.65437568540641*^9, 3.6543756943772573`*^9}, {3.654375824288029*^9, 
   3.6543758372917075`*^9}, {3.654375933262485*^9, 3.654375938526569*^9}, {
   3.654375993113818*^9, 3.65437599414003*^9}, {3.6543786061862803`*^9, 
   3.6543786476518245`*^9}, {3.6543789503169956`*^9, 3.654378972403546*^9}, 
   3.6543793092879667`*^9, 3.6543794743729877`*^9, {3.6543823772441645`*^9, 
   3.654382387552289*^9}, {3.654392209850321*^9, 3.6543922112216034`*^9}, {
   3.6543926618149652`*^9, 3.654392662928194*^9}, {3.6550199021087065`*^9, 
   3.655019913467047*^9}}],

Cell[BoxData[
 RowBox[{"Close", "[", "data", "]"}]], "Input",
 CellChangeTimes->{{3.654378682498005*^9, 3.6543786916668944`*^9}, 
   3.6543787505910378`*^9, {3.6543794090595255`*^9, 3.654379411859105*^9}, {
   3.6543811869098783`*^9, 3.6543811875750146`*^9}}],

Cell[BoxData[
 RowBox[{"Close", "[", "reviews", "]"}]], "Input",
 CellChangeTimes->{{3.654379054377438*^9, 3.6543790599125786`*^9}}],

Cell[BoxData[
 RowBox[{"Streams", "[", "]"}]], "Input",
 NumberMarks->False],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.6541075610104527`*^9, 3.654107575969514*^9}, 
   3.654138567631236*^9, 3.654377363543214*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Scrub & Evaluate Data", "Chapter",
 CellChangeTimes->{{3.6543785102155046`*^9, 3.6543785102275057`*^9}, {
  3.6544094165295258`*^9, 3.6544094220976725`*^9}, {3.6544531592171173`*^9, 
  3.6544531649913073`*^9}}],

Cell[BoxData[
 RowBox[{"fulldata", "=", 
  RowBox[{"OpenRead", "[", "\"\<fulldata\>\"", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Streams", "[", "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ClearAll", "[", 
   RowBox[{"i", ",", "j", ",", "misspell", ",", "date"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"line", "=", 
   RowBox[{"Read", "[", "fulldata", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"j", "=", "1"}], ";", " ", 
  RowBox[{"i", "=", "1"}], ";", " ", 
  RowBox[{"date", "=", 
   RowBox[{"{", "}"}]}], ";", 
  RowBox[{"text", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"df2", "=", 
    RowBox[{"Reap", "[", 
     RowBox[{
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{"IntegerQ", "[", 
         RowBox[{"line", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"textwords", "=", 
          RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"stringslist", "=", 
          RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"misspell", "=", "0"}], ";", "\[IndentingNewLine]", 
         RowBox[{"text", "=", 
          RowBox[{"line", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"(*", 
          RowBox[{"CHECK", " ", "FOR", " ", "ENGLISH"}], "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{"If", " ", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"RandomInteger", "[", 
              RowBox[{"{", 
               RowBox[{"1", ",", "100"}], "}"}], "]"}], "\[Equal]", "1"}], "&&", 
            RowBox[{
             RowBox[{"LanguageIdentify", "[", "text", "]"}], "==", 
             RowBox[{"Entity", "[", 
              RowBox[{"\"\<Language\>\"", ",", "\"\<English\>\""}], "]"}]}]}],
            ",", " ", 
           RowBox[{"(*", 
            RowBox[{
             RowBox[{"only", " ", "takes", " ", 
              RowBox[{"1", "/", "100"}]}], " ", "=", " ", 
             RowBox[{
             "1", "%", " ", "of", " ", "entries", " ", "and", " ", "checks", 
              " ", "for", " ", "English"}]}], "*)"}], "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"text", "=", 
             RowBox[{"StringReplace", "[", 
              RowBox[{"text", ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"\"\<1\>\"", "\[Rule]", "\"\<\>\""}], ",", 
                 RowBox[{"\"\<2\>\"", "\[Rule]", "\"\<\>\""}], ",", 
                 RowBox[{"\"\<3\>\"", "\[Rule]", "\"\<\>\""}], ",", 
                 RowBox[{"\"\<4\>\"", "\[Rule]", "\"\<\>\""}], ",", 
                 RowBox[{"\"\<5\>\"", "\[Rule]", "\"\<\>\""}], ",", 
                 RowBox[{"\"\<6\>\"", "\[Rule]", "\"\<\>\""}], ",", 
                 RowBox[{"\"\<7\>\"", "\[Rule]", "\"\<\>\""}], ",", 
                 RowBox[{"\"\<8\>\"", "\[Rule]", "\"\<\>\""}], ",", 
                 RowBox[{"\"\<9\>\"", "\[Rule]", "\"\<\>\""}], ",", 
                 RowBox[{"\"\<0\>\"", "\[Rule]", "\"\<\>\""}], ",", 
                 RowBox[{"\"\<$\>\"", "\[Rule]", "\"\<\>\""}], ",", 
                 RowBox[{"\"\<*\>\"", "\[Rule]", "\"\< \>\""}], ",", 
                 RowBox[{"\"\<-\>\"", "\[Rule]", "\"\< \>\""}], ",", 
                 RowBox[{"\"\<+\>\"", "\[Rule]", "\"\< \>\""}]}], "}"}]}], 
              "]"}]}], ";", " ", 
            RowBox[{"(*", 
             RowBox[{"Remove", " ", "numbers", " ", "etc"}], "*)"}], 
            "\[IndentingNewLine]", 
            RowBox[{"text", "=", 
             RowBox[{"StringReplace", "[", 
              RowBox[{"text", ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"\"\<'d\>\"", "\[Rule]", "\"\<\>\""}], ",", 
                 RowBox[{"\"\<'s\>\"", "\[Rule]", "\"\<\>\""}], ",", 
                 RowBox[{"\"\<&quot;\>\"", "\[Rule]", "\"\<\>\""}], ",", 
                 RowBox[{"\"\<&apos;d\>\"", "\[Rule]", "\"\<\>\""}], ",", 
                 RowBox[{"\"\<&apos;s\>\"", "\[Rule]", "\"\<\>\""}], ",", 
                 RowBox[{"\"\<n&apos;t\>\"", "\[Rule]", "\"\<n't\>\""}]}], 
                "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"text", "=", 
             RowBox[{"StringReplace", "[", 
              RowBox[{"text", ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"\"\<&gt;\>\"", "\[Rule]", "\"\< \>\""}], ",", 
                 RowBox[{"\"\<&apos;\>\"", "\[Rule]", "\"\<\>\""}], ",", 
                 RowBox[{"\"\</\>\"", "\[Rule]", "\"\< \>\""}], ",", 
                 RowBox[{"\"\<\\\\t\>\"", "\[Rule]", "\"\< \>\""}], ",", 
                 RowBox[{"\"\<\\\\\>\"", "\[Rule]", "\"\< \>\""}]}], "}"}]}], 
              "]"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"text", "=", 
             RowBox[{"StringReplace", "[", 
              RowBox[{"text", ",", 
               RowBox[{"\"\<\\\\\>\"", "\[Rule]", "\"\< \>\""}]}], 
              RowBox[{"(*", 
               RowBox[{",", 
                RowBox[{"\"\<.\>\"", "\[Rule]", "\"\< \>\""}]}], "*)"}], 
              "]"}]}], ";", 
            RowBox[{"(*", 
             RowBox[{
              RowBox[{"Remove", " ", "paragraph", " ", "breaks"}], ",", " ", 
              "contractions", ",", " ", 
              RowBox[{"etc", "."}]}], "*)"}], "\[IndentingNewLine]", 
            RowBox[{"textwords", "=", 
             RowBox[{"TextWords", "[", "text", "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"For", " ", "[", 
             RowBox[{
              RowBox[{"j", "=", "1"}], ",", 
              RowBox[{"j", "<=", 
               RowBox[{"Length", "[", "textwords", "]"}]}], ",", 
              RowBox[{"j", "++"}], ",", " ", 
              RowBox[{"(*", 
               RowBox[{
               "j", " ", "is", " ", "the", " ", "particular", " ", "word", 
                " ", "number"}], "*)"}], "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"wordstring", "=", 
                RowBox[{"textwords", "[", 
                 RowBox[{"[", "j", "]"}], "]"}]}], ";", 
               RowBox[{"(*", 
                RowBox[{
                "discounts", " ", "words", " ", "3", " ", "characters", " ", 
                 "or", " ", "less", " ", "to", " ", "avoid", " ", "Roman", 
                 " ", "numerals", " ", "and", " ", "common", " ", "words", 
                 " ", "like", " ", "ok"}], "*)"}], "\[IndentingNewLine]", 
               RowBox[{"characters", "=", 
                RowBox[{"Characters", "[", "wordstring", "]"}]}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"If", " ", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"Length", "[", "characters", "]"}], ">", "3"}], "&&", 
                  RowBox[{"Not", "[", 
                   RowBox[{"SubsetQ", "[", 
                    RowBox[{"characters", ",", 
                    RowBox[{"{", "\"\<#\>\"", "}"}]}], "]"}], "]"}], "&&", 
                  RowBox[{"Not", "[", 
                   RowBox[{"SubsetQ", "[", 
                    RowBox[{"characters", ",", 
                    RowBox[{"{", "\"\<&\>\"", "}"}]}], "]"}], "]"}], "&&", 
                  RowBox[{"Not", "[", 
                   RowBox[{"SubsetQ", "[", 
                    RowBox[{"characters", ",", 
                    RowBox[{"{", "\"\<.\>\"", "}"}]}], "]"}], "]"}], "&&", 
                  RowBox[{"Not", "[", 
                   RowBox[{"SubsetQ", "[", 
                    RowBox[{"characters", ",", 
                    RowBox[{"{", "\"\<;\>\"", "}"}]}], "]"}], "]"}], "&&", 
                  RowBox[{"Not", "[", 
                   RowBox[{"SubsetQ", "[", 
                    RowBox[{"characters", ",", 
                    RowBox[{"{", "\"\<:\>\"", "}"}]}], "]"}], "]"}], "&&", 
                  RowBox[{"Not", "[", 
                   RowBox[{"wordstring", "==", "\"\<awol\>\""}], "]"}], "&&", 
                  RowBox[{"Not", "[", 
                   RowBox[{"wordstring", "==", "\"\<AWOL\>\""}], "]"}], "&&", 
                  RowBox[{"Not", "[", 
                   RowBox[{"wordstring", "==", "\"\<dvds\>\""}], "]"}], "&&", 
                  RowBox[{"Not", "[", 
                   RowBox[{"wordstring", "==", "\"\<DVDs\>\""}], "]"}], "&&", 
                  RowBox[{"Not", "[", 
                   RowBox[{"wordstring", "==", "\"\<iPhone\>\""}], "]"}], "&&", 
                  RowBox[{"Not", "[", 
                   RowBox[{"wordstring", "==", "\"\<iPhones\>\""}], "]"}], "&&", 
                  RowBox[{"Not", "[", 
                   RowBox[{"wordstring", "==", "\"\<iphones\>\""}], "]"}], "&&", 
                  RowBox[{"Not", "[", 
                   RowBox[{"wordstring", "==", "\"\<iPad\>\""}], "]"}], "&&", 
                  RowBox[{"Not", "[", 
                   RowBox[{"wordstring", "==", "\"\<iPads\>\""}], "]"}], "&&", 
                  RowBox[{"Not", "[", 
                   RowBox[{"wordstring", "==", "\"\<iphone\>\""}], "]"}], "&&", 
                  RowBox[{"Not", "[", 
                   RowBox[{"wordstring", "==", "\"\<ipad\>\""}], "]"}], "&&", 
                  RowBox[{"Not", "[", 
                   RowBox[{"wordstring", "==", "\"\<ipads\>\""}], "]"}], "&&", 
                  RowBox[{"Not", "[", 
                   RowBox[{"wordstring", "==", "\"\<apps\>\""}], "]"}], "&&", 
                  RowBox[{"Not", "[", 
                   RowBox[{"wordstring", "==", "\"\<Apps\>\""}], "]"}]}], ",", 
                 RowBox[{"(*", 
                  RowBox[{
                  "checks", " ", "for", " ", "links", " ", "and", " ", "some",
                    " ", "slang", " ", "and", " ", "strange", " ", "accent", 
                   " ", "type", " ", "characters", " ", "and", " ", "most", 
                   " ", "emojis"}], "*)"}], "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"If", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"DictionaryLookup", "[", 
                    RowBox[{"wordstring", ",", 
                    RowBox[{"IgnoreCase", "\[Rule]", "True"}]}], "]"}], "==", 
                    RowBox[{"{", "}"}]}], ",", "\[IndentingNewLine]", 
                    RowBox[{"misspell", "=", 
                    RowBox[{"misspell", "+", "1"}]}]}], "]"}], ";"}]}], "]"}],
                ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}], 
          "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"date", "=", 
          RowBox[{"DateValue", "[", 
           RowBox[{
            RowBox[{"FromUnixTime", "[", 
             RowBox[{
              RowBox[{"line", "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", 
              RowBox[{"TimeZone", "\[Rule]", "0"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "\"\<Year\>\"", ",", "\"\<Month\>\"", ",", "\"\<Day\>\""}], 
             "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{"time", "=", 
            RowBox[{"FromUnixTime", "[", 
             RowBox[{"ToExpression", "[", 
              RowBox[{"StringDrop", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"StringSplit", "[", 
                  RowBox[{
                   RowBox[{"line", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", "\"\<,\>\"", ",", 
                   "2"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}], ",", "1"}], "]"}], "]"}], 
             "]"}]}], ";"}], "*)"}], "\[IndentingNewLine]", 
         RowBox[{"If", " ", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", "textwords", "]"}], "\[NotEqual]", "0"}], 
           ",", 
           RowBox[{"Sow", "[", 
            RowBox[{"{", 
             RowBox[{"date", ",", 
              RowBox[{"N", "[", 
               RowBox[{"misspell", "/", 
                RowBox[{"Length", "[", "textwords", "]"}]}], "]"}]}], "}"}], 
            "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"line", "=", 
          RowBox[{"Read", "[", "fulldata", "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"i", "=", 
          RowBox[{"i", "+", "1"}]}], ";"}]}], "\[IndentingNewLine]", "]"}], 
      ";"}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.6541860609101853`*^9, 3.6541860667323756`*^9}, {
   3.6541861113134966`*^9, 3.654186116718602*^9}, {3.654186159489352*^9, 
   3.6541861693873787`*^9}, {3.6541862519472713`*^9, 
   3.6541862852450843`*^9}, {3.65418631978015*^9, 3.65418632583739*^9}, 
   3.65418658129858*^9, {3.654186781427526*^9, 3.6541867979239016`*^9}, {
   3.654188686012887*^9, 3.6541887551200266`*^9}, {3.6541905539332747`*^9, 
   3.6541905582121487`*^9}, {3.654191173066975*^9, 3.6541911775738983`*^9}, {
   3.6542545497177753`*^9, 3.6542546257203264`*^9}, {3.6542546637741117`*^9, 
   3.6542546647933207`*^9}, {3.6542557970659523`*^9, 
   3.6542558385934486`*^9}, {3.6543329475726557`*^9, 
   3.6543329620606203`*^9}, {3.6543339003156624`*^9, 3.654333910624772*^9}, {
   3.6543339844488773`*^9, 3.6543340325829525`*^9}, {3.6543340691764393`*^9, 
   3.654334169463958*^9}, {3.6543342159414682`*^9, 3.654334222883889*^9}, {
   3.6543616719276657`*^9, 3.6543616932610307`*^9}, {3.654379705233557*^9, 
   3.6543797190824103`*^9}, {3.654380113204626*^9, 3.6543801198289895`*^9}, {
   3.654380959544026*^9, 3.654380972086611*^9}, {3.6543810151634874`*^9, 
   3.6543810170578775`*^9}, {3.654381064730702*^9, 3.6543810704978895`*^9}, {
   3.654381109112847*^9, 3.654381125273177*^9}, {3.654381281278325*^9, 
   3.6543813930133495`*^9}, {3.6543816894034243`*^9, 3.654381836091652*^9}, {
   3.654381888189387*^9, 3.654381932087434*^9}, {3.6543822441617403`*^9, 
   3.654382245463009*^9}, {3.6543828466108837`*^9, 3.654382865030681*^9}, {
   3.6543830405768538`*^9, 3.654383079434863*^9}, 3.6543831488551664`*^9, {
   3.654383565134947*^9, 3.654383565819089*^9}, {3.654391513150755*^9, 
   3.6543915143570037`*^9}, {3.6543915885122857`*^9, 
   3.6543915905447035`*^9}, {3.6543916442917786`*^9, 
   3.6543916455990486`*^9}, {3.6543917380651026`*^9, 3.654391741766868*^9}, {
   3.6543918221774354`*^9, 3.654391822425486*^9}, {3.654391860375307*^9, 
   3.6543918982131033`*^9}, {3.654392866732191*^9, 3.6543928683945336`*^9}, {
   3.6543930101147366`*^9, 3.6543930775986433`*^9}, 3.654393606915719*^9, 
   3.654407411970456*^9, {3.654407494236408*^9, 3.65440749943748*^9}, {
   3.6544077754363537`*^9, 3.654407785865503*^9}, {3.654408033101449*^9, 
   3.65440803732732*^9}, {3.6544086500395794`*^9, 3.654408670016696*^9}, 
   3.654409210177004*^9, {3.6544115858665514`*^9, 3.6544116454398265`*^9}, {
   3.6544116814612494`*^9, 3.654411684492874*^9}, 3.654411761581759*^9, {
   3.654412003758662*^9, 3.6544120602052937`*^9}, {3.654412094806425*^9, 
   3.654412095326532*^9}, {3.654412129328539*^9, 3.6544121586285763`*^9}, {
   3.6544168608955493`*^9, 3.654416875201497*^9}, {3.6544169229123287`*^9, 
   3.654416999192047*^9}, {3.6544424356213593`*^9, 3.6544424492081594`*^9}, {
   3.654442525509881*^9, 3.65444254797451*^9}, {3.654442583381807*^9, 
   3.654442658111206*^9}, {3.6544427166772757`*^9, 3.6544427229415665`*^9}, 
   3.6544427970748415`*^9, {3.6544428477702885`*^9, 3.654442880951126*^9}, {
   3.6544430418352795`*^9, 3.6544430420163155`*^9}, {3.654443402619623*^9, 
   3.6544434141439977`*^9}, {3.6544435655381947`*^9, 
   3.6544435657482395`*^9}, {3.6544438956712236`*^9, 3.654443939528261*^9}, {
   3.6544454309175873`*^9, 3.654445514568822*^9}, {3.6544455606683207`*^9, 
   3.6544455733159285`*^9}, {3.654455240477992*^9, 3.6544552760043125`*^9}, {
   3.6544557265301495`*^9, 3.654455820923602*^9}, 3.654457933756983*^9, {
   3.6544593519082146`*^9, 3.654459360259935*^9}, {3.6544652657168427`*^9, 
   3.654465273876524*^9}, 3.6544653562985086`*^9, {3.6544684342597694`*^9, 
   3.654468446953384*^9}, {3.6544686598812623`*^9, 3.654468701494836*^9}, {
   3.654523566255134*^9, 3.6545236688442726`*^9}, {3.6545237124601555`*^9, 
   3.6545237192315493`*^9}, {3.654523825920534*^9, 3.654523841754798*^9}, 
   3.6545239010060067`*^9, {3.654523942542567*^9, 3.6545239456802125`*^9}, {
   3.6545278629964347`*^9, 3.6545278736616325`*^9}, {3.6545279201212068`*^9, 
   3.6545279301622744`*^9}, {3.6546559138384523`*^9, 3.654655925837924*^9}, {
   3.654656929203684*^9, 3.6546570127969093`*^9}, {3.6546570504636707`*^9, 
   3.6546570528941703`*^9}, {3.6546570998388453`*^9, 
   3.6546571246999674`*^9}, {3.6546571564005003`*^9, 3.654657190251475*^9}, 
   3.654657230008667*^9, 3.6546572716502485`*^9, {3.6546573963799515`*^9, 
   3.654657428251519*^9}, {3.6546582515421696`*^9, 3.654658304110002*^9}, {
   3.654658792745693*^9, 3.6546588829302764`*^9}, {3.6548090339657636`*^9, 
   3.654809057074525*^9}, {3.654809502348281*^9, 3.6548095058279996`*^9}, {
   3.6548107210601873`*^9, 3.654810749171981*^9}, {3.6548107982190866`*^9, 
   3.6548108505748773`*^9}, 3.654862743597562*^9, 3.6549853612825327`*^9}],

Cell[CellGroupData[{

Cell["Wrap Up", "Subsection",
 CellChangeTimes->{{3.6544170350374346`*^9, 3.6544170377139845`*^9}}],

Cell[BoxData[
 RowBox[{"Close", "[", "fulldata", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Streams", "[", "]"}]], "Input",
 CellChangeTimes->{{3.6543834092328215`*^9, 3.654383411621313*^9}}],

Cell[BoxData[
 RowBox[{"Length", "[", "df2", "]"}]], "Input",
 CellChangeTimes->{{3.6544075429034367`*^9, 3.6544075534806156`*^9}, {
   3.654407614660223*^9, 3.654407615376371*^9}, 3.654413159829889*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"df3", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Drop", "[", 
      RowBox[{"df2", ",", "1"}], "]"}], ",", "2"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{3.654822083984688*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "df3", "]"}]], "Input",
 CellChangeTimes->{{3.654442256864523*^9, 3.6544422661774416`*^9}}],

Cell[BoxData["3469458"], "Output",
 CellChangeTimes->{3.6544422691800604`*^9, 3.654617636451497*^9, 
  3.6547714058570523`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<fulldf3_20C.dat\>\"", ",", "df3"}], "]"}]], "Input",
 CellChangeTimes->{{3.654383497573025*^9, 3.6543835014228177`*^9}, 
   3.654413156338169*^9, {3.6544186576187906`*^9, 3.6544186738541374`*^9}, {
   3.6544187381873927`*^9, 3.6544187460740175`*^9}, {3.654446391247474*^9, 
   3.6544463918946085`*^9}, {3.6546054246410675`*^9, 
   3.6546054251271667`*^9}, {3.6546818895343933`*^9, 3.6546818936902494`*^9}, 
   3.654809561671507*^9, 3.654985480746149*^9}],

Cell[BoxData[
 RowBox[{"Beep", "[", "]"}]], "Input",
 CellChangeTimes->{{3.6542120294428463`*^9, 3.654212040631135*^9}, 
   3.6543833460868087`*^9, 3.6544187550948772`*^9, {3.6544311817923393`*^9, 
   3.6544311852900586`*^9}}],

Cell[BoxData[
 RowBox[{"Clear", "[", "df2", "]"}]], "Input",
 CellChangeTimes->{{3.6544312151552124`*^9, 3.6544312198281755`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Can start here if evaluating IMPORTED data; otherwise, skip this section.\
\>", "Subchapter",
 CellChangeTimes->{{3.6543332447953176`*^9, 3.6543332629650345`*^9}, {
  3.6552503227148004`*^9, 3.655250348970159*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"df1", "=", 
  RowBox[{"Import", "[", 
   RowBox[{"\"\<fulldf3_20B.dat\>\"", ",", "\"\<Table\>\""}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.654605591593469*^9, 3.6546055949611635`*^9}, {
   3.65460564788307*^9, 3.654605650567622*^9}, {3.6546820283870063`*^9, 
   3.654682029365207*^9}, {3.654862972737781*^9, 3.6548629728998127`*^9}, 
   3.654985485980228*^9, {3.655192956410552*^9, 3.655192974592262*^9}}],

Cell[BoxData[
 InterpretationBox[
  TagBox[
   FrameBox[GridBox[{
      {
       ItemBox[
        TagBox[
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            
            RowBox[{"\<\"{2013,\"\>", ",", "\<\"4,\"\>", ",", "\<\"5}\"\>", 
             ",", "0.`"}], "}"}], ",", 
           RowBox[{"{", 
            
            RowBox[{"\<\"{2013,\"\>", ",", "\<\"4,\"\>", ",", "\<\"8}\"\>", 
             ",", "0.03076923076923077`"}], "}"}], ",", 
           RowBox[{"{", 
            
            RowBox[{"\<\"{2013,\"\>", ",", "\<\"3,\"\>", ",", "\<\"10}\"\>", 
             ",", "0.`"}], "}"}], ",", 
           RowBox[{"{", 
            
            RowBox[{"\<\"{2012,\"\>", ",", "\<\"11,\"\>", ",", "\<\"23}\"\>", 
             ",", "0.`"}], "}"}], ",", 
           RowBox[{"{", 
            
            RowBox[{"\<\"{2014,\"\>", ",", "\<\"2,\"\>", ",", "\<\"13}\"\>", 
             ",", "0.030303030303030304`"}], "}"}], ",", 
           RowBox[{"{", 
            
            RowBox[{"\<\"{2013,\"\>", ",", "\<\"8,\"\>", ",", "\<\"5}\"\>", 
             ",", "0.`"}], "}"}], ",", 
           RowBox[{"{", 
            
            RowBox[{"\<\"{2013,\"\>", ",", "\<\"7,\"\>", ",", "\<\"26}\"\>", 
             ",", "0.05`"}], "}"}], ",", 
           TemplateBox[{"3468969"},
            "OutputSizeLimit`Skeleton",
            DisplayFunction->(FrameBox[
              RowBox[{"\" \[CenterEllipsis]\"", #, "\"\[CenterEllipsis] \""}],
               Background -> GrayLevel[0.75], 
              BaseStyle -> {
               "Deploy", FontColor -> GrayLevel[1], FontSize -> Smaller, 
                ShowStringCharacters -> False}, BaselinePosition -> Baseline, 
              ContentPadding -> False, FrameMargins -> 1, FrameStyle -> 
              GrayLevel[0.75], RoundingRadius -> 7]& )], ",", 
           RowBox[{"{", 
            
            RowBox[{"\<\"{2013,\"\>", ",", "\<\"6,\"\>", ",", "\<\"17}\"\>", 
             ",", "0.`"}], "}"}], ",", 
           RowBox[{"{", 
            
            RowBox[{"\<\"{2014,\"\>", ",", "\<\"7,\"\>", ",", "\<\"15}\"\>", 
             ",", "0.04878048780487805`"}], "}"}], ",", 
           RowBox[{"{", 
            
            RowBox[{"\<\"{2014,\"\>", ",", "\<\"4,\"\>", ",", "\<\"25}\"\>", 
             ",", "0.`"}], "}"}], ",", 
           RowBox[{"{", 
            
            RowBox[{"\<\"{2013,\"\>", ",", "\<\"2,\"\>", ",", "\<\"19}\"\>", 
             ",", "0.041666666666666664`"}], "}"}], ",", 
           RowBox[{"{", 
            
            RowBox[{"\<\"{2012,\"\>", ",", "\<\"5,\"\>", ",", "\<\"12}\"\>", 
             ",", "0.`"}], "}"}], ",", 
           RowBox[{"{", 
            
            RowBox[{"\<\"{2013,\"\>", ",", "\<\"5,\"\>", ",", "\<\"14}\"\>", 
             ",", "0.005405405405405406`"}], "}"}], ",", 
           RowBox[{"{", 
            
            RowBox[{"\<\"{2013,\"\>", ",", "\<\"8,\"\>", ",", "\<\"12}\"\>", 
             ",", "0.`"}], "}"}]}], "}"}],
         Short[#, 5]& ],
        BaseStyle->{Deployed -> False},
        StripOnInput->False]},
      {GridBox[{
         {
          TagBox[
           TooltipBox[
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource[
                "FEStrings", "sizeBriefExplanation"], StandardForm],
               ImageSizeCache->{98., {4., 14.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarCategory",
             StripOnInput->False],
            StyleBox[
             DynamicBox[
              ToBoxes[
               FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
               StandardForm]], DynamicUpdating -> True, StripOnInput -> 
             False]],
           Annotation[#, 
            Style[
             Dynamic[
              FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"]], 
             DynamicUpdating -> True], "Tooltip"]& ], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
                StandardForm],
               ImageSizeCache->{80., {1., 14.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
                StandardForm]],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           
           ButtonFunction:>OutputSizeLimit`ButtonFunction[
            Identity, 1, 14809592986061736052, 5/2],
           Enabled->True,
           Evaluator->Automatic,
           Method->"Queued"], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
                StandardForm],
               ImageSizeCache->{93., {1., 14.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
                StandardForm]],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           
           ButtonFunction:>OutputSizeLimit`ButtonFunction[
            Identity, 1, 14809592986061736052, 5 2],
           Enabled->True,
           Evaluator->Automatic,
           Method->"Queued"], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
                StandardForm],
               ImageSizeCache->{69., {1., 14.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
                StandardForm]],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           
           ButtonFunction:>OutputSizeLimit`ButtonFunction[
            Identity, 1, 14809592986061736052, Infinity],
           Enabled->True,
           Evaluator->Automatic,
           Method->"Queued"], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
                StandardForm],
               ImageSizeCache->{120., {1., 14.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
                StandardForm]],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           ButtonFunction:>FrontEndExecute[{
              FrontEnd`SetOptions[
              FrontEnd`$FrontEnd, 
               FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
              FrontEnd`FrontEndToken["PreferencesDialog"]}],
           Evaluator->None,
           Method->"Preemptive"]}
        },
        AutoDelete->False,
        FrameStyle->GrayLevel[0.85],
        GridBoxDividers->{"Columns" -> {False, {True}}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{"Columns" -> {{2}}}]}
     },
     DefaultBaseStyle->"Column",
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], 
         Offset[1.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Background->RGBColor[0.9657, 0.9753, 0.9802],
    FrameMargins->{{12, 12}, {0, 15}},
    FrameStyle->GrayLevel[0.85],
    RoundingRadius->5,
    StripOnInput->False],
   Deploy,
   DefaultBaseStyle->"Deploy"],
  Out[1]]], "Output",
 CellChangeTimes->{3.6551928579604673`*^9, 3.655192967366788*^9, 
  3.655193028589279*^9, 3.655247349225152*^9, 3.655253092487632*^9, 
  3.65526478736083*^9, 3.6552945760643315`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "df1", "]"}]], "Input",
 CellChangeTimes->{{3.6548085324984293`*^9, 3.6548085355820646`*^9}, 
   3.6551928717602825`*^9, {3.6551930356017094`*^9, 3.6551930364138746`*^9}}],

Cell[BoxData["3468983"], "Output",
 CellChangeTimes->{{3.655192864703842*^9, 3.655192874409824*^9}, 
   3.6551930378141613`*^9, 3.655247357416824*^9, 3.655253092606656*^9, 
   3.6552647874408464`*^9, 3.655294576303381*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", "z", "]"}]], "Input",
 CellChangeTimes->{{3.6548087599963083`*^9, 3.6548087632029676`*^9}, 
   3.6551928931786523`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"df2A", "=", 
   RowBox[{"Reap", "[", 
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"z", "=", "1"}], ",", 
      RowBox[{"z", "\[LessEqual]", 
       RowBox[{"Length", "[", "df1", "]"}]}], ",", 
      RowBox[{"z", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Sow", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"ToExpression", "[", 
          RowBox[{"StringJoin", "[", 
           RowBox[{
            RowBox[{"df1", "[", 
             RowBox[{"[", "z", "]"}], "]"}], "[", 
            RowBox[{"[", 
             RowBox[{"1", ";;", "3"}], "]"}], "]"}], "]"}], "]"}], ",", 
         RowBox[{
          RowBox[{"df1", "[", 
           RowBox[{"[", "z", "]"}], "]"}], "[", 
          RowBox[{"[", "4", "]"}], "]"}]}], "}"}], "]"}]}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.6548070202548075`*^9, 3.6548070292506604`*^9}, {
  3.6548070819125147`*^9, 3.6548070960014167`*^9}, {3.654807171610999*^9, 
  3.654807181519039*^9}, {3.654808263494997*^9, 3.6548084450364056`*^9}, {
  3.6548084758757625`*^9, 3.6548086001273656`*^9}, {3.6548086708639417`*^9, 
  3.654808710417091*^9}, {3.654808743527913*^9, 3.6548088136093554`*^9}, {
  3.6548629789690633`*^9, 3.6548630092853107`*^9}, {3.6549318611978836`*^9, 
  3.654931866006874*^9}, {3.6551928894238853`*^9, 3.655192905648196*^9}, {
  3.655193054862638*^9, 3.6551930695946445`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"df3", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{
    RowBox[{"Drop", "[", 
     RowBox[{"df2A", ",", "1"}], "]"}], ",", "2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.654808854554793*^9, 3.654808858791667*^9}, {
  3.654808967833135*^9, 3.6548089755357237`*^9}, {3.6548629855874286`*^9, 
  3.654862991535653*^9}}],

Cell[BoxData[
 InterpretationBox[
  TagBox[
   FrameBox[GridBox[{
      {
       ItemBox[
        TagBox[
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"2013", ",", "4", ",", "5"}], "}"}], ",", "0.`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"2013", ",", "4", ",", "8"}], "}"}], ",", 
             "0.03076923076923077`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"2013", ",", "3", ",", "10"}], "}"}], ",", "0.`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"2012", ",", "11", ",", "23"}], "}"}], ",", "0.`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"2014", ",", "2", ",", "13"}], "}"}], ",", 
             "0.030303030303030304`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"2013", ",", "8", ",", "5"}], "}"}], ",", "0.`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"2013", ",", "7", ",", "26"}], "}"}], ",", "0.05`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"2014", ",", "7", ",", "18"}], "}"}], ",", "0.`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"2014", ",", "2", ",", "4"}], "}"}], ",", 
             "0.022222222222222223`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"2014", ",", "1", ",", "3"}], "}"}], ",", "0.`"}], 
            "}"}], ",", 
           TemplateBox[{"3468964"},
            "OutputSizeLimit`Skeleton",
            DisplayFunction->(FrameBox[
              RowBox[{"\" \[CenterEllipsis]\"", #, "\"\[CenterEllipsis] \""}],
               Background -> GrayLevel[0.75], 
              BaseStyle -> {
               "Deploy", FontColor -> GrayLevel[1], FontSize -> Smaller, 
                ShowStringCharacters -> False}, BaselinePosition -> Baseline, 
              ContentPadding -> False, FrameMargins -> 1, FrameStyle -> 
              GrayLevel[0.75], RoundingRadius -> 7]& )], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"2013", ",", "1", ",", "22"}], "}"}], ",", "0.`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"2012", ",", "12", ",", "25"}], "}"}], ",", "0.`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"2013", ",", "6", ",", "17"}], "}"}], ",", "0.`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"2014", ",", "7", ",", "15"}], "}"}], ",", 
             "0.04878048780487805`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"2014", ",", "4", ",", "25"}], "}"}], ",", "0.`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"2013", ",", "2", ",", "19"}], "}"}], ",", 
             "0.041666666666666664`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"2012", ",", "5", ",", "12"}], "}"}], ",", "0.`"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"2013", ",", "5", ",", "14"}], "}"}], ",", 
             "0.005405405405405406`"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"2013", ",", "8", ",", "12"}], "}"}], ",", "0.`"}], 
            "}"}]}], "}"}],
         Short[#, 5]& ],
        BaseStyle->{Deployed -> False},
        StripOnInput->False]},
      {GridBox[{
         {
          TagBox[
           TooltipBox[
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource[
                "FEStrings", "sizeBriefExplanation"], StandardForm],
               ImageSizeCache->{98., {4., 14.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarCategory",
             StripOnInput->False],
            StyleBox[
             DynamicBox[
              ToBoxes[
               FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
               StandardForm]], DynamicUpdating -> True, StripOnInput -> 
             False]],
           Annotation[#, 
            Style[
             Dynamic[
              FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"]], 
             DynamicUpdating -> True], "Tooltip"]& ], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
                StandardForm],
               ImageSizeCache->{80., {1., 14.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
                StandardForm]],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           
           ButtonFunction:>OutputSizeLimit`ButtonFunction[
            Identity, 5, 14809592986061736052, 5/2],
           Enabled->True,
           Evaluator->Automatic,
           Method->"Queued"], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
                StandardForm],
               ImageSizeCache->{93., {1., 14.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
                StandardForm]],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           
           ButtonFunction:>OutputSizeLimit`ButtonFunction[
            Identity, 5, 14809592986061736052, 5 2],
           Enabled->True,
           Evaluator->Automatic,
           Method->"Queued"], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
                StandardForm],
               ImageSizeCache->{69., {1., 14.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
                StandardForm]],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           
           ButtonFunction:>OutputSizeLimit`ButtonFunction[
            Identity, 5, 14809592986061736052, Infinity],
           Enabled->True,
           Evaluator->Automatic,
           Method->"Queued"], 
          ButtonBox[
           PaneSelectorBox[{False->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
                StandardForm],
               ImageSizeCache->{120., {1., 14.}}],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControl",
             StripOnInput->False], True->
            StyleBox[
             StyleBox[
              DynamicBox[ToBoxes[
                FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
                StandardForm]],
              StripOnInput->False,
              DynamicUpdating->True], "SuggestionsBarControlActive",
             StripOnInput->False]}, Dynamic[
             CurrentValue["MouseOver"]],
            Alignment->Center,
            FrameMargins->0,
            ImageSize->{Automatic, 25}],
           Appearance->None,
           ButtonFunction:>FrontEndExecute[{
              FrontEnd`SetOptions[
              FrontEnd`$FrontEnd, 
               FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
              FrontEnd`FrontEndToken["PreferencesDialog"]}],
           Evaluator->None,
           Method->"Preemptive"]}
        },
        AutoDelete->False,
        FrameStyle->GrayLevel[0.85],
        GridBoxDividers->{"Columns" -> {False, {True}}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{"Columns" -> {{2}}}]}
     },
     DefaultBaseStyle->"Column",
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], 
         Offset[1.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Background->RGBColor[0.9657, 0.9753, 0.9802],
    FrameMargins->{{12, 12}, {0, 15}},
    FrameStyle->GrayLevel[0.85],
    RoundingRadius->5,
    StripOnInput->False],
   Deploy,
   DefaultBaseStyle->"Deploy"],
  Out[5]]], "Output",
 CellChangeTimes->{3.655192926080367*^9, 3.655193194221072*^9, 
  3.6552474577903004`*^9, 3.655253161687749*^9, 3.6552648537743793`*^9, 
  3.6552946438941717`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"ClearAll", "[", 
  RowBox[{"df1", ",", "df2", ",", "df2A"}], "]"}]], "Input",
 CellChangeTimes->{{3.6552474292744827`*^9, 3.655247453076339*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Group & Compute Average Data", "Chapter",
 CellChangeTimes->{{3.6542443363508205`*^9, 3.6542443454066744`*^9}, {
   3.654245869605239*^9, 3.654245879009162*^9}, {3.6542466211530085`*^9, 
   3.654246623615514*^9}, {3.654267746475107*^9, 3.6542677536545763`*^9}, {
   3.6543782764313297`*^9, 3.6543782924736357`*^9}, {3.6545960425007353`*^9, 
   3.6545960446181755`*^9}, 3.655264868111306*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"groupsAvg", "=", 
   RowBox[{"GroupBy", "[", 
    RowBox[{"df3", ",", 
     RowBox[{"First", "\[Rule]", "Last"}], ",", "Mean"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.6542458851924286`*^9, 3.654245903586192*^9}, {
   3.654246045566242*^9, 3.654246045772283*^9}, 3.6542466345277443`*^9, 
   3.654248167400139*^9, {3.6542485135786724`*^9, 3.6542485149729586`*^9}, 
   3.6542489368784385`*^9, 3.6542504717454596`*^9, 3.654254382300753*^9, {
   3.6542641383609524`*^9, 3.654264147342327*^9}, 3.6542679140983453`*^9, {
   3.6542783520002875`*^9, 3.654278353145522*^9}, {3.654279874750799*^9, 
   3.654279874944851*^9}, {3.6542901888001413`*^9, 3.6542901889431677`*^9}, 
   3.6545960214754033`*^9, 3.6546821113871098`*^9}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"groupsCnt", "=", 
    RowBox[{"GroupBy", "[", 
     RowBox[{"df3", ",", 
      RowBox[{"First", "\[Rule]", "Last"}], ",", "Length"}], "]"}]}], ";"}], 
  "*)"}]], "Input",
 CellChangeTimes->{{3.6542508300727744`*^9, 3.654250836385066*^9}, {
   3.65427836691434*^9, 3.6542783741668243`*^9}, 3.654278520223443*^9, {
   3.6542799935878096`*^9, 3.6542799959572926`*^9}, {3.6542902311044273`*^9, 
   3.654290257832896*^9}, 3.654300993817187*^9, 3.6543030185850687`*^9, {
   3.6543062200118084`*^9, 3.654306221312075*^9}, {3.654306281582406*^9, 
   3.6543062830717115`*^9}, 3.654809293922332*^9, 3.6548221428258142`*^9, 
   3.65526479025542*^9}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"groupsVar", "=", 
    RowBox[{"GroupBy", "[", 
     RowBox[{"df3", ",", 
      RowBox[{"First", "\[Rule]", "Last"}], ",", "Variance"}], "]"}]}], ";"}],
   "*)"}]], "Input",
 CellChangeTimes->{{3.654251520505435*^9, 3.654251532616914*^9}, 
   3.6542783785727253`*^9, 3.6542785475650363`*^9, 3.6542799995040193`*^9, {
   3.6542902334309034`*^9, 3.6542902638191204`*^9}, 3.654300988903182*^9, 
   3.654303009813274*^9, {3.654809300184623*^9, 3.654809318936487*^9}, 
   3.6548221488780603`*^9, 3.6552647951364155`*^9}],

Cell[BoxData[
 RowBox[{"ClearAll", "[", "df3", "]"}]], "Input",
 CellChangeTimes->{{3.654279906638637*^9, 3.6542799307075615`*^9}, {
   3.6542807208297443`*^9, 3.654280723234234*^9}, 3.654280943968073*^9, {
   3.6542821720816603`*^9, 3.654282173148878*^9}, 3.6542983859492655`*^9, {
   3.654299620387841*^9, 3.6542996402849092`*^9}, 3.6544774820392*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Display Data", "Chapter",
 CellChangeTimes->{{3.654091277633485*^9, 3.654091281454265*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"mercuryretrogrades", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "1", ",", "11"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2009", ",", "2", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2009", ",", "5", ",", "7"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2009", ",", "5", ",", "31"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2009", ",", "9", ",", "7"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2009", ",", "9", ",", "29"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2009", ",", "12", ",", "26"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2010", ",", "1", ",", "15"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2010", ",", "4", ",", "18"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2010", ",", "5", ",", "11"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2010", ",", "8", ",", "20"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2010", ",", "9", ",", "12"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2010", ",", "12", ",", "10"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2010", ",", "12", ",", "30"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2011", ",", "3", ",", "30"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2011", ",", "4", ",", "23"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2011", ",", "8", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2011", ",", "8", ",", "26"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2011", ",", "11", ",", "24"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2012", ",", "11", ",", "7"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2011", ",", "12", ",", "14"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2012", ",", "3", ",", "12"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2012", ",", "4", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2012", ",", "7", ",", "15"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2012", ",", "8", ",", "8"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2012", ",", "11", ",", "6"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2012", ",", "11", ",", "26"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2013", ",", "2", ",", "23"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2013", ",", "3", ",", "17"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2013", ",", "6", ",", "26"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2013", ",", "7", ",", "20"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2013", ",", "10", ",", "21"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2013", ",", "11", ",", "10"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2014", ",", "2", ",", "6"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2014", ",", "2", ",", "28"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2014", ",", "6", ",", "7"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2014", ",", "7", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2014", ",", "10", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2014", ",", "10", ",", "25"}], "}"}]}], "}"}]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"UK", " ", "time"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.6543302829771843`*^9, 3.654330505902649*^9}, {
   3.6543306967116885`*^9, 3.6543307610818586`*^9}, {3.654330865562236*^9, 
   3.6543308826417303`*^9}, {3.654331058653743*^9, 3.6543311589052544`*^9}, 
   3.654331218187384*^9, {3.6543312761542454`*^9, 3.6543312764263*^9}, 
   3.654331522661584*^9, {3.6544200914992633`*^9, 3.6544204372105017`*^9}, {
   3.6544205201435924`*^9, 3.654420528487311*^9}, {3.654420581095152*^9, 
   3.6544206875180817`*^9}, {3.654591641414826*^9, 3.65459176373003*^9}, {
   3.654591828183313*^9, 3.654591945537494*^9}, {3.65459199641698*^9, 
   3.6545920926568108`*^9}, 3.6545921267488356`*^9, {3.6545921610729094`*^9, 
   3.6545922409623723`*^9}, {3.654592272385846*^9, 3.654592384444938*^9}, {
   3.654592432794902*^9, 3.6545924717379265`*^9}, {3.6546065905663233`*^9, 
   3.654606606842678*^9}, {3.654608877432566*^9, 3.6546088778816586`*^9}, {
   3.654632012579912*^9, 3.6546320357666903`*^9}, 3.65463211981701*^9, {
   3.654682135573094*^9, 3.654682138158626*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.6546444125681157`*^9, 3.6546448775909405`*^9}, {
   3.6546449519412613`*^9, 3.6546449554979935`*^9}, {3.6546450464777412`*^9, 
   3.6546450543143573`*^9}, {3.6546450884223857`*^9, 3.654645092292183*^9}, {
   3.654645181281521*^9, 3.6546451867726526`*^9}, 3.654645431656113*^9, {
   3.654645507904826*^9, 3.6546455221957703`*^9}, {3.654645667936803*^9, 
   3.6546456721536713`*^9}, {3.654645746754044*^9, 3.6546459940199976`*^9}, {
   3.6546462903760657`*^9, 3.6546465437572784`*^9}, {3.6546482431854715`*^9, 
   3.6546483518918715`*^9}, {3.6546483914090137`*^9, 3.654648422680458*^9}, 
   3.654648470590332*^9, {3.6546485781624985`*^9, 3.6546486060112376`*^9}, 
   3.65476281375352*^9, 3.654853559276576*^9, {3.655018625299858*^9, 
   3.6550186300478363`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tsAvg", "=", 
  RowBox[{"TimeSeries", "[", "groupsAvg", "]"}]}]], "Input",
 CellChangeTimes->{{3.654245965611882*^9, 3.6542459714950867`*^9}, {
   3.654290302716079*^9, 3.654290308258213*^9}, 3.6543333518632236`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["TimeSeries",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False}, 
    PanelBox[
     PaneSelectorBox[{False->GridBox[{
        {
         PaneBox[
          ButtonBox[
           
           DynamicBox[FEPrivate`FrontEndResource[
            "FEBitmaps", "SquarePlusIconMedium"],
            ImageSizeCache->{18., {0., 18.}}],
           Appearance->None,
           ButtonFunction:>(Typeset`open$$ = True),
           Evaluator->Automatic,
           Method->"Preemptive"],
          Alignment->{Center, Center},
          
          ImageSize->
           Dynamic[{
            Automatic, 3.5 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification]}]], 
         GraphicsBox[{{}, {}, 
           {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
            Opacity[1.], LineBox[CompressedData["
1:eJwVknkw3HcYxjcrRGKrGRJh1WaCSNzHkokZ8XqjaREi1FlDEwkdQ9xHBI0h
tcveSobduI9WqsRWrIyjiVRSKbKVptZRWpXE7xu1mLS0qrr9453nn3eeZ973
8xyJTQmOo9NoNA/N/K8DBz66r6ynkPXcbdlQyAOF2/Kxd1spfEKXU/pZEmD+
5Ki2a6fQ9dW2aXSNBArVTdldXRQeFGc/cpKJQe/GEx+mgsIXuryOF30SoFV9
fm2zn8J/jnuf7MmTwIbl3aT0IQqlN821/R8JIcI5d/Did5p9852RkT3lMNer
/tBtnMIzRlsrYYkiiL93U9H8jMKzFe/P7t4jgQj3NxmlUxSyj25PXo6VgL9L
0ereeQqdZz6lx7FFENc6pEhepLAx5Ny87UMhLFXfm/MhFLawplfHk8WQrPPr
8KCaQlVxS+GpIDFErw8ybv9B4UJHampnvADSIgNrc7coRPkJlV+WCLju+1cX
aQRPRz3dnGBLQLea0zCsQ7AmsXgh5Ech8NIcDU8zCPLyBa4PckRwdUSwyDYg
qDo8dinGVwilt2pp+4wJTjxni5d28aFmaX42z4wgqzPjjVW6EEy7J40vWRDk
NM+5P/QUgmxz58DL4wTdnjbNCP4SgVfvdFSAA0GmOj1bKBVA4EYi3caVoNJK
NUXkArjQaZ/Q6E7wSGN3QlisAGZetjiKgWCky793TPLFkFet9Io9Q9Bd+c1+
nyI+mA3bGij9COrq2Ktss/lgnXrK++vzBMN/HzD+ky6CkxXXXV3CNH5XzCID
W/iQyM5MrYwiGKCtVdlZxQfd4MOM5IsEcxeCHF4VCeAL6u+PF+IJjj3ms1r1
BNBFE1iMJhE0tN6yPPeDEAbEgXVB6Zp7GL+sKDX/XZF9G9eXQ9DZpl5JpQqB
a7XKkxYQPB+qdUPrugiO2vinHywmKGNerp2aFYDdVzG92qUEd2r0Dq3Pa/ry
pYXvtJBgEtspVq7gQ4m5idSvgqDlW4x2ypMPLJNhPyephk/ere5iXx70chv6
uuoIflCgl0tnlEFOhlPOoRaCRv379spHyqD+56zy9dsEq4iT50BTGXx///WV
hDsEP3u2Jla0ceGChXFbaA/B3Z/gECeEC8xdGw5W/QSn2yos23/jwmS4Tlb5
A4JpE/GDtl5c2LYfZWY+JmiQ74vRnlywKhgqXBslKGc11OtHcqD3bMp7ixME
o69tnfDI5UBK5XhYn0rDp2M5SwVcsI6IOeYwp8mXjb3TU1IKAdLmcKNFgplX
g9dH7nIgI9TUR0oRtKOF13mslYD363pHR7WmT/pv0/Q0/P4DWvfWYA==
             "]]}},
          AspectRatio->1,
          Axes->{False, False},
          AxesLabel->{None, None},
          AxesOrigin->{3.45*^9, 0.010400000000000001`},
          DisplayFunction->Identity,
          Frame->{{True, True}, {True, True}},
          FrameLabel->{{None, None}, {None, None}},
          FrameStyle->Directive[
            Opacity[0.5], 
            Thickness[Tiny], 
            RGBColor[0.368417, 0.506779, 0.709798]],
          FrameTicks->{{None, None}, {None, None}},
          GridLines->{None, None},
          GridLinesStyle->Directive[
            GrayLevel[0.5, 0.4]],
          
          ImageSize->
           Dynamic[{
            Automatic, 3.5 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification]}],
          
          Method->{
           "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
            AbsolutePointSize[6], "ScalingFunctions" -> None},
          
          PlotRange->{{3439756800, 3615062400}, {0.011202310192743502`, 
            0.017607834772010462`}},
          PlotRangeClipping->True,
          PlotRangePadding->{{
             Scaled[0.1], 
             Scaled[0.1]}, {
             Scaled[0.1], 
             Scaled[0.1]}},
          Ticks->{Automatic, Automatic}], GridBox[{
           {
            TagBox[
             TemplateBox[{RowBox[{
                 TagBox["\"Time: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"01 Jan 2009\"", "SummaryItem"]}],RowBox[{
                 TagBox["\" to \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"23 Jul 2014\"", "SummaryItem"]}]},
              "RowDefault"],
             "SummaryItem"], "\[SpanFromLeft]"},
           {
            RowBox[{
             TagBox["\<\"Data points: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["2030",
              "SummaryItem"]}], "\[SpanFromLeft]"}
          },
          AutoDelete->False,
          
          BaseStyle->{
           ShowStringCharacters -> False, NumberMarks -> False, 
            PrintPrecision -> 3, ShowSyntaxStyles -> False},
          GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
          GridBoxSpacings->{"Columns" -> {{2}}, "Rows" -> {{Automatic}}}]}
       },
       AutoDelete->False,
       BaselinePosition->{1, 1},
       GridBoxAlignment->{"Rows" -> {{Top}}},
       GridBoxItemSize->{
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], True->GridBox[{
        {
         PaneBox[
          ButtonBox[
           
           DynamicBox[FEPrivate`FrontEndResource[
            "FEBitmaps", "SquareMinusIconMedium"]],
           Appearance->None,
           ButtonFunction:>(Typeset`open$$ = False),
           Evaluator->Automatic,
           Method->"Preemptive"],
          Alignment->{Center, Center},
          
          ImageSize->
           Dynamic[{
            Automatic, 3.5 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification]}]], 
         GraphicsBox[{{}, {}, 
           {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
            Opacity[1.], LineBox[CompressedData["
1:eJwVknkw3HcYxjcrRGKrGRJh1WaCSNzHkokZ8XqjaREi1FlDEwkdQ9xHBI0h
tcveSobduI9WqsRWrIyjiVRSKbKVptZRWpXE7xu1mLS0qrr9453nn3eeZ973
8xyJTQmOo9NoNA/N/K8DBz66r6ynkPXcbdlQyAOF2/Kxd1spfEKXU/pZEmD+
5Ki2a6fQ9dW2aXSNBArVTdldXRQeFGc/cpKJQe/GEx+mgsIXuryOF30SoFV9
fm2zn8J/jnuf7MmTwIbl3aT0IQqlN821/R8JIcI5d/Did5p9852RkT3lMNer
/tBtnMIzRlsrYYkiiL93U9H8jMKzFe/P7t4jgQj3NxmlUxSyj25PXo6VgL9L
0ereeQqdZz6lx7FFENc6pEhepLAx5Ny87UMhLFXfm/MhFLawplfHk8WQrPPr
8KCaQlVxS+GpIDFErw8ybv9B4UJHampnvADSIgNrc7coRPkJlV+WCLju+1cX
aQRPRz3dnGBLQLea0zCsQ7AmsXgh5Ech8NIcDU8zCPLyBa4PckRwdUSwyDYg
qDo8dinGVwilt2pp+4wJTjxni5d28aFmaX42z4wgqzPjjVW6EEy7J40vWRDk
NM+5P/QUgmxz58DL4wTdnjbNCP4SgVfvdFSAA0GmOj1bKBVA4EYi3caVoNJK
NUXkArjQaZ/Q6E7wSGN3QlisAGZetjiKgWCky793TPLFkFet9Io9Q9Bd+c1+
nyI+mA3bGij9COrq2Ktss/lgnXrK++vzBMN/HzD+ky6CkxXXXV3CNH5XzCID
W/iQyM5MrYwiGKCtVdlZxQfd4MOM5IsEcxeCHF4VCeAL6u+PF+IJjj3ms1r1
BNBFE1iMJhE0tN6yPPeDEAbEgXVB6Zp7GL+sKDX/XZF9G9eXQ9DZpl5JpQqB
a7XKkxYQPB+qdUPrugiO2vinHywmKGNerp2aFYDdVzG92qUEd2r0Dq3Pa/ry
pYXvtJBgEtspVq7gQ4m5idSvgqDlW4x2ypMPLJNhPyephk/ere5iXx70chv6
uuoIflCgl0tnlEFOhlPOoRaCRv379spHyqD+56zy9dsEq4iT50BTGXx///WV
hDsEP3u2Jla0ceGChXFbaA/B3Z/gECeEC8xdGw5W/QSn2yos23/jwmS4Tlb5
A4JpE/GDtl5c2LYfZWY+JmiQ74vRnlywKhgqXBslKGc11OtHcqD3bMp7ixME
o69tnfDI5UBK5XhYn0rDp2M5SwVcsI6IOeYwp8mXjb3TU1IKAdLmcKNFgplX
g9dH7nIgI9TUR0oRtKOF13mslYD363pHR7WmT/pv0/Q0/P4DWvfWYA==
             "]]}},
          AspectRatio->1,
          Axes->{False, False},
          AxesLabel->{None, None},
          AxesOrigin->{3.45*^9, 0.010400000000000001`},
          DisplayFunction->Identity,
          Frame->{{True, True}, {True, True}},
          FrameLabel->{{None, None}, {None, None}},
          FrameStyle->Directive[
            Opacity[0.5], 
            Thickness[Tiny], 
            RGBColor[0.368417, 0.506779, 0.709798]],
          FrameTicks->{{None, None}, {None, None}},
          GridLines->{None, None},
          GridLinesStyle->Directive[
            GrayLevel[0.5, 0.4]],
          
          ImageSize->
           Dynamic[{
            Automatic, 3.5 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification]}],
          
          Method->{
           "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
            AbsolutePointSize[6], "ScalingFunctions" -> None},
          PlotRange->{{3439756800, 3615062400}, {0.011202310192743502`, 
            0.017607834772010462`}},
          PlotRangeClipping->True,
          PlotRangePadding->{{
             Scaled[0.1], 
             Scaled[0.1]}, {
             Scaled[0.1], 
             Scaled[0.1]}},
          Ticks->{Automatic, Automatic}], GridBox[{
           {
            TagBox[
             TemplateBox[{RowBox[{
                 TagBox["\"Time: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"01 Jan 2009\"", "SummaryItem"]}],RowBox[{
                 TagBox["\" to \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"23 Jul 2014\"", "SummaryItem"]}]},
              "RowDefault"],
             "SummaryItem"], "\[SpanFromLeft]"},
           {
            RowBox[{
             TagBox["\<\"Data points: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["2030",
              "SummaryItem"]}], "\[SpanFromLeft]"},
           {
            RowBox[{
             TagBox["\<\"Regular: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["True",
              "SummaryItem"]}], 
            RowBox[{
             TagBox["\<\"Output dimension: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["1",
              "SummaryItem"]}]},
           {
            RowBox[{
             TagBox["\<\"Metadata: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["None",
              "SummaryItem"]}], 
            RowBox[{
             TagBox["\<\"Minimum increment: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox[
              RowBox[{"{", 
               RowBox[{"1", ",", "\<\"Day\"\>"}], "}"}],
              "SummaryItem"]}]},
           {
            TagBox["\<\"\"\>",
             "SummaryItem"], 
            RowBox[{
             TagBox["\<\"Resampling: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["\<\"LinearInterpolation\"\>",
              "SummaryItem"]}]}
          },
          AutoDelete->False,
          
          BaseStyle->{
           ShowStringCharacters -> False, NumberMarks -> False, 
            PrintPrecision -> 3, ShowSyntaxStyles -> False},
          GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
          GridBoxSpacings->{"Columns" -> {{2}}, "Rows" -> {{Automatic}}}]}
       },
       AutoDelete->False,
       BaselinePosition->{1, 1},
       GridBoxAlignment->{"Rows" -> {{Top}}},
       GridBoxItemSize->{
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}]}, Dynamic[
      Typeset`open$$],
      ImageSize->Automatic],
     BaselinePosition->Baseline],
    DynamicModuleValues:>{}], "]"}],
  TemporalData[TimeSeries, {CompressedData["
1:eJwVmHc81f0bxoWSpCQrErJXKiqzW0YqQpSyGkZJZkNGFMWZ33FQHiokI5KZ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    "], {
     TemporalData`DateSpecification[{2009, 1, 1, 0, 0, 0.}, {
      2014, 7, 23, 0, 0, 0.}, {1, "Day"}]}, 1, {"Continuous", 1}, {
    "Discrete", 1}, 1, {
    ValueDimensions -> 1, DateFunction -> Automatic, 
     ResamplingMethod -> {"Interpolation", InterpolationOrder -> 1}}}, True, 
   10.1],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.6551933066380053`*^9, 3.655247507209383*^9, 
  3.655253171057661*^9, 3.6552648817930965`*^9, 3.6552946480450172`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{"tsCnt", "=", 
   RowBox[{"TimeSeries", "[", "groupsCnt", "]"}]}], "*)"}]], "Input",
 CellChangeTimes->{{3.654298512033063*^9, 3.6542985258478894`*^9}, 
   3.655264887461253*^9}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{"tsVar", "=", 
   RowBox[{"TimeSeries", "[", "groupsVar", "]"}]}], "*)"}]], "Input",
 CellChangeTimes->{{3.654298531069957*^9, 3.654298544865779*^9}, 
   3.655264892789339*^9}],

Cell[BoxData[
 RowBox[{"ClearAll", "[", 
  RowBox[{"groupsAvg", ",", "groupsCnt", ",", "groupsVar"}], "]"}]], "Input",
 CellChangeTimes->{{3.6547048023869314`*^9, 3.6547048369190474`*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.6548477853144307`*^9, 3.6548477922548614`*^9}}],

Cell[CellGroupData[{

Cell["Averages", "Subchapter",
 CellChangeTimes->{{3.654847518871526*^9, 3.654847520355832*^9}}],

Cell["", "Text",
 CellChangeTimes->{{3.6549789989771156`*^9, 3.6549790279310822`*^9}, 
   3.6550187008954363`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tsA", "=", 
  RowBox[{"TimeSeriesWindow", "[", 
   RowBox[{"tsAvg", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "1", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2014", ",", "7", ",", "23"}], "}"}]}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.6551933417791753`*^9, 3.6551933419712143`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["TimeSeries",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False}, 
    PanelBox[
     PaneSelectorBox[{False->GridBox[{
        {
         PaneBox[
          ButtonBox[
           
           DynamicBox[FEPrivate`FrontEndResource[
            "FEBitmaps", "SquarePlusIconMedium"],
            ImageSizeCache->{18., {0., 18.}}],
           Appearance->None,
           ButtonFunction:>(Typeset`open$$ = True),
           Evaluator->Automatic,
           Method->"Preemptive"],
          Alignment->{Center, Center},
          
          ImageSize->
           Dynamic[{
            Automatic, 3.5 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification]}]], 
         GraphicsBox[{{}, {}, 
           {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
            Opacity[1.], LineBox[CompressedData["
1:eJwVknkw3HcYxjcrRGKrGRJh1WaCSNzHkokZ8XqjaREi1FlDEwkdQ9xHBI0h
tcveSobduI9WqsRWrIyjiVRSKbKVptZRWpXE7xu1mLS0qrr9453nn3eeZ973
8xyJTQmOo9NoNA/N/K8DBz66r6ynkPXcbdlQyAOF2/Kxd1spfEKXU/pZEmD+
5Ki2a6fQ9dW2aXSNBArVTdldXRQeFGc/cpKJQe/GEx+mgsIXuryOF30SoFV9
fm2zn8J/jnuf7MmTwIbl3aT0IQqlN821/R8JIcI5d/Did5p9852RkT3lMNer
/tBtnMIzRlsrYYkiiL93U9H8jMKzFe/P7t4jgQj3NxmlUxSyj25PXo6VgL9L
0ereeQqdZz6lx7FFENc6pEhepLAx5Ny87UMhLFXfm/MhFLawplfHk8WQrPPr
8KCaQlVxS+GpIDFErw8ybv9B4UJHampnvADSIgNrc7coRPkJlV+WCLju+1cX
aQRPRz3dnGBLQLea0zCsQ7AmsXgh5Ech8NIcDU8zCPLyBa4PckRwdUSwyDYg
qDo8dinGVwilt2pp+4wJTjxni5d28aFmaX42z4wgqzPjjVW6EEy7J40vWRDk
NM+5P/QUgmxz58DL4wTdnjbNCP4SgVfvdFSAA0GmOj1bKBVA4EYi3caVoNJK
NUXkArjQaZ/Q6E7wSGN3QlisAGZetjiKgWCky793TPLFkFet9Io9Q9Bd+c1+
nyI+mA3bGij9COrq2Ktss/lgnXrK++vzBMN/HzD+ky6CkxXXXV3CNH5XzCID
W/iQyM5MrYwiGKCtVdlZxQfd4MOM5IsEcxeCHF4VCeAL6u+PF+IJjj3ms1r1
BNBFE1iMJhE0tN6yPPeDEAbEgXVB6Zp7GL+sKDX/XZF9G9eXQ9DZpl5JpQqB
a7XKkxYQPB+qdUPrugiO2vinHywmKGNerp2aFYDdVzG92qUEd2r0Dq3Pa/ry
pYXvtJBgEtspVq7gQ4m5idSvgqDlW4x2ypMPLJNhPyephk/ere5iXx70chv6
uuoIflCgl0tnlEFOhlPOoRaCRv379spHyqD+56zy9dsEq4iT50BTGXx///WV
hDsEP3u2Jla0ceGChXFbaA/B3Z/gECeEC8xdGw5W/QSn2yos23/jwmS4Tlb5
A4JpE/GDtl5c2LYfZWY+JmiQ74vRnlywKhgqXBslKGc11OtHcqD3bMp7ixME
o69tnfDI5UBK5XhYn0rDp2M5SwVcsI6IOeYwp8mXjb3TU1IKAdLmcKNFgplX
g9dH7nIgI9TUR0oRtKOF13mslYD363pHR7WmT/pv0/Q0/P4DWvfWYA==
             "]]}},
          AspectRatio->1,
          Axes->{False, False},
          AxesLabel->{None, None},
          AxesOrigin->{3.45*^9, 0.010400000000000001`},
          DisplayFunction->Identity,
          Frame->{{True, True}, {True, True}},
          FrameLabel->{{None, None}, {None, None}},
          FrameStyle->Directive[
            Opacity[0.5], 
            Thickness[Tiny], 
            RGBColor[0.368417, 0.506779, 0.709798]],
          FrameTicks->{{None, None}, {None, None}},
          GridLines->{None, None},
          GridLinesStyle->Directive[
            GrayLevel[0.5, 0.4]],
          
          ImageSize->
           Dynamic[{
            Automatic, 3.5 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification]}],
          
          Method->{
           "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
            AbsolutePointSize[6], "ScalingFunctions" -> None},
          
          PlotRange->{{3439756800, 3615062400}, {0.011202310192743502`, 
            0.017607834772010462`}},
          PlotRangeClipping->True,
          PlotRangePadding->{{
             Scaled[0.1], 
             Scaled[0.1]}, {
             Scaled[0.1], 
             Scaled[0.1]}},
          Ticks->{Automatic, Automatic}], GridBox[{
           {
            TagBox[
             TemplateBox[{RowBox[{
                 TagBox["\"Time: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"01 Jan 2009\"", "SummaryItem"]}],RowBox[{
                 TagBox["\" to \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"23 Jul 2014\"", "SummaryItem"]}]},
              "RowDefault"],
             "SummaryItem"], "\[SpanFromLeft]"},
           {
            RowBox[{
             TagBox["\<\"Data points: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["2030",
              "SummaryItem"]}], "\[SpanFromLeft]"}
          },
          AutoDelete->False,
          
          BaseStyle->{
           ShowStringCharacters -> False, NumberMarks -> False, 
            PrintPrecision -> 3, ShowSyntaxStyles -> False},
          GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
          GridBoxSpacings->{"Columns" -> {{2}}, "Rows" -> {{Automatic}}}]}
       },
       AutoDelete->False,
       BaselinePosition->{1, 1},
       GridBoxAlignment->{"Rows" -> {{Top}}},
       GridBoxItemSize->{
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], True->GridBox[{
        {
         PaneBox[
          ButtonBox[
           
           DynamicBox[FEPrivate`FrontEndResource[
            "FEBitmaps", "SquareMinusIconMedium"]],
           Appearance->None,
           ButtonFunction:>(Typeset`open$$ = False),
           Evaluator->Automatic,
           Method->"Preemptive"],
          Alignment->{Center, Center},
          
          ImageSize->
           Dynamic[{
            Automatic, 3.5 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification]}]], 
         GraphicsBox[{{}, {}, 
           {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
            Opacity[1.], LineBox[CompressedData["
1:eJwVknkw3HcYxjcrRGKrGRJh1WaCSNzHkokZ8XqjaREi1FlDEwkdQ9xHBI0h
tcveSobduI9WqsRWrIyjiVRSKbKVptZRWpXE7xu1mLS0qrr9453nn3eeZ973
8xyJTQmOo9NoNA/N/K8DBz66r6ynkPXcbdlQyAOF2/Kxd1spfEKXU/pZEmD+
5Ki2a6fQ9dW2aXSNBArVTdldXRQeFGc/cpKJQe/GEx+mgsIXuryOF30SoFV9
fm2zn8J/jnuf7MmTwIbl3aT0IQqlN821/R8JIcI5d/Did5p9852RkT3lMNer
/tBtnMIzRlsrYYkiiL93U9H8jMKzFe/P7t4jgQj3NxmlUxSyj25PXo6VgL9L
0ereeQqdZz6lx7FFENc6pEhepLAx5Ny87UMhLFXfm/MhFLawplfHk8WQrPPr
8KCaQlVxS+GpIDFErw8ybv9B4UJHampnvADSIgNrc7coRPkJlV+WCLju+1cX
aQRPRz3dnGBLQLea0zCsQ7AmsXgh5Ech8NIcDU8zCPLyBa4PckRwdUSwyDYg
qDo8dinGVwilt2pp+4wJTjxni5d28aFmaX42z4wgqzPjjVW6EEy7J40vWRDk
NM+5P/QUgmxz58DL4wTdnjbNCP4SgVfvdFSAA0GmOj1bKBVA4EYi3caVoNJK
NUXkArjQaZ/Q6E7wSGN3QlisAGZetjiKgWCky793TPLFkFet9Io9Q9Bd+c1+
nyI+mA3bGij9COrq2Ktss/lgnXrK++vzBMN/HzD+ky6CkxXXXV3CNH5XzCID
W/iQyM5MrYwiGKCtVdlZxQfd4MOM5IsEcxeCHF4VCeAL6u+PF+IJjj3ms1r1
BNBFE1iMJhE0tN6yPPeDEAbEgXVB6Zp7GL+sKDX/XZF9G9eXQ9DZpl5JpQqB
a7XKkxYQPB+qdUPrugiO2vinHywmKGNerp2aFYDdVzG92qUEd2r0Dq3Pa/ry
pYXvtJBgEtspVq7gQ4m5idSvgqDlW4x2ypMPLJNhPyephk/ere5iXx70chv6
uuoIflCgl0tnlEFOhlPOoRaCRv379spHyqD+56zy9dsEq4iT50BTGXx///WV
hDsEP3u2Jla0ceGChXFbaA/B3Z/gECeEC8xdGw5W/QSn2yos23/jwmS4Tlb5
A4JpE/GDtl5c2LYfZWY+JmiQ74vRnlywKhgqXBslKGc11OtHcqD3bMp7ixME
o69tnfDI5UBK5XhYn0rDp2M5SwVcsI6IOeYwp8mXjb3TU1IKAdLmcKNFgplX
g9dH7nIgI9TUR0oRtKOF13mslYD363pHR7WmT/pv0/Q0/P4DWvfWYA==
             "]]}},
          AspectRatio->1,
          Axes->{False, False},
          AxesLabel->{None, None},
          AxesOrigin->{3.45*^9, 0.010400000000000001`},
          DisplayFunction->Identity,
          Frame->{{True, True}, {True, True}},
          FrameLabel->{{None, None}, {None, None}},
          FrameStyle->Directive[
            Opacity[0.5], 
            Thickness[Tiny], 
            RGBColor[0.368417, 0.506779, 0.709798]],
          FrameTicks->{{None, None}, {None, None}},
          GridLines->{None, None},
          GridLinesStyle->Directive[
            GrayLevel[0.5, 0.4]],
          
          ImageSize->
           Dynamic[{
            Automatic, 3.5 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification]}],
          
          Method->{
           "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
            AbsolutePointSize[6], "ScalingFunctions" -> None},
          PlotRange->{{3439756800, 3615062400}, {0.011202310192743502`, 
            0.017607834772010462`}},
          PlotRangeClipping->True,
          PlotRangePadding->{{
             Scaled[0.1], 
             Scaled[0.1]}, {
             Scaled[0.1], 
             Scaled[0.1]}},
          Ticks->{Automatic, Automatic}], GridBox[{
           {
            TagBox[
             TemplateBox[{RowBox[{
                 TagBox["\"Time: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"01 Jan 2009\"", "SummaryItem"]}],RowBox[{
                 TagBox["\" to \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"23 Jul 2014\"", "SummaryItem"]}]},
              "RowDefault"],
             "SummaryItem"], "\[SpanFromLeft]"},
           {
            RowBox[{
             TagBox["\<\"Data points: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["2030",
              "SummaryItem"]}], "\[SpanFromLeft]"},
           {
            RowBox[{
             TagBox["\<\"Regular: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["True",
              "SummaryItem"]}], 
            RowBox[{
             TagBox["\<\"Output dimension: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["1",
              "SummaryItem"]}]},
           {
            RowBox[{
             TagBox["\<\"Metadata: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["None",
              "SummaryItem"]}], 
            RowBox[{
             TagBox["\<\"Minimum increment: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox[
              RowBox[{"{", 
               RowBox[{"1", ",", "\<\"Day\"\>"}], "}"}],
              "SummaryItem"]}]},
           {
            TagBox["\<\"\"\>",
             "SummaryItem"], 
            RowBox[{
             TagBox["\<\"Resampling: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["\<\"LinearInterpolation\"\>",
              "SummaryItem"]}]}
          },
          AutoDelete->False,
          
          BaseStyle->{
           ShowStringCharacters -> False, NumberMarks -> False, 
            PrintPrecision -> 3, ShowSyntaxStyles -> False},
          GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
          GridBoxSpacings->{"Columns" -> {{2}}, "Rows" -> {{Automatic}}}]}
       },
       AutoDelete->False,
       BaselinePosition->{1, 1},
       GridBoxAlignment->{"Rows" -> {{Top}}},
       GridBoxItemSize->{
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}]}, Dynamic[
      Typeset`open$$],
      ImageSize->Automatic],
     BaselinePosition->Baseline],
    DynamicModuleValues:>{}], "]"}],
  TemporalData[TimeSeries, {CompressedData["
1:eJwVmHc81f0bxoWSpCQrErJXKiqzW0YqQpSyGkZJZkNGFMWZ33FQHiokI5KZ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    "], {
     TemporalData`DateSpecification[{2009, 1, 1, 0, 0, 0.}, {
      2014, 7, 23, 0, 0, 0.}, {1, "Day"}]}, 1, {"Continuous", 1}, {
    "Discrete", 1}, 1, {
    ValueDimensions -> 1, DateFunction -> Automatic, 
     ResamplingMethod -> {"Interpolation", InterpolationOrder -> 1}}}, True, 
   10.1],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.655193382137409*^9, 3.6552475457542467`*^9, 
  3.655253171664785*^9, 3.6552649154709673`*^9, 3.655294648433097*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"res5", "=", 
  RowBox[{"MeanFilter", "[", 
   RowBox[{"tsA", ",", 
    RowBox[{"(*", "20000000", "*)"}], "20000000"}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.655193410735243*^9, {3.6552649247318583`*^9, 3.6552649567593913`*^9}, 
   3.655268673806738*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["TimeSeries",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False}, 
    PanelBox[
     PaneSelectorBox[{False->GridBox[{
        {
         PaneBox[
          ButtonBox[
           
           DynamicBox[FEPrivate`FrontEndResource[
            "FEBitmaps", "SquarePlusIconMedium"],
            ImageSizeCache->{18., {0., 18.}}],
           Appearance->None,
           ButtonFunction:>(Typeset`open$$ = True),
           Evaluator->Automatic,
           Method->"Preemptive"],
          Alignment->{Center, Center},
          
          ImageSize->
           Dynamic[{
            Automatic, 3.5 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification]}]], 
         GraphicsBox[{{}, {}, 
           {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
            Opacity[1.], LineBox[CompressedData["
1:eJwVkn001Xccx++cQxZTGcvDSY1GiCs3K+eyz/1Mmok8NDFOcTU9nG4e7hXR
LEvh3uv+7k/jbq4eCG0RdteWK7rDGVnkmBaRiO7K98vJw5npLJvd/fE+73/e
5/XH+/1+NzElMsmIw+H4GfS/37GKb+uvIJjwxYh5q4iBJp8Zl13XCKY31Eyc
u8+A3SB3dusNgpO1O61C+UrIna3K0GgIqhqbUl5fV4LZuXtBdk0Exak9ojhj
FjjffJv9qpXgUn3dzLwLC0ubfxKJOwh273j2ljCchZhtWTphN8E96rDxgTQW
xrSzsT59BJe75iWPTrBwuFnVVP2AoO7fCklMlCHv+6dEOkywt0SgDuezEOJ9
du7NcYIDUyPxL11ZSLrW0ZSsJ1gk3AU7LFmYKmseC6IEmSytrozDQrLJRKdu
lqDenme0b1AJBxZ05rWLBNV7c7Jzy5WQ9mnY5azXBAW/dy1/FK+EQt+1c3oO
RdJQ7djrpgTTsoLKThOKvLbyzvMOSpCncd/+0JyiNqLUuMpcCad+Veh5lhSv
jl8atphkQHrxMme1DcXNqip3Vy0Dl6bGR09voNj+1Xy3qJIB+x+HbA45UczO
fXDTSMZA+asVq+dbKH7gH2tRnMGAQDsSF+pJ8baXb+SZeAbClo4buW2n+DTt
6Gd52xhIaPQ4dtWXoiBkWpjvxsDj5zVcFihq8qx7/vJl4HRZvyAxkOJy8RoL
GsLAhk53y/5gilE3Ih6LAxlwTfUPuBlO8VZxc906HwZ2lpzZ7r2f4sVVhwZz
DPzjvPTU0jiKPVajL8K9GDCN3GieLKTovirRMmATA9+Rv49MHjb0c+BLb5UF
AxqOwqlXRPGP++6b8JkC7rBhVyLEFHNkR/2T2hXwsvyXpJZMignKlanfVAoo
dJ6Tq3Mopta35w2kKOA9txCxdR7Fr72f8MQeCthaf1BrLKXIV6xbOdJXBDF1
Th+PMBSZucDh+ugiyHe0VQeXUHTgj3oULMjBwbYz2EtNsci6o2GlSA7awsoW
zRWKXs37uDZcOWRKvDLX11D0m9siKWiWQcWTkxcWainWirJap/gy6GmbPnHs
e4qejo0vhGNSSHCyuR51i+Ld7ATTofNSsHtjydO5laJCMpnPghSGok1OXmg3
7B87od+4WAj/ePTapd+luML7fJF/rxCcczpy53sprh4TZHStlYJ2T8pu/QDF
UypNuS5DCimlfftbHlGc8Zuw3Euk4Bpz0MVzjKKZ6Oez4Z/IIFRdHf2OnmLb
U/bhmm4ZSKLsg9TE8BdHsx9s35dDwHQFlztLUb7+4fLa23L4D7Kl3/4=
             "]]}},
          AspectRatio->1,
          Axes->{False, False},
          AxesLabel->{None, None},
          AxesOrigin->{3.45*^9, 0.0117},
          DisplayFunction->Identity,
          Frame->{{True, True}, {True, True}},
          FrameLabel->{{None, None}, {None, None}},
          FrameStyle->Directive[
            Opacity[0.5], 
            Thickness[Tiny], 
            RGBColor[0.368417, 0.506779, 0.709798]],
          FrameTicks->{{None, None}, {None, None}},
          GridLines->{None, None},
          GridLinesStyle->Directive[
            GrayLevel[0.5, 0.4]],
          
          ImageSize->
           Dynamic[{
            Automatic, 3.5 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification]}],
          
          Method->{
           "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
            AbsolutePointSize[6], "ScalingFunctions" -> None},
          
          PlotRange->{{3439756800, 3615062400}, {0.012104481152642064`, 
            0.016059203033274277`}},
          PlotRangeClipping->True,
          PlotRangePadding->{{
             Scaled[0.1], 
             Scaled[0.1]}, {
             Scaled[0.1], 
             Scaled[0.1]}},
          Ticks->{Automatic, Automatic}], GridBox[{
           {
            TagBox[
             TemplateBox[{RowBox[{
                 TagBox["\"Time: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"01 Jan 2009\"", "SummaryItem"]}],RowBox[{
                 TagBox["\" to \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"23 Jul 2014\"", "SummaryItem"]}]},
              "RowDefault"],
             "SummaryItem"], "\[SpanFromLeft]"},
           {
            RowBox[{
             TagBox["\<\"Data points: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["2030",
              "SummaryItem"]}], "\[SpanFromLeft]"}
          },
          AutoDelete->False,
          
          BaseStyle->{
           ShowStringCharacters -> False, NumberMarks -> False, 
            PrintPrecision -> 3, ShowSyntaxStyles -> False},
          GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
          GridBoxSpacings->{"Columns" -> {{2}}, "Rows" -> {{Automatic}}}]}
       },
       AutoDelete->False,
       BaselinePosition->{1, 1},
       GridBoxAlignment->{"Rows" -> {{Top}}},
       GridBoxItemSize->{
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], True->GridBox[{
        {
         PaneBox[
          ButtonBox[
           
           DynamicBox[FEPrivate`FrontEndResource[
            "FEBitmaps", "SquareMinusIconMedium"]],
           Appearance->None,
           ButtonFunction:>(Typeset`open$$ = False),
           Evaluator->Automatic,
           Method->"Preemptive"],
          Alignment->{Center, Center},
          
          ImageSize->
           Dynamic[{
            Automatic, 3.5 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification]}]], 
         GraphicsBox[{{}, {}, 
           {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
            Opacity[1.], LineBox[CompressedData["
1:eJwVkn001Xccx++cQxZTGcvDSY1GiCs3K+eyz/1Mmok8NDFOcTU9nG4e7hXR
LEvh3uv+7k/jbq4eCG0RdteWK7rDGVnkmBaRiO7K98vJw5npLJvd/fE+73/e
5/XH+/1+NzElMsmIw+H4GfS/37GKb+uvIJjwxYh5q4iBJp8Zl13XCKY31Eyc
u8+A3SB3dusNgpO1O61C+UrIna3K0GgIqhqbUl5fV4LZuXtBdk0Exak9ojhj
FjjffJv9qpXgUn3dzLwLC0ubfxKJOwh273j2ljCchZhtWTphN8E96rDxgTQW
xrSzsT59BJe75iWPTrBwuFnVVP2AoO7fCklMlCHv+6dEOkywt0SgDuezEOJ9
du7NcYIDUyPxL11ZSLrW0ZSsJ1gk3AU7LFmYKmseC6IEmSytrozDQrLJRKdu
lqDenme0b1AJBxZ05rWLBNV7c7Jzy5WQ9mnY5azXBAW/dy1/FK+EQt+1c3oO
RdJQ7djrpgTTsoLKThOKvLbyzvMOSpCncd/+0JyiNqLUuMpcCad+Veh5lhSv
jl8atphkQHrxMme1DcXNqip3Vy0Dl6bGR09voNj+1Xy3qJIB+x+HbA45UczO
fXDTSMZA+asVq+dbKH7gH2tRnMGAQDsSF+pJ8baXb+SZeAbClo4buW2n+DTt
6Gd52xhIaPQ4dtWXoiBkWpjvxsDj5zVcFihq8qx7/vJl4HRZvyAxkOJy8RoL
GsLAhk53y/5gilE3Ih6LAxlwTfUPuBlO8VZxc906HwZ2lpzZ7r2f4sVVhwZz
DPzjvPTU0jiKPVajL8K9GDCN3GieLKTovirRMmATA9+Rv49MHjb0c+BLb5UF
AxqOwqlXRPGP++6b8JkC7rBhVyLEFHNkR/2T2hXwsvyXpJZMignKlanfVAoo
dJ6Tq3Mopta35w2kKOA9txCxdR7Fr72f8MQeCthaf1BrLKXIV6xbOdJXBDF1
Th+PMBSZucDh+ugiyHe0VQeXUHTgj3oULMjBwbYz2EtNsci6o2GlSA7awsoW
zRWKXs37uDZcOWRKvDLX11D0m9siKWiWQcWTkxcWainWirJap/gy6GmbPnHs
e4qejo0vhGNSSHCyuR51i+Ld7ATTofNSsHtjydO5laJCMpnPghSGok1OXmg3
7B87od+4WAj/ePTapd+luML7fJF/rxCcczpy53sprh4TZHStlYJ2T8pu/QDF
UypNuS5DCimlfftbHlGc8Zuw3Euk4Bpz0MVzjKKZ6Oez4Z/IIFRdHf2OnmLb
U/bhmm4ZSKLsg9TE8BdHsx9s35dDwHQFlztLUb7+4fLa23L4D7Kl3/4=
             "]]}},
          AspectRatio->1,
          Axes->{False, False},
          AxesLabel->{None, None},
          AxesOrigin->{3.45*^9, 0.0117},
          DisplayFunction->Identity,
          Frame->{{True, True}, {True, True}},
          FrameLabel->{{None, None}, {None, None}},
          FrameStyle->Directive[
            Opacity[0.5], 
            Thickness[Tiny], 
            RGBColor[0.368417, 0.506779, 0.709798]],
          FrameTicks->{{None, None}, {None, None}},
          GridLines->{None, None},
          GridLinesStyle->Directive[
            GrayLevel[0.5, 0.4]],
          
          ImageSize->
           Dynamic[{
            Automatic, 3.5 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification]}],
          
          Method->{
           "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
            AbsolutePointSize[6], "ScalingFunctions" -> None},
          
          PlotRange->{{3439756800, 3615062400}, {0.012104481152642064`, 
            0.016059203033274277`}},
          PlotRangeClipping->True,
          PlotRangePadding->{{
             Scaled[0.1], 
             Scaled[0.1]}, {
             Scaled[0.1], 
             Scaled[0.1]}},
          Ticks->{Automatic, Automatic}], GridBox[{
           {
            TagBox[
             TemplateBox[{RowBox[{
                 TagBox["\"Time: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"01 Jan 2009\"", "SummaryItem"]}],RowBox[{
                 TagBox["\" to \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"23 Jul 2014\"", "SummaryItem"]}]},
              "RowDefault"],
             "SummaryItem"], "\[SpanFromLeft]"},
           {
            RowBox[{
             TagBox["\<\"Data points: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["2030",
              "SummaryItem"]}], "\[SpanFromLeft]"},
           {
            RowBox[{
             TagBox["\<\"Regular: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["True",
              "SummaryItem"]}], 
            RowBox[{
             TagBox["\<\"Output dimension: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["1",
              "SummaryItem"]}]},
           {
            RowBox[{
             TagBox["\<\"Metadata: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["None",
              "SummaryItem"]}], 
            RowBox[{
             TagBox["\<\"Minimum increment: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["86400",
              "SummaryItem"]}]},
           {
            TagBox["\<\"\"\>",
             "SummaryItem"], 
            RowBox[{
             TagBox["\<\"Resampling: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["\<\"LinearInterpolation\"\>",
              "SummaryItem"]}]}
          },
          AutoDelete->False,
          
          BaseStyle->{
           ShowStringCharacters -> False, NumberMarks -> False, 
            PrintPrecision -> 3, ShowSyntaxStyles -> False},
          GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
          GridBoxSpacings->{"Columns" -> {{2}}, "Rows" -> {{Automatic}}}]}
       },
       AutoDelete->False,
       BaselinePosition->{1, 1},
       GridBoxAlignment->{"Rows" -> {{Top}}},
       GridBoxItemSize->{
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}]}, Dynamic[
      Typeset`open$$],
      ImageSize->Automatic],
     BaselinePosition->Baseline],
    DynamicModuleValues:>{}], "]"}],
  TemporalData[TimeSeries, {CompressedData["
1:eJwdmnk8lV8TwNEiJLKHFEUhyhYpjV1R9qUiS2UrIpUlqWS997n3eS7KVqH4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    "], {{3439756800, 3615062400, 86400}}, 1, {"Continuous", 1}, {
    "Discrete", 1}, 1, {
    ValueDimensions -> 1, DateFunction -> Automatic, 
     ResamplingMethod -> {
      "Interpolation", InterpolationOrder -> 1, Method -> "Spline"}, 
     TemporalRegularity -> True}}, True, 10.1],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{{3.655193389728959*^9, 3.6551934128826823`*^9}, 
   3.655247547764657*^9, 3.6552531720018525`*^9, {3.6552649370253644`*^9, 
   3.6552649580566545`*^9}, 3.6552686751750174`*^9, 3.6552946488381796`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DateListPlot", "[", 
  RowBox[{"{", 
   RowBox[{"tsA", ",", "res5"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.6550187790145335`*^9, 3.6550187840475717`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJws3XlYzG0bBuBRkV1ooaQo0kJR1oqmIhSliMqSFhJaLCmJIqTQUESURGWJ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      "]]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw023lYTG8DxvGxL1mGNhLKrpSKRLaZlC00ZQlFE0JEY5cskUqislXWhvol
ayHZilAiYSR7KiFmSJMUiry3uXv94/pcz5kz8505c85zzpyM5/i6eDUUCARf
mwkE//7HvwyFXCm2mjyncZpP+EhYXQMPf/W5+UaZxkY9jyrFVasGbipeqbHE
Cd7pfLZ15GqNA/zg73e3t23rr3FyHByzYfi3xI0aFz+Azxjrlf7YrLHwJ7yi
VGi8Z6vGom7HlOK8DebpTUM0lk2AI2a4x48L01i+Gk75+7zj750aK+TwY6fm
OVURGgvuw74f5St779bYogru4uPxxW2vxtKucUrxn6bZhmNjNI4cB99q1/yo
xQGNM1bAT/dFhZocZv9h+O8A7+R5R9h/Fy4dkvK1NJb932Drm5vC78ax3zBe
KY785pFZmMj+0fCpQYOcfp1mvwz+WtzIySCJ/QfheT+9Qy+cY38WbHO9d1J0
CvvL4fOBO8fYXmJ/x/+U4h5jW811u8r+UbB5/pccr+vsXwoXbn53POIm+2Pg
DsvqBoZksv8WXHPmyMF+2ez/Am90Lh3V4B779RKU4l4z/uxyzWG/CNZZFt1V
9ID9i+H/7uUsyFKwfx/cu//JLe/y2H8D7pTn/zn/GfuV8JrJ1+Omv2K/9nGl
2LvkxKwXBewfAe/x9XHNKWb/Qnhpnz/BJe/Yvxs+Etth1LEP7E+DjY3fTor+
yP5SeGgDw9xpSva3S1SKX2xWdWr5mf1D4RHKElVEGfu94KcJdkULy9kfAa/3
iJplVMn+K/DMVy86N69m/zvYsuGoZrY17G9zQimu2GGQ0u4v+wfDPUccU/o0
jND0z4Fduh077dZE4+Qd8MjJlW0mtNC4OBWeZ/o1eIeWxsK38IDFyqKg1hqL
tE4qxY2H305La6+xzBrO3tVH8UdPY7kH7NZ1+C5LQ40VofCih/eP3euqsSAF
3iZpO+NTN40tCuEjdi+yRvXUWNr8FJ5/SJPsO701jrSCLY70nTTUROMMdzgm
KHxJT3ON1cHwx8g49woLjY3OwXblE94oB2gseQ0vHaf+en8Q+5ucVoprTQ/0
+jCE/f3h9eqR1vOHsn8G7GCZ0XbeMPZvhSs/B9jVDGf/WTg4PKQ8aAT7X8At
zf88MLJjf8MzSrF24+JHefbs7weXvd8Xe24s+13hpG9WNQYT2L8ZdvQ3757s
xP5TcF/VtHUDJrP/KVwo2JR7chr7/8J6g6McR85kf9+zSnFxsm37ajf2T4G/
DpI9Ozab/Rvht3e2i3I92Z8I9znQ/ZfRAvbnwRZrW2SbL2L/bzjqhe+MCUvY
3zsJ+0vnJmmvlrPfGS55cvW352r2+8N9flfkWK9l/3/wmkUj9yf4sf8R3DrT
K9J1Pftr4ASjmVq3N7G/RzI+n/Q7XpMC2T8Jbht1Yd+gbexfC3cYfPhgk53s
PwZf2Rdf7RDJ/ly4/7HA0U572P8DTiiR9/wbw37jc0pxVvzauzOOsN8RnnAv
5sWIOPavggXubt6y/9gfC7uMTn1emMj+HPjXt6g1oafY/x1uotO+wuMM+7uc
V4qvRtiWeSSxfyzcSZltfT2F/cvh8R9V+c2vsP8wvE00OiA0nf3Z8B7joBTj
m+yvgI1niDcPymR/pwvY3uNthx/MZr8DnGA3L/fdPfb7wpnzdG5uf8D+A3CH
I57rHjxmfybs7/A9PSyf/V9hoeOUuBfP2N8hRSk++W5pu10v2W8HZ0iWnOlV
wP4lcIXN1vQDheyPhnu3rdyW9I79N+FrFrKKmlL2f4ZfeOu8H6tkv+5Fpbjb
unfSG5/ZL4I/G5cNufGV/Yvg1PZOg5Iq2L8X/nv/cbPN39l/He6QbrZk9k/2
f4IPlIYHD6xhf/tUpVhreP+9Br/ZPxweV3IteFsd+xfAbt0Thr76y/5dsPfH
cQs/CyI1/dfgWzWKE7Mbalz8AY44smtR30YaC4WXcPw3vOymaqyxyBbue+5Q
g/SmGsvmwd973v/aobnG8nC4UZb8QZcWGisuw50C3xQ9bqmx4B08xXXS27ta
Glu0vozvt/4jm6u01AYW9fG6s7KVxpGe8LjusuAaOiMM9qqRqj+21lh9EX68
NVrPs63GRsVwVkrJ7GChxpKWV5TiDWK/DSHtNA4YCB+65Gt8tj37Z8NG9mU6
Adrs3wZHzzniG6zD/gtw3Ioxfdrosv8N/Mbm+ey/tKzZVaV4bMNXDZ302W8J
203uLWrRgf1ucDOvhKzPtCAYPhc9pMm1juxPhlvO0nsRZMD+V3DO7KeWNzqx
v/E1pfjS3SXuHw3Zbw4b5R4Yeqoz+6fDI+40avmmC/sD4WdPbhTEdWX/GXji
6Ir4pUbsfw53Grj8Wbgx+xukKcVnXZ/Ia7ux3xTu/Cfh1pPu7J8Gty/LXfig
B/sD4Gfvl93N7sn+k3CFfpMs717sz4e1j63z7N2b/XVwE1neBd0+7O+brhTf
buyf40dbTIZ15WbS0L7s3wA/mS7r1cSE/cf/WRW56ymd8RhuOXv/rgpT9tfC
c6pbDU3vx/5e15Xi6if9KlRm7JfAZz9oh583Z/86+I//bS0zC/bHw1c/v5Kc
tWT/Q7i922/ZrQHs/wW7JP/53sOa/d1vKMUhfnv8Bw5i/0S4f/Mez41t2L8G
fqrtFD1lMPuPwrox1W7ThrA/F07cUDxgiy37q+GTi7scHDSM/UYZSvEjv7/y
jOHsHw+veDhr8uWR7F8J/50VuXaUmP1H4LWqsKRIO/bfg7usXbDrKC2phP2v
zksNH8X+zjeV4uZdhjd8bc/+MbBhk8a2NmPYvwzuK7Ga130c+w/BhbprK5eN
Z/8d2MPfbq++I/vV8JUUgWjEBPYb3FKKuzfMmvZmIvvt4dYhl092cWK/L1xp
vShstIT9++G6xlcNdzqz/zbs1mvG9goX9pfBdxbulcdMZr/+baVY+iBXeGsK
+8WwSDdrRNZU9vvASQedrcymsT8KXj08vYebK/sz4HjFWMfE6exXwbkdAwXZ
M9mvk6kUh8UoOw5wZ/9I2DT0d0j2LPZ7wy+P7F393IP9e2AXxz8hCin70+ER
frZl7zzZ/xEe2923waU57G+fpRRvGVkZ1Hcu+4fBxxdUvGs7j/3z4Z9vZfK9
89kfCU+5LfwWsYD9V+F1nxSjm3iz/z08oOCnUZdF7G97B8eHSp0fKxazfwgc
ZJ277MwS9s+FLzVo7u29lP074XHtuvnk0cWX4PAW41tk+rK/BH76fWRC+2Xs
b5WN43Mr/5ggWjYIfvVIJ8ualkvht8NWpVyiFdvhPEF2aiAtuAg7y3wMutEW
RfDWQVOUIbS0xV0cjyY9OphGRw6ALwYPS/8jY/8suFev8UWpHFeHwPrz58oL
l7P/PHxw2rIf+bSkAF5j8LG53Qr2N72nFN9fmlGTQidbwNXPHruW0cUz4Uej
BUnltDAI9jrsqf+ZFiXBDQ+G/RdNy17COz1Xxgyl5Y1ysH4/F63ZfH6FGSw5
NSPWjRZMhxXZA4/sr+/fAte0HtqiE/ukp2HvlCsNnPn+Rz6Ddyasm7GMzhDc
x/Z8uK6vGz8vtQnc8G561CDaaCpcuzp19H1+3pJNcMS1XuvP13/+J2BJUt3l
hXTyE/hr07ymVvWf/x8458x37Rxa2CdXKf4gOFTlwucXucCCtKMxE2nZ+n/j
Zu8PGNDyBHjN65PjAtmjUMCL5oxdd5wW1MIGb7PcOtMWPR8oxUeHdR9iU9/v
BLd0zBs1nY70gw+2SdzTvf7zj4Mb/rLavZbPp34Av38vaDWsvv8nXLZ3fU+X
+v5uD5XiqeMD79tyPGACnPTZpkxa378afp7bKfOXD/vl8CnBWDNTfn+E92HD
bVePT+b3S1QF913cUf/KQvZ3fYT5aca7pAP8fsrHwe0XW4a15PdXsQL2HdFg
1x5+vwVH4NfR5SaJ9d//u/CKLc+uraWl3+BrLkvNBnL5SEOFUvxFS2d0J+4/
MkbDCxaVt8jn/kUtgyuinKNP0EYH4fS1kqIC7o8kWXCnA72tvsxmfzm8/efC
xBHcnyV3fIz5TvWqAAn3d8Wj4N4zlfHnZ7B/KVylKH95hhbFwB/Khwke0rJb
8MuXo4rG0PIvcHXNsZl23L8q9PKU4h/TtiRYcv8rEMPXora8cOD+2mIx/DD4
9kEdWroPzvx+5sRSOvIGPNIw6YiQj89Qwpui5G8KaLX2E6V4jHthVA5tNAI2
PawYfK9+/78QrmweN24SHbAbDts/xvAL15+cBs/zb9E3iseT4lL4zEKh71ke
b4Tt8pXiy3b9PvrToqHwi4G9o/RpmRfcoO/WNU95/JJHwOna01028PimuAKn
hFwuG0AL3sOWfwsvq3g8tGjzFPs/iz6KBbR0MPxRq6OvehL758Dv2xxfYcHx
jB3wF8c8kw60OhWeNqv1rKm00Vt4X6vwXn35fBKtZ0rx3GJRmDsdYA33nFxz
U5tO9oCnBB6tmkAXh8I3czPqFtHCFPhJ8pmWfbh+USHsOPhRT30e32XNnyvF
e08e8F3D+YDcCj7dur/Oa84fFO7w7ZlfcqppQQh8aV+5zqux7D8H37gz5+FH
zj+kr+Far9iBd0ezv8kLpfjBMieXfAf294dXHpW5B9LqGbC2siqrK+c3Rlvh
hYO/x0ZxfiQ5C9vu3Gy7ng54Ae/TiygaKmJ/w5dK8X9TP4T34vyquB8c2t91
xHrOv4SucM66zg3bcX4m2gxfN3Y9+mwo+0/BsdNXTOnJ+Z38KXzDzP7Tqvr5
319YFjl9bi3nhwKTV0pxWkHCiIkct5gC1wgmRZrR0o3wbdXJT550ZCK8/Jpb
eSidkQeHBs2f7MTnU/+GJcsyux7kuFHv1zj/GOe0YhYtcYZ/dxIVNuDzB/jD
mTLtgjWczyb/B9co1pasGsj+R3DV8RvNimhhDbwm/lP3vbSoRwGO3/Yp6s2c
H8smwT43mh4ssmL/Wvjcqe0FzWjFMfjP7aD2dpxfCx7AZ/2WX2/L+bfFD/iT
yqOqiPNzqfEbnO9OO68OoSMd4ZPTZw6UcT6fsQoeuPC7nxatjoVvT78WFFg/
/8+Bv/p2ffWN5weS77Akz6VSi+MBXQqx/wl3O7KF48lj4Tidda/bc7x4OWw9
oCJqPseFh+FJC+d3sKRF2XCKwtNpO89HZBXwrh67PznT8k5FSrFqxoeQBJ7P
KBzgtKqVy/fUn//I4OXzvcoa8/zI4gDce6748nKeP0kzYcsLG98/5PlV5FfY
L3z06T88H8voUIz3Z2e2Xv35mtoOTu+bY/SK53NGS+BrLfJb96cl0XB/l+7l
8fXnfzdhS9MFo0N4fpj8Ge4+T+S+guePxbpvlWL59UOF83l+KRTBV1WmD014
/ilaBBdM/XV5FC3bC9fVNbOexfNV+XX4g21UsJDjik/w1NCwqbkcF2iX4Hiz
0OrE7/rz3+HwCuePlXk8P5YugH3a+g0Q83w6chc8IOjpeys99l+DXSY+Lr3N
83P1B3jL8a7/PeX5u5HwHb6Puk8N6s/vJbbwEa3PEcb15//zYMOvsrwbvF6Q
HA6fMqmMXE0XX4b7ul9Z3ITLC9/B8ntn3lbSotbvleIeHX83akHLbODXvgYT
2/D55J5ww3uOOf1pRRi87YHb4zG0IBX+473HQJuPtyiGlzRsFKvN6xXSlh/w
fk7dc6MXX0/kQHjVyPDoN23YPxu+PG6C3UhavQ0esybeL5nXQ4wuwHOuyOq2
8nqJ5A1sbaF1tgHHA5qVYr7itW7ODo4nW8LKXecN3vL6S7EbHNw04psZLQyG
f8elvwyjRclw6AZdg0W07BX8q7X74Oa0vPFHvP4P0zo78XqPwhw27Cu6uaH+
+s8MuMV6z0M3aItAWOVTkPya14ukZ2Crni5vPHg9KfI5vCBxou5OXm/KaPAJ
5xuXZQNDaLUpvDMu5XUobTQN7jjiqmdSM/YHwNpGT22C6YCT8Crn45dOc/nk
fLhuQsbc+Cbsr4PVMQ4NB9HCvkql2KZ82Sm9+utfk2H7nz213vF6mWwDPMhv
yTsxLT8OW+pYjd1HKx7DdZ89jq6mBb9hSdO0yREN2N9LpRQPHaNYHMLrcVIJ
XD4y5+JhOnIdXPlierWU1+8y4mHDeOOQTF7vUz+EJ+q/0d7K64FGv2BF6pIr
Vb94/a/7Z+yvgv5mjKcDJsLrO/Toc4ROXgO/+/61mS2vLxYfhavbNpHu+sHr
n7lwj4j3pwbSomrY8azXrsRqXv80+oL5bXSv7Ae8XikfD390sc8c943XP1fC
/VZ5/rnE65uCWFgW8mvWKTWvf96D7dSLz0t5PVRaCbuF3bpfQ0d2LsP37+7X
Zp3ojDHw9MkXDS7zeqp6GXzVQDxc+Yn9h+CshrvX/aQld+A82ea4bh/Yr4Z1
OzoUR5ew3+Ar5ju71uxq8Zb99nDgHi3BymL2+8LndK4oYorYvx9WnSqqKHrD
/tvwhDG3qu7yerG8DL7qXCd0pRX65Upx21DXjp1fs98OLl+74Eccrzdb+Pyz
/b7yj7weLY2C9aSG3Yc9Z38GXPCf39mxHM9QwTPD+v+KpdU6aqXYbM6s9Ppx
o5Hw3dSd80yesN8bjt5zr0aH18MD9sCuublLdz9kfzq8+838vAe8fl78ETYZ
0vL38Vz2t6/A9nK5qpXhffYPg0Wpw99Kctg/Hw4ulrmb83q8PBL+YFNS6cLr
9YqrcM+nnsvX0IIP8KYt0Rn3s9jf9ptSfHiKd/+SW+wfAhtvS/Gr5u8BkXPh
XwcKUyV0xk54q1D/TtAN9l+CRw/ZsOJbGvtL4IdPotrsv8r+VpXYfnUX9u9x
if2D4KFlOa2c+PtEshT+kfDCQe8C+7fDq3Ym6Kzi7xnCi7D9OG97CX/vEBXB
x/fkH82q//2jxXfsH5Z8jdA6y/4BcM9zz/MfcFwxC7ZyTClbTAu2wX5jfkZf
4O8pFufhY8NrK26fZH8BbOjcc2HycfY3rVKK92cWrSnh7zMZFvCCO61udefv
N+qZcJ2PcLFxLPuDYOWpqc3MDrM/CZ7XZPD8UQfZ/xJeOVlYMoK/DyU3qlaK
jZoNOVoZzX4zWGtEuwaFUeyfDsfY3vLvuZv9W2CHYx/3pkWw/zScdsL1lNYO
9j+DJXfCrh8LZb/gB+bLpfrpzvw9S2AKJ/041nZcCPunwi/nRW8rDWL/Jnje
VZfkLXTkCVjL/vnuN/x9LOMJ3E/cvbnJFvb/gQ9Kq0+68Pc0oz4/8X6cd/29
ib+3SVxg/ZtVoqR17F8PW3d8KVDRyQnwAfPZ91fRxQr49fjKwUtoYS28Z+8c
rc9cn6jnL5zv9FjQdBAtc4ItdM3n7uLycj9Y+vFtiPsa9sfBM78lbnZdyf6H
cD+P7Ekxy9j/EzZa1k5YK2N/txps33+7eR/1Zf8E+Pa2FT3D+Htkxmr41Z7Y
Bia0Wg6fK++c1d2H/ffhUY4JZun8PVNSBdv3KrQ/7cX+rrVK8eeKwm5W89g/
Ds4d0f2j3Vz2r4BnrpZYhniw/wjc+NT3L6mz2H8X/thry5IjtOwbbNnTpGss
LTf8rRTHFwl3j3Rn/2hYusmi0pe/1wqWwcFtnne1py0Owl+E0edtXdmfBU/+
21n8vP7333I4pFnCfzdd2N/xj1I8vlN5jaEz+0fBbq8fNS7h78lGS+EZ3xfM
q+XvzZIYWOdXsxGOo9l/C36+rXzEWTr5C9z1ncXsJ/y9ulivDt/P0aueHhrF
fjHs0Lwm8zDHRYvh3/a+Nj0c2L8P7v5GL79R/e/fN+CMtW5Bu0eyXwknD7zc
5hZ/Txfo/MX57dSUMH9b9o+AzQcObCEfzP6FcOewc2M727B/NxxjGJimojPS
YO/lrXxH0OpS+Gf4Kf+ygexvJ1CJY0vb5H+q//1/KDwlJOtwJB3gBW/3jNj6
zIr9EfC7LK3+ct4/UHwFVg/rZLWY9xcI38P+Qaa97/P+A1GbBirxN9/pATW0
bDBsv+tTUElf9s+B3xgVPr7eh/074DUZ34uNeD+D4BKcLp9Z0ZDjFm/hpN1O
61bQUq2GKnFzgyn5u3ux3xr+mdXhhhkfn+EBN5U97eTNcXUonDxxqkMLjhul
wMNPP0t5x/VJCuG61BXmUr6+gOaNVOLlK4atVtPJVrC4ZG2hnyn73WGLVQ4/
c/l4YQisDPXdvJL3Z4jOwZKKK+Xh3dn/Gs5N7nxFm/dzyJs0Volr0+ICxhix
vz/c53d+dbv6+z9mwsHrJhwq4bjFVvjXyCzrm7T0LKx3fEOeuTH7X8Cl08au
PkBnNGyiEpue2fN8IJdX94OP2qZtXML1G7nCj5bGTtjXhf2b4Wf+09e36sz+
U/Akl2dO/ejkp/D1S6m6E+jiv3Db+5VHXtFCk6Yq8Y+vTs32cH2iKXDj01fW
+3BcthG+f/yt4VCOyxPhlHPOp6bSijy4X8+0owdpwR+4icr3zV0+3qJ3M5W4
kVjR8TLvl5E6w8cbdTqXacB+f3j8sz5zrDux/z+4pSDV+QbH1Y/g3af39OjB
xxvVwPEzm/vac/2SHs1V4k+bHi704HjAJFi0fIxPGB+fvBY23VlqM6Ej+4/B
gXfWOO/twP4H8O1QoZWYFv2A38c/ermVy8uMW6jEU6t8diRyXO4Ivxk7VM+V
44pV8NMpz6fuoQVy2P/TTP0r+uzPgW9M9K7MpKXf4WffV8ZXcn2RXVqqxF+e
e2u15eMzxsJ959d+jeO4ejncc9eqJpf5eKPDcKmDcMk0WpINV/1uFBijy/4K
2H5/UO0WbfZ30lKJY+LnR19ux34H2FP7TsfHQvbLYJO/R87Macv+A/DzyecN
lrdhfybczs1ogTbH5V9h7SmjN47juKJDK5U4+kyKfQrvnxKMgkefd/twqBX7
l8CSlS2LB/N+K2k0nHZJ0b5JM/bfhN3XPV+2rhH7P8M6sxtMqBGwX7e1Snz4
Q9tBNhw3EsEHDHVX96Ili+AzMcP8terv/9oLx7iPrmjF+8OSr8OJOe+zp/zh
/W+f4JN/Isrm1PL+N+022F5DN/7sTYuGw+mqw8XveL+ZbAGcOM9+4tmfvP9t
F9y2w7nO13l/muIaPFF/U6AeLSiFHWcEn5ZU8f43YVuV2HncX5Pv33j/my38
fc6Klb505Dy4X9uyJm50Rjh8v3nxrta0+jKcZtxzxWfa6B081dVq7H1a0lqo
El/JPJTsWMH7/2zgVVon7rTm/XXJnvCgMwtb/vzC/jD4aOtvBmt4f54wFZ5c
+2OW9if2F8OV1rFbBLy/T9ayHV7PufCh/UvZPxD+0mn2gU+0YjZ8KPbv3wo+
XhAKT3T1zhvG+wEtLsAJLxs3UL1n/xtYdWhc6RM6sll79AV6bRHwfsMMS/je
97crepWw3w3u1KD61lTen2gUDD92WhW55g37k+ERP89fD6QDXsH7Xy+0G1vI
/sbaeH5t7TN3eL9jsTm89eLNgWWv2T8Dvt/GLPEoHy8KhDtXXmhoT8vOwCcX
9Ksr4vLy5/DBRz8uN6YVDXRg05z3M16yvx+s/SMp7shz9k+DI1qXTLv4lP0B
sKc0pP8l3p8ZeRIusbctXkpn5MP94koVfZ+wvw72SnVoXsD7O4366qrEs2Zf
3ziQlkyGD2ac+TOf94MGbICHhex6Xv6Q/cfhuJS+T9rTxY/hfqcv1lnlsv83
vCiutfwK7zcV9dJTiT3+E61O5f2oMgm8a2AX7WO0fB3smnV6b/Zd9sfDAb0d
tre9w/5HcHTyq5UFWez/BQdPHmxiUX//a3d9vP/ji8Z04/2xkRPh6wGjTo/M
YP8a+F78jWvVvJ9WfRSeVT3+UVUa+3PhN90CBl7h/beSajj3j3/Z/ivsN+qA
7cvmbH5gKvvHw9UbYp36XWD/SjjqRGJ31/Psj4X3mVx836L+/t978NPnm27+
Psv+SnhGn2cvTp9kf+eOOF75nVt09wT7x8A9VHcfXue4YDl8Oq7rPRltcQg+
8177mfYp9t+BG9qO6pzJx0eq4cFWBu3n8X7lDAMDlfhqwnCfubTaHja9GliR
SBv5/htfnt/r+X/s3w/f0Nla1DiB/bdhq2ai3T50chn8bcqzDhPoYv1OmE8l
BuTnx7PfDl48fk/SVlrkA7v12FlpyPupZVGwV9wfg/u0PAMOODC+TQKXV6jg
9epz31fTAl1DlXhlV2UfBy5vMRK+P6VSuEHOfm8491e810o6cg/sOyb57n3e
z52RDuuPaSeYTKs/wga1lpcX0UbtO2N7bVTi+bP+/u9h8NsHDw8Zc30B82Hn
7zrBNnRyJDym1QnxgWPsv9r53/YYPjCFFn6Am3oWV1w7yv62XdCbE9xXQsuG
wPOeFi56xfXJ58JDLlR9cOW4Yif8IzH0cBzXJ7gMR9aGtvbh8hYlcOOnt05l
8352aauu2H5vTL90ife7Rw6C+5+16fthP/ulsMTncX+vaPZvh7+d9ZpWso/9
F+FQQbWtBS0pghdvHtZEiw5oYYTjgf77Ix/4+OQBcGkDWVgN1188C+5u2Ud4
kfffC7fBi9zThfe4vOg87Lpw55pttKwAvrXYTqc0iv1NjVXinPZ2e1V8PoUF
3PLPhNKXvL9f4AYP7rvwm/ke9gfBCvNp73vuYn8S/LLXkVlBkex/CXto1xkO
5N8PZDTqhvmY4SLfYv59gdoMfqx/NGQP//7AaDr87lBO9OTt7N8CP20fJ3cO
Zf9peFxalwItOvkZvL95h7/Xt7Ff0B3vR4ehnsv5eKEpLD2fOv8jLZoKf9u5
b48LLdsE6+xWDPHg+uQn4PsWTsn9gtn/BO7oIXfbHsT+Ojh8iqCgin9PYdGn
h0q8Of3H3zyOS11ga7d7k03oyPXwgM+n33Tg8hkJ8OBZ8s31j1crYPMLtqm9
aaNaWN787/xn/PsNSc+eKvFQkcniAQHsd4KDSh9WuW5ivx/83xPH3KUcL477
N35w6PIkWvgQnnLgwJgWXF70E/a80m37Nf69iKxbL5V4jvnj8qa0fAJcGNUq
04V/X6JYDeeE+ZYt9WP/UbhZr9V3Rqxl/3043cXqeRf+fYq0Ct4Z/T1mzir2
d+2N/scHo2zpjHGwx/3L4yVcXr3i3/gcm8MjOW50BN6x9J5FMS25Cz93nrR8
BR3wDV7V1kqVTycb9sH85voV1Rj+vUzxaDjwifih3wr2L4NzNurF+tCig/CD
wzmfp9KyLNjTO0A4gOuTl8NHlvvN/sHXp+jYF+cz/p8Mrq9hvz38xN0oL7C+
fyncNPTvGW1aGgP38QlpvY7LR96CSxS6A47X93+BT3ZsHNiKr1etZ4L9wSyn
c3/4eozEcETN2w2v6v/+ZzFsfNUu53f93//sgzt1z2v/sr7/Btx9qslM7fp+
JTw3YsbVccvZr2OK8dZPG41dxv4RcLVzo6I+vuxfCLsNO7rs6xL274Yndm48
aRStSINfzRjeaCP/XknwEdZtO9W+nzf72/VTiYsPNMu/NZ/9Q2E7x3Zma7zY
7wV3sD0oGjCP/RHwxZ6HYurmsP8KXBsybUCMJ/vfw/rOP/KeS9nfxgzvZ/lz
TxuOBwyG1yd9K1pLJ8+Bj+5tfqT3XPbvgJtl9/ziQAsvwRd0PQN/cn2it7C5
U5fTdXy8TMsc54NODsl9aLk1rJy18Y6Yyys84PGtzxp9ms3+7eb/5ittJ9XN
Yn8K/OWbXbExLS2Ed3/fdCjOnf3N+6vEXZc3Ct9EZ1jBh9ZNq+rH5dXucFnX
7dc+ctwoBL5k7SeqpSXn4C2ei4zD6YDX8K8ubo0b08lNLFTijQusvjpNZ39/
+PLGT8ExU9k/Ew5J2Pt6+hT2b4XLXuu8Xu7M/rNw0L4537Oc2P8CNmiautyG
VjS0VIljh+t1ODiJ/WbwNndnf+EE9rvCn/cXdro3lv2b4XTxrY4BDuw/BYtL
7aN+jmL/U3jP2SmPj9Pqv3DFd2OtXrSRiRXml5kPbi0QsX8K3O3+pN3N6YCN
8J4rF55eH8H+RLhfSMk3l+Hsz4Mb/z0akD2U/X/gyK03JrS1ZX/vATg/j4+c
JRrMfmf44e78EWm03B+ef+rE5a427P8P3r93bk7hQPYrYLOf0+P3DGB/Dby3
9OjfbZbs7zEQ84mfG3Qz6chJ8E3n0otF/dm/duC/9+P7xI3m7D8Gz5pq/XK+
GfsfwO/ubMvX4vKSH/CQc4NfXKEDjK3xfVCd2TrFgv2OsJlk76h3HC9eBXu2
vNNjMC2Uw71ib8vtaFEObBqX1b0dHy/7bv3v+78gxpXj8i6DVOLtra7MdeS4
Yuygf/v32elDacEKeI7KZ8QGLm9xGJ77Re5/mz3SbLjM48/+YPZEVsAb2lRP
jeB4Ricblbhofonz6fp+B3hN9+mnbtX3y2A3xY0ubrTkANz29QHDKf3Ynwmr
D6UadDdl/1d4l6JbxOO+7O8wGNvzhefbXU3YPwpeo5xQ6M3lRUvgtv0T1R9p
WTTcZd3ZVlq0/Cbc8XpN4A8+XvEZHmlZmx1OC/SGYL6wrs18Yy5vIYJHhl+3
GcVx6SI4ytRqsRVfT+Re2DxU1HQtxzOuw3dWZ92Oo9WfYK2EiYtKubyRtq1K
/DFoocsbrl8yHO75ePxj0/r+BXDZvTN9rtb374Ir3DPM6l9/8TU4r0ydMoMW
lsIRwjqFN59PJByqEqc4qF8s4fPJbOGHO8ofm9LyebDlildDJ9GKcHjcmv+O
vKIFV+Dno3t6X+b6LN7BJ9Y+HVfEcWnrYSqx3/f8/T/6sN8GnnNaZ9RXOsMT
tvHe6HiJy6vDYH/roRt/cX1GqfCp7VZ+TWlJMTzcKneJkD0BLYfj+Cyzs/Ll
+5E8ENbS6xU7nNtL8Wz41ICNfcppYSj83Kqq+AQtugDbzRr50IOWvfnn2fOb
X6PlzUaoxEsP1n3tSissYV2f4ZVbub0K3OHU7z0mLeD3wSIYdvKtbTa7/vuf
DKsickeGWLH/FbxL3UmSSGc0Honzkx1TVzbn/kRtDrfRfuDuOYj9M+A3bV84
L+f+SBIIWyVcanB1CPvPwG3faVtv5v4s+Tncd1p8b8Nh7G8gwutdq3fpGC3s
B69y2DDcjRZNgxO9DTaU0LIAuEZrVmAr7j/lJ2GP7U1FQbQiH7YJvWJeSgv+
whu7Hb+bMJL9fcU4H1M/MW4jZv9k2H+UbYkbHbkB3lO0NTzSjv3HYeupE46L
7Nn/GNZp/mW0KY8XRr/hkVH29na0pJcdtkfXidbudIAEvqv3aMkUOnkdfMg5
ZZ/5GPbHwyW19y9t5vFI+Ai26zq/+Dgt+gVX933W89o49ncfpRJnbpyvDKPl
E+FPe6IivnN5xRq4NmN+t2pacAyen9XSI4LLW+TCOh4vDtrT0mq44vihz83H
s9/IHvOv8eOsxI7sHw/vf2lb6Mfjp3olnBUU5bh2Ivtj4YbzlT830JJ7cODA
k1at6YBKeKt+76FCHo+TOztgvJ3u/fN08Rh4u/h+wTQuL1wO71mY+zyRzyc6
BL8aOcnfguOyO7Bh1qaQw7RcDd9r+ND6ENenMBj9b/8/Z/9fzgcEDrD5Ei/X
JI5b+MKTst/8bspx6X543Q7t2hF05G34DU47H9EZZXDWuZz+VhL264/BeHGE
xyWOG9nBs209G6k4P5H4wG1uRbsn0gFRsOBlH7PPfHxyBnxM2masG12sgkOL
UpO2cn1C3bGYT35b8TiEfaKRsGV0gNNhvh8yb/i8beDRIFq+B9bTt/OdSSvS
4ZEnRpe35ucp+ARPbr9m/DtuDxbtx6nEoycNm2NeP/8ZBv+orKwcTEfOhyeP
abHkL50RCY90nCAex+1FfRW+/8VO/x3Xb/QB7tZuz6Zh3F4kbcdj/vDiU8Zi
jgcMgbOejvVw4+OT58IKw81vHOjinXDPsIKaDvw+CC/DJbM6V3Uczf4SeN3b
KVO+8/sna+WoEi8eZDa2ivMv+SB498iwAWdphRR2zcmrzKQFYbCP8TCLIXy8
xUVYL/fq+akclxbBJTMOTCur//63mIDPq1R52JXzt4wBsNRB9L079x/qWXDZ
Qg+9T7TRNnjUGZObJ2nJebi3clQDVzqgAB4gXlRdv79JbjoR8wGp8dq53L8U
W0z8d34ctUyXr0foBsd/CNm/lOOiINhizFD/X7QsCT4z9dLxGFr+Ep6zs0IS
TCsaTVKJw8bMif3K5xeYw7MW22TJuD+0mA7ffffKNIz7U+kWeI3xxxlt6cjT
8OHfX8clcPmMZ3BFpbJV/fJqgZNKvOxj3w9p3J8bmcLNPI4lvazf/0+Fv8UO
W9WSx4eATfClb7HtxDx+JJ+At3z9MybMmv1P4BY9Ng5+TAvr4EPRcoM2fLyo
jwTHt0EzOlXTMhd4ZpuFUU9o+Xp4ZBfXks+0IgEu7V2tsuD6BI/h224rW2Tz
+S1q4fzAozYtOC7t6YzzrVmPkxM4P450gt03d5nWgs7wgwcFHK65zeOhOg6+
1qdZRxOOGz2EEzM8Jm+iJT/hmVnXfm+mA7q54Pt+pip8H508Afb7oxjpSxev
huWVH75r0cKjcH/Rz5MjaNF9OG/6oO1b+PyyKtjkvtOeJB6/5V0nY3sK/3zI
uX7+Ow5+/bDgxkPOdwUr4ZXSY5Ih9fPfI/C9LJeoebT0Lnyjy5/3npwvRH77
Nx4jjrGun/8aTsHnr329w3TOL9Sj4Zezvpi25nzGaBmcMG9YTlH9/O8gPLKD
i0FI/fwvCw51L5Wo+fjkcth2icm3k1x/ccepmD/6tFseUT//t4c3Rfuv+Vg/
/18Kf56Wsaeyfv4fA+f/fDJmLC2/Bes3iDBuzvdD8QWO/L31SyO+XwL9aSqx
TCFYMpm2EMNp3c5Y1y8vXQzf66mz4DafL3If3DrZ7/DS+vOfG3D4ielL+/L5
1ErY80gXHUs+3kjHVSUefMtrgA4tGQFHDFsYMowOWAj3lXvk6def/+yG/wt6
FjubLk6DHY45vdhGCz/C+ks2PlrMx4vaTcfxfr+P5Q2+HtlQONo53DSk/vzH
C47pkNeo/v1URMA3Jjc2XVw//7sKt3GW7rnL99/iPdzMdU90+/rPv80Mlfic
5MLds3z+yMGwnTTfO5jPnzEHnv1ha/8yLq/eAY9Y7zPeg8sbXYKTiw5Ftqzv
fwvfvpzdeWB9v9ZMfJ4frM/0r++3hpvevNojuL7fA3ZfbZk1ub5/O2zzODjh
Uf3nnwLX3nyiP6z+8y+Ep662k0+q3/6bu2H/qh6c0bD+87eCv9lNFzWgBbNg
w8Ov/1jRFiFwXfi6oDyuT3oOdnge/8yl/vN/DT9M7aDKrt/+m7irxI1qI5Sr
6/v7wxssKxKyOG40E/6QKrrRov78dyvsXLWm/3uOB5yF31hG/f98NvkF7BH7
JCW6fvtvOAvfn5E/ffTrt38zuMK48ZyG9f2usF/s+9F3ubxsM7zk2BjVxfr5
/yn48Bu5y05+/xRPYZXb+VcjaYFgNt6v9NOL7OrP/0zgR31KN8jqz3+mwNVP
vnVNrT//2whXeAhmnq0//0uEM0t/7FLUn//lwS3NH7fXrz//+QMrjq8p8+bj
Jb09VGLf2lu2v3qz3xlWLlV9/kAn+8NOWlNsF/P8qvg/2OBC+/32HBcq4MsL
UwJ30aIaeNwqZaODvdjfQ6oSv9+6QT6kJ/snwZ4VBeNVtGItvM3n2JoEWhAH
y8+FnvxJWzyABRWLagb3YP8PuP/5vMywbuw39sR8IaBufEM6wxGuy29908iY
/avggZfy2guN2C+HY2L/K6vtyv4ceFnW4rLjHA/4DvsuU53O4Xhylzkq8fFT
P95JOV48FpY5uM6v5rhwBfxCYBh2vQv7D8Pm+VPGjaFl2XDfuCEmJp3ZXwHf
8x5i1Yrjik5zMf+K1bP+yHHBaNjPpKR6CG0hg3sdcuw42ZD9B+C/EV5z99KR
mfDTnHkn8umMr/C2d8PX9KDVHeZh/zTticFvA/aPgj91zVut7sj+JXBlZrnF
GDogGn44oEtKMzr5JjzKI9nGuAP7P8NuBs3MftBCPS9sb2Ldz124vEgERzrK
u9Q/XrYIHiZ88ClCn/174ec6Ldt66bL/Ohx+d4yjtTb7lfDVzjpLS9uxX3s+
vn/SmQ/n0dLh8Lz9aw8cEbJ/Afxo3fG+3eiMXfAo77sWF9qw/xrca+/ujD20
USkc/7GRbxQtES5QiTueeD3OrDX7beFF6222L2vF/nnwhNedj37XYn84HPnF
dnUpLbwCF1xMK/agRe/gl7Njlm1ryf7WC7F/2zX40voW7LeBFy1cczexOfs9
4eMbTM4ea8r+Hf98Z8qC0ibsT4VrJRndxbS0GN7tfXWIZSP2t/RWiYXl5jHl
Ddg/EH5dE73Ni1bPhtXGYbHv/u7U9IfCQd5es7rRkgvwiNCYjkl1Gge8ge32
z+3+4rfGyc0W4fh9WeusfY3GxZbwuJoxSctooTscFD940SNaFAznfWq57Agt
S4ZVZvlTrH5qLH8Fr89vE2JTpbGi8WLsv+w8Uu0rNRb0h5sccBpi/01jixlw
4dDHf1erNZYGwtNNHmd2Ltc48gy8ZErb7fp0xnPYMqWZeshXjdUNfPB5bJF6
JXxhfz84fHnAzHWf2T8NvjT+2RaPT+wPgBsfE6zw+sD+k3B53I1x5u/Znw/L
o+wtGr1j/184VZLZaMRb9vddgv3Do5BPA4vYPxnW1lUU7S5g/wY4TPeEveFr
9h+Hp1tEnTvwiv158JO8osN/aYvfsOPHu7srX7K/11KVWNInveQoHSmBZ6/x
dLd8wf518Ay9kxdUT9kfD9/vuC13/hP2P4IN2ghK6vLY/wtu92Fp56F0QHdf
vL45RaGRCvZPhIe1u6vn+Ij9a2BTv2P2mx6y/xj8t6zjo5UP2J8L90kxiArI
ZX81LNWfGf4qh/1GMpU4u+js/ev32D8e3rvHttz2LvtXwa8WfJveMJv9sfD3
CR7R37LYfw/uNHRSbFs6shJuoz/s2a/b7O+8DNtTRkO/npnsHwMHF5ptzee4
0XLYdOakR2a05BDsNer3xuBb7L8DZ25rWbfrJvvVcMsOnrZJGew3WK4SP57f
fni9hQ5wUvvUAimXF/nCE2Na7/KlZfvhaeNMp9ly/fLbsLs4qGoirSiDq1Yu
Me/H5QUdVuD9P7/rUfIN9tvBK9tLdJTp7PeBU9ZN+jv+Gvuj4JxA/x9OV9if
Ab9w0G1gT6tVsJ0wLyfyEvt1V+L7215/2PVU9o+EO5x74m53kf3e8LxR5gv8
U9i/B3Zqu3fshgvsT4dFl9T2JefY/wk+bdxHMi+Z/e1XqcQnB3sExp9h/zBY
usi6zfCT7J8Pz280ZmqDE+yPhJeevJy55jj7r8E/Lw9UOyaw/wPc/3JY53H/
sb/tapV4h135DJ949g+B102MvJwQx/65cFqzG8/mH2P/Tvjzf5tln+Tsvwwf
75brGXuE/SXwsNafneSH2N9qDeZfITFHfh9g/yA46qvf8N372S+FR89XbHsY
w/4wOPLAKrVVNPsvwmLHq2WlUewvgi3feydPo+Ut1mL7GntP8mEf+wfAwqXX
lm+hBbPhgk6FNWF72b8NPntS0dV5D/vPw3YOq8/r72Z/ATx87r5D+yPZ39QP
2/uHRyMSI9hvAfctdH9SFM5+N/ircvfqSTvYH+T3736wb961oexPgpcvHeTu
E8L+l/DSwT5W3sHsb7ROJfaPSjE6TgvN4Sw7Xb0OQeyfDo/0uDD+XiD7t8Dd
XsdHb6Dlp+HbGc3c67aw/xl8/0W5uBUtaOCP17t5Q6cjm9lvCtvvWD32eAD7
p8Ib3h3Y+WUj+zfBncIMO6xZz/4T8Hqp5dDD/ux/Ak9OthI5rmN/HbxSdnr/
Nj/291mvEh8QVSy8tJb9LvCO+CPHUujk9bBF2IrRqWvYnwCfnfAjrgstfAx3
6f+ipmoV+2thZ52IeWkr2d9zA7a/doNcJSvY7wQLC4QXFyxjvx/cwdd1ZksZ
++PhX02i597yZf9DeNSStMhutPTnv+UbrnjZZyn7u21Uicf67gka7sP+CfCg
0p12xxaxfzV8X8u50QZv9h+Fnzw3bTdpIfvvw1ta71xkvID9Vf8eP+h3owde
7O+6CfP1CybHL85l/zhY3uJAoOkc9q+EczfmThsnZf8R+P2Wnlv3zmb/XfjI
4omz+89i/zdYUmn3WuzGfsMAzLeTnr05OYP9Y2DTSR099k5n/zL4yeARz9tP
Y/9BWF6xb9iRKezPgu+GdTmywYX95XBNoPsjsRP7O25WiVe16Hdx1AT228P7
1iofmY9n/1J45I0eEwrGsD8G7qln5hTrwP5bsLiF9vyu9uz/Ap9xGGZWIWK/
/hYc7/K1jSyGs18MDyj5vLRsCPsXw9b5TU7/GsT+ffDDS3MHnBvI/htwRNZn
y0gr9qvgI8MlXr/7s18nEOcTNjK3MDP2j4DP3emwTGTC/oVw6z+vxx/vzf7d
8Efrk7/b9GJ/GvzgcoOnO7qz/2Pgv+0xOu6VEfvbbVWJh/469m1fF/YPhQ07
jM64ach+L3h8dWmlngH7I2Bd+6HvdfTYfxUeu2Rf6iJt9r+Hh8j/CqXt2N8m
CMfX4Oo8szbsHwyXBgbWFmmxfw58bvK1+Orm7N8Jr9rtsvZ0U/Zfgsc+u5Wb
15j9b+Fbfgb59g3YrxWM41GrkAEpdTs0/dawdPOpAulvjdUe8I9vl0pqf2ps
tB2+1uPrlJ/VGktSYIdJ51XtqzQOKIRn2+3Y9uebxsnNQ1TirXrvbQvLNS62
gpe+jZ//+ovGwlnwkPfNd11XaSwKgW+OiNs045PGsnNw8KOovydKNZa/hlv9
enH40juNFU224fx52ax+U4o1xg4f+7O5ljO8CjW2mAl7LXr2xKRAY+lWODul
bfXmlxpHnoWHJc37MvAZ+1/A5uLZe+bnsb9hKM5vDee5n3/IfjN4/4qvFeNz
2O8KO38KX9LvDvs3wy7bN2V632L/KTigid/DxjfY/xQ+Pl/6fnAa+wXb8f0Y
pN9j0mX2m8C2epY5oSnsnwKPHd2jxeJk9m+EX1/cnl5+mv2JsNOTNQXdTrL/
CRyX9u34iQT2/4GDbz7OTzvG/t5hmG+vc0vMjmW/Mxwsjbjy9CD7/eFPDad2
k8Ww/z84c+awo7K97FfA8qQlVg12sb8Gfl03PjVuJ/t77MD2IQlcIN/O/knw
5drFK7S2sX8t7PxwamOPIPbHwW18k4eEb2b/A7ixb35w2kb2/4A/uDvsn+DP
fuOdKvGdgUeimvux3xGe2+qqUftV7F8NW8Z/v/t8GfvlsOn2wXu7+rI/B75+
xcCz2WL2f4eNen2+um8B+7uE4/h66/bDLfPYPxZe1Wj3txpP9q+AB0yMWnLF
g/2H4WNb1rXZ7M7+bHji1deTKqezvwLu2nnnog7T2N8pAueD751a5LiwfzQ8
v8WT8V2d2C+DMz6ecEucwP4DsEFo2dVe49mfCfeu+nO16Rj2f4VDDynNVo9i
f8dIzL+mF4lLRrJ/FNwtfGtM+6HsXwKP3jlng7YN+6PhaV5bX2wYyP6bcFy+
QeEfS/Z/hvVCjscM789+vV0qcZF35sDEfuwXwe9W7h2Y2Jf9i+Cv1Z0cZT3Z
vxfeKjUWDunG/utw1JTlElUX9ivhDZETA3MM2a+9WyUOzMr0cTNg/3DYIfK7
ywJ99i+Ap0ZfvLlJh/274IC2i62y27E/DX47+NaGlm3YXwqfPnSuk7Il+4V7
sL9JMRqyrRn7beGifbuVMxuzfx6MSeVTm4bsD4cDXlt+PFwXpum/AhsIp+zM
qNVY8g4+Jwx+7PxT44DWe7H9Ja5OcKjSONkGXmBxOrdtpcbFnvAXhyDtogqN
hTvgCw8DHkxSayxKhUfoKl12lmksK4b/mAR+DFdpLG+5TyU+f+KXx4ePGisG
wurs3s8zP2gs8IBzRpROi36nsUUoHPfxU9PuxRpLL8CXosr02hZoHPkG3iSJ
isl+oXFGsyiVOO/PTx2rfI3VlnDTeX2PblKw3x1ecclm9bsH7A+GdQbW7N6f
y/5kOOdi8OXke+x/Bd8pnKPrls3+xtHYfzgv/xCbyf7+cLvi8VMX3GL/DNjX
o1N1+Q32B8Jr82p+p6ez/ww8MXPicv9r7H8Ol5hFV6ZdZn/DGJy/LpioY5XK
/n4wZqQ9nc6zfxq83U4vpnUS+wPgtXpZicdOs/8kXPWnOuNLIvvz4fC4dmaJ
Cez/C+cKPXeYxbO/734crwYoa3/L2T8Z7nTG/vyYI+zfADss0d4WeID9x2Hr
d0uybaLYnwfvVbxLrN7N/t+w4VKzKc6R7O91APubXV9NNu1kvwSeUdd/waww
9q+Dn/aWX4kLZf9/sG7TiJvTQtj/CP7w97HftUD2/4Lb+p+zcd/E/u4HcX64
YlvsJn/2T4RF38zG7l/L/jXw3dZfnXuvZv8xOKUg94HeSvbnwm+Gy8KSlrG/
Gg648GD46KXsNzqE9fcRn031Yf94OFZ19OfMRexfBW/LyHhyYAH7Y+HtZzMU
bl7svwcHnz8813Qu+yvhRsPlsTGe7O98WCVuEfT57XQP9o+FP8b+0TJ3Z/9y
OCxC1cxpBvsPwVt7Nx47eBr778Amy9pdL3Fhvxr+apf794AT+w2OYP9w4X7V
2Qnsd4DF7V/6Scax3xd2tF/YauJo9u+H/77MUgSMYv9tuOfkRXcrRrK/DA59
5hytHMb+DrEqcbL08OnwIey3g33qbIdvGMR+H/i6TcNG7gPYHwWHfDJ/ZGrJ
/gx4k0fHlWoz9n+GE7UXrysxYb+uHNvv1xZW3r3ZPxIePTXfcUJ39nvDxU9G
pZd2Yf8eeP/+mwabO7E/HRaufN/RrAP7P8EjBl3dFa/D/vZHVeK6Hxv7fhey
fxgslY30CGnN/vmwcnVRfOcW7I+EAwvN93RqzP5rsNkpZ1mAgP0f4KCJUS2d
fm/X9Lc9hvMv6zONA35qLB8CfzLy/La1SmPFXNh/46yCrd80FoTDzcxUOVu+
amxxGb7qPaPwp0pjaQm8pvmwTo4fNY5sFYf57c4LBddLNM4YBBtsVA8tL9RY
LYXPpe2dPLxAY6MwOHrk23UVLzSWXITb3owd1u+ZxgFF8CI9m6J5eRont4hX
iSN/7K+7+Ujj4gGwdtjpbdb3NRbOhjObrKk+la2xaBv8w/9l5ctM9p+H+1wv
SPt4k/0FsN3hwsWJ6exv+h/2b2uHFGRfZb8lvND5S59Dl9jvBivWDpkZlcL+
ILjXzZFOj86xPwleGlg0aV0S+1/+c3tdhekp9jdKwPmsTfw1nePsN4fNrxz4
WX6M/dPhqr1NAzJi2b8FDr9g0mPtIfafhuuqLSY228/+Z/DbH31bddvH/gbH
sb6Xrzu23MV+U/iy9EtZ2Q72T4UrrqXk2oWyfxNcsz5/iUkQ+0/A/VPnTh+2
hf35cJ/dY2+mbGJ/3fF/f5/Xw2nlevb3SVSJRzkvve69lv0u8O+8LZd/LWf/
erjd5uT7ob7sT4A3tfcKbejD/sdwc+OWXW4sYH8tfMY3oLDLPPb3PPHv+uLE
p0FS9jvB6lZmbcbOYr8fvMH16wrHmeyPh6tebpi4fRr7H8KHFwfp/XRh/0/Y
scvTgj4S9nc7ie/HWcuJtxzZPwG28irYFj2W/WvgB2+yaySj2X8Ulpqn3moy
iv33YVVa0P2nI9hfBU+b/CsqaSj7u57C/lttYiofzP5x8Omm+oH6g9i/Enbo
M2D0yQHsPwJ3ftii9pQF++/CyrUq41JT9n+Dd9kOeRzUh/2Gp7E/SVtp+LMH
+8fAk0ZvTbrYjf3L4Cln386xNWL/QXifd8jBMkP2Z8Gbxlx6Md6A/eWw02Nb
/7167Dc4g/nIxOubwrXZbw/rGvdIjBGyfylsVLjpfW5r9sfAq82rnFtqsf8W
/P35ikp5c/Z/gc+NLjWsbsJ+/bOY34X42eg1Yr8YdrDe0NGrAfsXwx9zbtfN
rgvV9O+D93ZcO9q5VuPiG7DPg93+K39pLFTBfo+mRzX8qbFIJwmvTy90Y3CV
xrIR8GmtJrH/VWgsXwg/1D1bbfVVY8VuONLbb0D2Z40F6bDJqSuntik1tvgI
j3DMiZtTqrG0XTK2/46DvxS80zhyKLy2h0h19q3GGV7wY72r5+ILNVZHwJ6j
Mt4nvNbY6Co889Lsw21eaix5D8+PaBHc6LnGAW3O4f2LKtyc+YT9g+H0Sv0r
5x6xfw58y3xoXMtc9u+EWxek23bJYf8luMPkuBeqbPa/hcMeR75Nz2K/1nm8
Xw1T8qxvs98aVl/Lez84g/1S+MXRiCGb0tm/HRYtnFkTeZX9KXCX4Jctvlxi
fyEsD7FJXHOR/c0vqMQNZceSBp1nvxXc78ChhQlJ7J8Fv0pwXb3kDPtD4Dtl
VS8DTrH/HOzSNOmO/kn2v4bH6rulzU1kf5MUzA/CN2d8SWC/BSwJX3YwM579
M+G9EauXjDnG/q3wpOGBq2fJ2X8W7nZYLXtzhP0v4Jl3kwM/HGR/o4s4v3/f
dafufvabwScWpCc9jGK/Kzwn7M0jwV72b4aLd2wonrSL/afgrVpnOmaHs/8p
/LjjD6vDO9gvSMX+eqd/a9Pt7DeBf+7LCp+1jf1T4B3tG5apg9i/Ea708Ugc
tYX9ibDp4tzwnRvZ/wRO6VbeZft69v+BV/l2vfN4Hft7X1KJbR/eTSv2Y78z
bO7gYG60lv3+8Pi3hzdrr2Z/AnxrqrD7k5XsV8D3/My33VvO/hp4qpdt8lcZ
+3tcxutv+3PgHV/2T4IHTWmou3op+9fCw8fs6//Yh/1xcPzrvs+iF7H/wb/H
r98qKVjI/h/wGN9Du6/OZ7/xFZW4e5nR98B57HeEY9JsBn+ew/7V8MI91of+
eLJfDkc2TU/QlbI/Bx7XJHpXl1ns/w6nePToHTaT/V2uYn7TrcEJ7ensHwc3
N/pYd2Qq+1fA2cXOBesms/8wvNP5imu6M/uz4YEJs6uvS9hfATe6tWXhQSf2
d7qG40FThcPzCewfDa8tCvzPZTz7ZfDnuIpv/mPZfwCe3UMpq3NgfyYs6Ogz
zdGe/V/hv4o9Z7+L2d8xTSUuaK9n2U3E/lGwudm9ZxNHsH8JvKtXod3yYeyP
hrO9tjTysGX/TfiZt3dcwWD2f4GTDzg88rZhv146+hq+/jnCmv0i2LJ/S5tp
A9i/CO6VobNAYMn+vXCpy7liU3P2X4dbV0TOTzVlvxJu0sSrtllf9mtf/3f/
sDhfvxf7h8Pty3pqKbuzfwE8r3z/2Xxj9u+Cg748CSnqwv40+HV1yyuNDdlf
Ct94kraopCP7hTdU4vLlvV376rPfFv79Yt8UN132z4NnLPKPeNCe/RHwvcRf
LiFC9l+58e/v3e45vmrN/nfw3ZfFzz202N86QyXOz2zaIaE5+23gZlscm95v
yn5P+NmbrA+9m7B/B7zZpOOPjIbsT4WLjd7tdxSwvxhe3+FTUNe6bZr+ljdx
/PTZ8PBsrcbFA2GPhrqu735pLPSABy0wNU39obEoFNae3unAmSqNZRfgU6ld
x/eo1Fj+Bt43o9T3i1pjRbNbKvGvjXlHDL9qLLCCv7o0bLb7s8YW7nCvVwsf
3PqksTQYrrXWqz5aqnFkMlwes7Z4+nuNM17BNrXyg/tLNFY3vq0S5+j63FpW
rLFRf7jGceFFy0KNJTPgJwcNdvQt0DggEG7hd2lzxEv2n4GHNPiypetz9j+H
+17p9FbnKfsbZqrECz4kF714zP5+cOXgb/I+j9g/DY5LTunU4AH7A+B9k2b3
+5PD/pPwFZ+Wih604Clcu/F37eh77P8Lj5K1slBks79vFvZXq6Q9v95h/2S4
2xXtcHc6YwN803NNtTWtPg43zw41OUQb5cGRTxvIgrg+yW84oSRs+cS77O91
B+fz7Zs8aMbnT5bAz2L/Fv/hePE6ePvU3EG2HBf+B4dtDx5+geOiR/D8nhMa
PeL6Zb/g2/u3zl7AcXn3bJV4Zfb/WrTzcKrTPo7jhxiPPUpjQtEMeqbU0Sot
HLTQdtChGR4dSYqUtNEiosjSYCImSaNSkqVSkxqdKS3CdEKmjY5SckpRyaQ0
z6frM3++Ll2u3pzf/bvv701n/2VaPh/+x74wbDC/nyACTtP1U/+RPw/hr/Au
A60XVTXsr4UbN5Ue169l/3s4+KpH0xx+XWZ+A//foOPlvvx5d7nBcaslHmfk
7N8Az2r45Uo3f1/ig/DeQ7VRCfXsr4bdQ2wKiujSt7CRYcqUZlphVo3zmOFv
TrJG9s+Bk+cNONncxP5weFlEq0fZXfbnwAkXy+bbPWD/Nbj57Yysmfz8ybvg
A90b/K1a2W9yE7//z/s21j9h/0z4vXheqgY/79I1cEdr/Lp6Pg+p2XC/eYjB
Yz4vsiuwao7+3t/5PHV1fvn6vgCv63zezI1rlCJvtWIXYz6PYid4XEJu+Xw+
r9GrYE+rr2Jb+DyXZsJFQzQFZn3sl8HHNQWmsZ/Y/wKOKwgPusj1wtGoFu+n
6O0fPFS4/jnAFulOknQ1rn8r4dfqs3wjNLj+/QwH9r22dNLi+lcJRy3SDEzn
eid8DhuFFleN4XooNazD+rJyt6yZ62XqNHjhfpW2bq6nsuWwjrRzW7Yx179U
+M6gqf9Um3D9uwAfvNPlacH1W/wUHqWto9xtzvVP/088L2kjOlP/Xf+nwN/s
i7J9yPeDIgCOVG8L6+X7Y+AeWL9RPWzUaK7/v8GykBvbD/P9E/YYbtB95/AD
3095OrewH3PsOblwAvsnwXMeXFofzvedwB/+cGhniITvR2ESHGeoUTtiOvvL
v9iqO6XCgf2PYFnr/UebnNivKVeKihtNtqzm+7trPLwgKb6ykO93cz94p0fj
FBPuB8QJsMWHdqubC9h/Cr47zb20n/uJ0ofw3/Ol7re4/1B8dRvPc1Pps+le
7LeFB+UdGVvG/YujD1zSN8d4iQ/7d8KxlRVbrP3YXwKvveb9chz3S/J7cM60
K+nJ3F8J1OqVot2vC5b1BrF/DHxFTTK2mPs16WLYZYClQXwo+3fAqk5bd1/g
flBWBJv4vfj04zr2N8EGOYNn92xgv0qDUuQTPM44nPtP8Sg4V2L43GIL+yVw
prtN+ATub0u3w4L9vcNTY9h/HE4su3RGi/vjgY1w4fJtOtrcPzt+hpd0HitP
5/46bGQjzqfZz4OMuR/P84CPxC361o37dflWWM9q7bmqn9lfAKsLX6XUc78v
vA0bV0+rfsrzgPQjfO6CpMP0APst7+B9nz92SBnPF7KFcPT9OPOpPI90RcLD
FdaJKjy/mB+Gv8t5fsyD5x3xn/DQWNW4imL2/w33B64N/VzG/hFNStHYPMXm
73i+UsyDny4x0p1wnv2bYNPJx1RnXWT/IbjHwbks/xL7a+BVvvqi8Mvs74H/
9LljvY/nQfnwv5SitoxIFbNq9rvBMyUBp4bUsX89/NfykTfz5OzPhW9n2Myd
0Mj+G/DkrJRaKc+vsjdwZbCHa8l99pvexflq6etEE56HzWfDSrPV3y7geVm8
Fm4M2F4nbmP/flgyNHOPpJ39V+FKy0TdNzyPK17D9qm24W9esn/oPZz/Ygq2
DexivwssLbJrzn3L/tXwpCkRSVnv2Z8FR9/8Ofcy5wfyy/DtKTHeLZ/Y3wmX
bPT8Q0/A+cfX95WiGku9nRLOK6QiWDfZzEz4FecfIbBF1vFTrzjvkGXAKx2v
ervpcP5xCa7dGFu0XJ/zDyV855vu9/sNOf8Y/EApWue7KtLViPOPGXBd+8aV
4405/1kBj5wb8NHfhPOfdLjfaveKNcM4//kdDhHmDWu14PynHTazLjH62pLz
H4OH2D/GRzs3cn6UNxV2LK72TR7N+U8gHD647/dRnD8JUuGjGeMjmzmfElbA
f7d1DN4zmf1tcO4q40EV9uzXa8bX/Sbl63IeJrODVxgmJywTsX8pLH8TP+G4
C/tT4JilljUqnLeJz8GOV3MOP+c8LroVFk5UtXBayH7tFuxHHlZGzeA8TzER
rtL+POP6IvZLYTeXOH+dxexPhEdOSnPe5sP+M/AA69BAFT/2t8CbFtiO0fZn
/38e4bwc89/Nzpw/CsbDduWjrU9wPin8H5ydG/NYO4T98XDCre+19Fazvww+
+/FIx40w9j+A9YvGjXm4jv3qCqxPH7bZ+G1ivxBueKY8bbuF/T/CnlGPCp5G
sT8OLl/wNt6J89jSYti5sVqtgPNaxV34hV98S1IC+we0Yj2qaS/pSmK/DVzr
pRH5w0/s94bLP1WebkhnfwwcUTPPzjaT/Se+/Pvx+mopnC8LmuAdZ9ztKjh/
FgoeYz+RYmO3K4/938Nmhye5Psln/yLYUFKoIuZ8WxYFD8vscV1VyP5j8KwM
/7WOJ9nfAOdafd3fw3m5uB+OO78+b81p9ls/wXlhmvGZz2fZ7w5Xr4hIVuV8
XrEFXmMQoqHH+f3Ao7D8mkpWtoz9crirzLd39hX298EOjurvhlxj/3dtSlFv
8x0Hw2r2L4D7zErvJ9SyPxIOS3wsPSBnfz5seHrt3KWN7K+DD5hKR3/6i/29
8M5H8eeHPmC/xVOlqL1P70RqM/vnwvppJevdFezf+MXnBqkGPGF/HryoaubQ
H56x/+bTL+u/xh+XO9j/Dtb2D+yc2sn+Yc+Uorla3vcudbHfFQ7xDLLzesf+
dXDsr9azC3vZfwDeED4vcV0f+6/D94rlxj797O+GI3yGp2/n/ZHAtF0p8o8d
MdiY90vCWfDeGtc5BzV4/xUG78vZ/DBMm/dfv8AT5fbN3Xq8/6qCJeUtW4sM
ef/1Cs4Mz4/rMeL91zfPsV6fD5r6lvdhYmc4a2vEbBtT3n+Fwg32o9ebDef9
1z64OOnQG68RvP/6Az5ztc5royXvv17C5b+2eo4ayfuvIR1K0WPPxS5Zo3j/
5whvnS1wHjSW93/BsN+e2jTRON7/7YWv1BV3ZU1k/yW4zOXIsM28TxR2wBc0
PSKTp7N/kBL75aMrbqSI2D8drprRUW47k/1BsJpqquTFHPanwVqPTnl5/Xv/
eREe0HDzrDbvR8XP4ALDc/ZuvD+NHvgC+xv3ysIoCfvt4R3Knsv1i9m/DH75
1qspg/ezA3+Cn4xcFpwiZf95ODjX/qrpv/e/T+CS8ftrOlewX/clfv+F+W2z
Qtk/GU4cscn5PO+fBUvh+g2KEkPeVwuT4RNlamfnbWb/WTggc6ZKfBT7FbBF
W33q+h3s1+rE560pdEPMLvZPgPPMDra4JrJ/Cdydf8tccw/7d8NVp7tO+KSx
/zTs26v58dsM9jfDQyqyBQ7Z7Nd4hc/jhRA14wPsHwfXR8inex5ivy88sSD4
lucR9u+Cr08sdXjHv0fIK4XdlJ8SY/j3CvL78KFf8gNbStmv/hrP99xUA+9y
9o+FnQ22ahhUJDn8H/Nz7Qk=
      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{3.4397568*^9, 0.0101135830805459},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->
   FrontEndValueCache[{{Automatic, Automatic}, {Charting`FindScaledTicks[
       (Charting`getDateTicks[Automatic, {Automatic}, 
        Map[DateList, {
          SlotSequence[1]}], 
        Scaled[0.02]]& )[
        SlotSequence[1]], {Identity, Identity}]& , Charting`ScaledFrameTicks[
       (ReplaceAll[
        Charting`getDateTicks[Automatic, {Automatic}, 
         Map[DateList, {
           SlotSequence[1]}], 
         Scaled[0.02]], Blank[String] :> Spacer[{0, 0}]]& )[
        SlotSequence[1]], {Identity, Identity}]& }}, {{
     Automatic, Automatic}, {{{3.4397568*^9, 
        FormBox["\"2009\"", TraditionalForm], {0.01, 0.}}, {3.4712928*^9, 
        FormBox["\"2010\"", TraditionalForm], {0.01, 0.}}, {3.5028288*^9, 
        FormBox["\"2011\"", TraditionalForm], {0.01, 0.}}, {3.5343648*^9, 
        FormBox["\"2012\"", TraditionalForm], {0.01, 0.}}, {3.5659872*^9, 
        FormBox["\"2013\"", TraditionalForm], {0.01, 0.}}, {3.5975232*^9, 
        FormBox["\"2014\"", TraditionalForm], {0.01, 0.}}, {3.4397568*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4475328*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4553952*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.463344*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4712928*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4790688*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4869312*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.49488*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5028288*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5106048*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5184672*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.526416*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5343648*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5422272*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5500896*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5580384*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5659872*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5737632*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5816256*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5895744*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5975232*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.6052992*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.6131616*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.6211104*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}}, {{3.4397568*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}}, {3.4712928*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}}, {3.5028288*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}}, {3.5343648*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}}, {3.5659872*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}}, {3.5975232*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}}, {3.4397568*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4475328*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4553952*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.463344*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4712928*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4790688*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4869312*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.49488*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5028288*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5106048*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5184672*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.526416*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5343648*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5422272*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5500896*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5580384*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5659872*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5737632*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5816256*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5895744*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5975232*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.6052992*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.6131616*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.6211104*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}}}}],
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->{{3.4397568*^9, 3.6150624*^9}, {0.010560628496798867`, 
   0.01950153682185823}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{None, Automatic}]], "Output",
 CellChangeTimes->{{3.6551933947999926`*^9, 3.6551934171425576`*^9}, 
   3.655247550086131*^9, 3.6552531722989144`*^9, {3.655264939138795*^9, 
   3.6552649593839254`*^9}, 3.655268676817353*^9, 3.6552946491392403`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"%", ",", 
   RowBox[{"ImageSize", "\[Rule]", "Full"}]}], "]"}]], "Input",
 CellChangeTimes->{3.655253095251195*^9},
 NumberMarks->False],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJws3XlYzG0bBuBRkV1ooaQo0kJR1oqmIhSliMqSFhJaLCmJIqTQUESURGWJ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      "]]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw023lYTG8DxvGxL1mGNhLKrpSKRLaZlC00ZQlFE0JEY5cskUqislXWhvol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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{3.4397568*^9, 0.0101135830805459},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->
   FrontEndValueCache[{{Automatic, Automatic}, {Charting`FindScaledTicks[
       (Charting`getDateTicks[Automatic, {Automatic}, 
        Map[DateList, {
          SlotSequence[1]}], 
        Scaled[0.02]]& )[
        SlotSequence[1]], {Identity, Identity}]& , Charting`ScaledFrameTicks[
       (ReplaceAll[
        Charting`getDateTicks[Automatic, {Automatic}, 
         Map[DateList, {
           SlotSequence[1]}], 
         Scaled[0.02]], Blank[String] :> Spacer[{0, 0}]]& )[
        SlotSequence[1]], {Identity, Identity}]& }}, {{
     Automatic, Automatic}, {{{3.4397568*^9, 
        FormBox["\"2009\"", TraditionalForm], {0.01, 0.}}, {3.4712928*^9, 
        FormBox["\"2010\"", TraditionalForm], {0.01, 0.}}, {3.5028288*^9, 
        FormBox["\"2011\"", TraditionalForm], {0.01, 0.}}, {3.5343648*^9, 
        FormBox["\"2012\"", TraditionalForm], {0.01, 0.}}, {3.5659872*^9, 
        FormBox["\"2013\"", TraditionalForm], {0.01, 0.}}, {3.5975232*^9, 
        FormBox["\"2014\"", TraditionalForm], {0.01, 0.}}, {3.4397568*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4475328*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4553952*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.463344*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4712928*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4790688*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4869312*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.49488*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5028288*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5106048*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5184672*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.526416*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5343648*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5422272*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5500896*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5580384*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5659872*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5737632*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5816256*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5895744*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5975232*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.6052992*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.6131616*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.6211104*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}}, {{3.4397568*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}}, {3.4712928*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}}, {3.5028288*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}}, {3.5343648*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}}, {3.5659872*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}}, {3.5975232*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}}, {3.4397568*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4475328*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4553952*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.463344*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4712928*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4790688*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4869312*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.49488*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5028288*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5106048*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5184672*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.526416*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5343648*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5422272*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5500896*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5580384*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5659872*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5737632*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5816256*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5895744*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5975232*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.6052992*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.6131616*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.6211104*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}}}}],
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->Full,
  Method->{},
  PlotRange->{{3.4397568*^9, 3.6150624*^9}, {0.010560628496798867`, 
   0.01950153682185823}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{None, Automatic}]], "Output",
 CellChangeTimes->{3.6552505067263412`*^9, 3.65525317252096*^9, 
  3.6552649690759044`*^9, 
  3.6552686788847747`*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"diffA", "=", 
  RowBox[{"TimeSeriesThread", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"First", "[", "#", "]"}], "-", 
      RowBox[{"Last", "[", "#", "]"}]}], "&"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"TimeSeriesWindow", "[", 
       RowBox[{"tsA", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2009", ",", "7", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2013", ",", "7", ",", "1"}], "}"}]}], "}"}]}], "]"}], ",", 
      RowBox[{"TimeSeriesWindow", "[", 
       RowBox[{"res5", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2009", ",", "7", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2013", ",", "7", ",", "1"}], "}"}]}], "}"}]}], "]"}]}], 
     "}"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{"diffA", ",", 
   RowBox[{"{", 
    RowBox[{"2009", ",", "9", ",", "1"}], "}"}], ",", 
   RowBox[{"GridLines", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"mercuryretrogrades", ",", "None"}], "}"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.655194127785535*^9, 3.65519414579321*^9}, {
  3.6551955062477674`*^9, 3.6551955362858953`*^9}, {3.65519623712288*^9, 
  3.655196288907445*^9}, {3.6551972127979364`*^9, 3.655197236101691*^9}, {
  3.655197586747229*^9, 3.655197623409709*^9}, {3.6551976542460003`*^9, 
  3.6551976550121565`*^9}, {3.6551980679844112`*^9, 3.6551981599161663`*^9}, {
  3.6552473859306393`*^9, 3.6552473955476027`*^9}, {3.6552475683818645`*^9, 
  3.655247568686926*^9}, {3.6552479231102357`*^9, 3.655247932433137*^9}, {
  3.6552490644230843`*^9, 3.655249078535964*^9}, {3.6552492742648964`*^9, 
  3.6552492954852266`*^9}, {3.655291178716337*^9, 3.6552911905697565`*^9}, {
  3.6552912378844104`*^9, 3.6552912475133743`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["TimeSeries",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False}, 
    PanelBox[
     PaneSelectorBox[{False->GridBox[{
        {
         PaneBox[
          ButtonBox[
           
           DynamicBox[FEPrivate`FrontEndResource[
            "FEBitmaps", "SquarePlusIconMedium"],
            ImageSizeCache->{18., {0., 18.}}],
           Appearance->None,
           ButtonFunction:>(Typeset`open$$ = True),
           Evaluator->Automatic,
           Method->"Preemptive"],
          Alignment->{Center, Center},
          
          ImageSize->
           Dynamic[{
            Automatic, 3.5 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification]}]], 
         GraphicsBox[{{}, {}, 
           {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
            Opacity[1.], LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAAxXZEsKS+6UGZcK60a5BfP3z3WXaR
wulBj2Pqk9K0NT8c2JDA0sbpQXrcrVjIilO/eZRR28vK6UEka0AROxv4vqJY
eQKxzulBVEO0bYQjRD+0fMKt6tLpQToP44De4lc/g3yVKdzW6UGvWHAdmeYr
vzrciSki2+lBEdOtKWs3Mr+9Q+U1VN/pQRJvI16SPD2//YbKEj7j6UGMd//b
MhNevyYq0XN85+lBWbghm5DUVT8MqWGlcuvpQQiohRTH1Wc/vi9Z41Tv6UHU
QD6Sm4RKv1kWcqWL8+lBJEPkHqPcLj+x2BQ4evfpQYA3EH9nL1M/8frYTr37
6UFW7AIS1U0kP/0kBHLs/+lBo3tiFPbfRL/GKrll0wPqQYcrhMei3ym/eJCP
3Q4I6kHoBETciQT/vufR7yUCDOpB5O+HitCZOT8/c3HySRDqQSSPd/iCReQ+
Yxxay30U6kGKc4sGsUo4v0ShzHRpGOpBQD6qHx91Tb8NhmCiqRzqQRx6lwEi
CBo/lEZ+oKEg6kG/D/rJk6Ejv+YOA6uFJOpBJWkzgTYUST8hN6k5vijqQbQt
oL+JU1g/GTvZmK4s6kEbW+GNEwg2P/qeKnzzMOpB0vU5I/ulQr+nCuNrJDXq
QbqXRr2mqlO/EVIlLA056kFMNL5CFndPv2P5iHBKPepB3YswR905Ir9zfHaF
P0HqQTwXpJfGsUe/TgfLpiBF6kGSLIQEBvcxvxLyQExWSepB7vr6gh9NKL+T
uEDCQ03qQVpORkH6RFY//d5hvIVR6kEoDI/t0ldEvyThDId/VepBZ5lr52Cu
Or8X6x5eZVnqQcA4iBrbXOY+8lRSuZ9d6kFA7dWJFvARP4uaD+WRYepBlpL+
Kl6IL78MQO6U2GXqQaL2wqtH0kI/We0zUQtq6kE4+wKBy1lcP2N2A971bepB
gvBxYSvrML9WX/TuNHLqQdHkJnf4Oz6/BiRv0Ct26kEbnWhvIVUvP4LwUL4O
eupBRtv01SC6SD/mHFQwRn7qQTiZyahnAQC/CCXhcjWC6kH3UGmUbaRIPxKN
jzl5hupBOHo4un30Fj/o/KQMqYrqQfPL3PMnvEO/e0hEsJCO6kFw3E7RVfAf
P/fzBNjMkupBdhOi30LDMr8we0/QwJbqQVXF6MAktyM/UmK7TAmb6kFU70Sd
GG0iPz9RjtU9n+pBxhiCz939Hj/qG+suKqPqQSqxnLYn1zs/fUZpDGun6kEs
IRBQunMzv85Mcbpjq+pBSOF2Sm0AL787ibufaK/qQXylTyvlija/wD7X+w==

             "]]}},
          AspectRatio->1,
          Axes->{False, False},
          AxesLabel->{None, None},
          AxesOrigin->{3.44*^9, 0},
          DisplayFunction->Identity,
          Frame->{{True, True}, {True, True}},
          FrameLabel->{{None, None}, {None, None}},
          FrameStyle->Directive[
            Opacity[0.5], 
            Thickness[Tiny], 
            RGBColor[0.368417, 0.506779, 0.709798]],
          FrameTicks->{{None, None}, {None, None}},
          GridLines->{None, None},
          GridLinesStyle->Directive[
            GrayLevel[0.5, 0.4]],
          
          ImageSize->
           Dynamic[{
            Automatic, 3.5 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification]}],
          
          Method->{
           "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
            AbsolutePointSize[6], "ScalingFunctions" -> None},
          
          PlotRange->{{3455395200, 3581625600}, {-0.0018356320069794234`, 
            0.0029095543178998574`}},
          PlotRangeClipping->True,
          PlotRangePadding->{{
             Scaled[0.1], 
             Scaled[0.1]}, {
             Scaled[0.1], 
             Scaled[0.1]}},
          Ticks->{Automatic, Automatic}], GridBox[{
           {
            TagBox[
             TemplateBox[{RowBox[{
                 TagBox["\"Time: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"01 Jul 2009\"", "SummaryItem"]}],RowBox[{
                 TagBox["\" to \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"01 Jul 2013\"", "SummaryItem"]}]},
              "RowDefault"],
             "SummaryItem"], "\[SpanFromLeft]"},
           {
            RowBox[{
             TagBox["\<\"Data points: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["1462",
              "SummaryItem"]}], "\[SpanFromLeft]"}
          },
          AutoDelete->False,
          
          BaseStyle->{
           ShowStringCharacters -> False, NumberMarks -> False, 
            PrintPrecision -> 3, ShowSyntaxStyles -> False},
          GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
          GridBoxSpacings->{"Columns" -> {{2}}, "Rows" -> {{Automatic}}}]}
       },
       AutoDelete->False,
       BaselinePosition->{1, 1},
       GridBoxAlignment->{"Rows" -> {{Top}}},
       GridBoxItemSize->{
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], True->GridBox[{
        {
         PaneBox[
          ButtonBox[
           
           DynamicBox[FEPrivate`FrontEndResource[
            "FEBitmaps", "SquareMinusIconMedium"]],
           Appearance->None,
           ButtonFunction:>(Typeset`open$$ = False),
           Evaluator->Automatic,
           Method->"Preemptive"],
          Alignment->{Center, Center},
          
          ImageSize->
           Dynamic[{
            Automatic, 3.5 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification]}]], 
         GraphicsBox[{{}, {}, 
           {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
            Opacity[1.], LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAAxXZEsKS+6UGZcK60a5BfP3z3WXaR
wulBj2Pqk9K0NT8c2JDA0sbpQXrcrVjIilO/eZRR28vK6UEka0AROxv4vqJY
eQKxzulBVEO0bYQjRD+0fMKt6tLpQToP44De4lc/g3yVKdzW6UGvWHAdmeYr
vzrciSki2+lBEdOtKWs3Mr+9Q+U1VN/pQRJvI16SPD2//YbKEj7j6UGMd//b
MhNevyYq0XN85+lBWbghm5DUVT8MqWGlcuvpQQiohRTH1Wc/vi9Z41Tv6UHU
QD6Sm4RKv1kWcqWL8+lBJEPkHqPcLj+x2BQ4evfpQYA3EH9nL1M/8frYTr37
6UFW7AIS1U0kP/0kBHLs/+lBo3tiFPbfRL/GKrll0wPqQYcrhMei3ym/eJCP
3Q4I6kHoBETciQT/vufR7yUCDOpB5O+HitCZOT8/c3HySRDqQSSPd/iCReQ+
Yxxay30U6kGKc4sGsUo4v0ShzHRpGOpBQD6qHx91Tb8NhmCiqRzqQRx6lwEi
CBo/lEZ+oKEg6kG/D/rJk6Ejv+YOA6uFJOpBJWkzgTYUST8hN6k5vijqQbQt
oL+JU1g/GTvZmK4s6kEbW+GNEwg2P/qeKnzzMOpB0vU5I/ulQr+nCuNrJDXq
QbqXRr2mqlO/EVIlLA056kFMNL5CFndPv2P5iHBKPepB3YswR905Ir9zfHaF
P0HqQTwXpJfGsUe/TgfLpiBF6kGSLIQEBvcxvxLyQExWSepB7vr6gh9NKL+T
uEDCQ03qQVpORkH6RFY//d5hvIVR6kEoDI/t0ldEvyThDId/VepBZ5lr52Cu
Or8X6x5eZVnqQcA4iBrbXOY+8lRSuZ9d6kFA7dWJFvARP4uaD+WRYepBlpL+
Kl6IL78MQO6U2GXqQaL2wqtH0kI/We0zUQtq6kE4+wKBy1lcP2N2A971bepB
gvBxYSvrML9WX/TuNHLqQdHkJnf4Oz6/BiRv0Ct26kEbnWhvIVUvP4LwUL4O
eupBRtv01SC6SD/mHFQwRn7qQTiZyahnAQC/CCXhcjWC6kH3UGmUbaRIPxKN
jzl5hupBOHo4un30Fj/o/KQMqYrqQfPL3PMnvEO/e0hEsJCO6kFw3E7RVfAf
P/fzBNjMkupBdhOi30LDMr8we0/QwJbqQVXF6MAktyM/UmK7TAmb6kFU70Sd
GG0iPz9RjtU9n+pBxhiCz939Hj/qG+suKqPqQSqxnLYn1zs/fUZpDGun6kEs
IRBQunMzv85Mcbpjq+pBSOF2Sm0AL787ibufaK/qQXylTyvlija/wD7X+w==

             "]]}},
          AspectRatio->1,
          Axes->{False, False},
          AxesLabel->{None, None},
          AxesOrigin->{3.44*^9, 0},
          DisplayFunction->Identity,
          Frame->{{True, True}, {True, True}},
          FrameLabel->{{None, None}, {None, None}},
          FrameStyle->Directive[
            Opacity[0.5], 
            Thickness[Tiny], 
            RGBColor[0.368417, 0.506779, 0.709798]],
          FrameTicks->{{None, None}, {None, None}},
          GridLines->{None, None},
          GridLinesStyle->Directive[
            GrayLevel[0.5, 0.4]],
          
          ImageSize->
           Dynamic[{
            Automatic, 3.5 CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification]}],
          
          Method->{
           "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
            AbsolutePointSize[6], "ScalingFunctions" -> None},
          
          PlotRange->{{3455395200, 3581625600}, {-0.0018356320069794234`, 
            0.0029095543178998574`}},
          PlotRangeClipping->True,
          PlotRangePadding->{{
             Scaled[0.1], 
             Scaled[0.1]}, {
             Scaled[0.1], 
             Scaled[0.1]}},
          Ticks->{Automatic, Automatic}], GridBox[{
           {
            TagBox[
             TemplateBox[{RowBox[{
                 TagBox["\"Time: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"01 Jul 2009\"", "SummaryItem"]}],RowBox[{
                 TagBox["\" to \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"01 Jul 2013\"", "SummaryItem"]}]},
              "RowDefault"],
             "SummaryItem"], "\[SpanFromLeft]"},
           {
            RowBox[{
             TagBox["\<\"Data points: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["1462",
              "SummaryItem"]}], "\[SpanFromLeft]"},
           {
            RowBox[{
             TagBox["\<\"Regular: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["True",
              "SummaryItem"]}], 
            RowBox[{
             TagBox["\<\"Output dimension: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["1",
              "SummaryItem"]}]},
           {
            RowBox[{
             TagBox["\<\"Metadata: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["None",
              "SummaryItem"]}], 
            RowBox[{
             TagBox["\<\"Minimum increment: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["86400",
              "SummaryItem"]}]},
           {
            TagBox["\<\"\"\>",
             "SummaryItem"], 
            RowBox[{
             TagBox["\<\"Resampling: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["\<\"LinearInterpolation\"\>",
              "SummaryItem"]}]}
          },
          AutoDelete->False,
          
          BaseStyle->{
           ShowStringCharacters -> False, NumberMarks -> False, 
            PrintPrecision -> 3, ShowSyntaxStyles -> False},
          GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
          GridBoxSpacings->{"Columns" -> {{2}}, "Rows" -> {{Automatic}}}]}
       },
       AutoDelete->False,
       BaselinePosition->{1, 1},
       GridBoxAlignment->{"Rows" -> {{Top}}},
       GridBoxItemSize->{
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}]}, Dynamic[
      Typeset`open$$],
      ImageSize->Automatic],
     BaselinePosition->Baseline],
    DynamicModuleValues:>{}], "]"}],
  TemporalData[TimeSeries, {CompressedData["
1:eJwVmmlcjO8Xxp9+Qos0bbSbEpUW077Pedr3TPu0aUqoiJA9eZQlJBMhhEGU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    "], {{3455395200, 3581625600, 86400}}, 1, {"Continuous", 1}, {
    "Discrete", 1}, 1, {
    ValueDimensions -> 1, DateFunction -> Automatic, 
     ResamplingMethod -> {"Interpolation", InterpolationOrder -> 1}, 
     TemporalRegularity -> True}}, True, 10.1],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{
  3.655193427752715*^9, 3.655194133832769*^9, 3.655194166310396*^9, {
   3.6551955166488905`*^9, 3.655195539388529*^9}, {3.6551962726821375`*^9, 
   3.655196314863741*^9}, 3.655197240446577*^9, 3.6551975956630487`*^9, 
   3.65519762655235*^9, {3.6551976569515524`*^9, 3.6551976767485914`*^9}, {
   3.6551980962521777`*^9, 3.655198162151623*^9}, 3.6552475721526327`*^9, 
   3.65524793436053*^9, 3.6552490803533344`*^9, 3.655249297546646*^9, 
   3.6552531728430243`*^9, 3.655265004354101*^9, 3.655268691756401*^9, 
   3.6552911918690214`*^9, 3.6552912485475845`*^9, 3.6552946496033363`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwlnHlcTF8UwB9CJI0W2jDhZ0uZEkL0iiiSob3ERFKRBoUIT1lCZSKE8BBl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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{3.4553952*^9, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->
   FrontEndValueCache[{{Automatic, Automatic}, {Charting`FindScaledTicks[
       (Charting`getDateTicks[Automatic, {Automatic}, 
        Map[DateList, {
          SlotSequence[1]}], 
        Scaled[0.02]]& )[
        SlotSequence[1]], {Identity, Identity}]& , Charting`ScaledFrameTicks[
       (ReplaceAll[
        Charting`getDateTicks[Automatic, {Automatic}, 
         Map[DateList, {
           SlotSequence[1]}], 
         Scaled[0.02]], Blank[String] :> Spacer[{0, 0}]]& )[
        SlotSequence[1]], {Identity, Identity}]& }}, {{
     Automatic, Automatic}, {{{3.4712928*^9, 
        FormBox["\"2010\"", TraditionalForm], {0.01, 0.}}, {3.5028288*^9, 
        FormBox["\"2011\"", TraditionalForm], {0.01, 0.}}, {3.5343648*^9, 
        FormBox["\"2012\"", TraditionalForm], {0.01, 0.}}, {3.5659872*^9, 
        FormBox["\"2013\"", TraditionalForm], {0.01, 0.}}, {3.4553952*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.463344*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4712928*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4790688*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4869312*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.49488*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5028288*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5106048*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5184672*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.526416*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5343648*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5422272*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5500896*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5580384*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5659872*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5737632*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5816256*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}}, {{3.4712928*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}}, {3.5028288*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}}, {3.5343648*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}}, {3.5659872*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}}, {3.4553952*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.463344*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4712928*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4790688*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4869312*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.49488*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5028288*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5106048*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5184672*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.526416*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5343648*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5422272*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5500896*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5580384*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5659872*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5737632*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5816256*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}}}}],
  GridLines->{CompressedData["
1:eJxTTMoPSmVkYGBQZwCDBWWLXjoC6QlvloLphClbwfSDjp1guuDmSYh85Vkw
LfDrNpi+4HofTDvMfAeRT/4Ephs4mF+B5S+xgemGWlEw7XBSAkwrzFMH0wsm
aYPpA4k2YFpAxwFMf2DwB9MJLR1geoNPEIT/PQHCP5gCMX9CKZgOaK0E0wZR
EPUflnZDzA+YBTH/w1yIvqnrIOq6NkHk7x6EmKt5FEw/WHkZTDN4XQfTE2Y9
h7ir/zVE3uw3xN41/145AgC0j28l
    "], None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->{{3.4553952*^9, 3.5816256*^9}, {-0.0032498692601550614`, 
   0.00352352887012722}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{None, Automatic}]], "Output",
 CellChangeTimes->{
  3.655193427752715*^9, 3.655194133832769*^9, 3.655194166310396*^9, {
   3.6551955166488905`*^9, 3.655195539388529*^9}, {3.6551962726821375`*^9, 
   3.655196314863741*^9}, 3.655197240446577*^9, 3.6551975956630487`*^9, 
   3.65519762655235*^9, {3.6551976569515524`*^9, 3.6551976767485914`*^9}, {
   3.6551980962521777`*^9, 3.655198162151623*^9}, 3.6552475721526327`*^9, 
   3.65524793436053*^9, 3.6552490803533344`*^9, 3.655249297546646*^9, 
   3.6552531728430243`*^9, 3.655265004354101*^9, 3.655268691756401*^9, 
   3.6552911918690214`*^9, 3.6552912485475845`*^9, 3.6552946497083564`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"dA", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"diffA", "[", 
      RowBox[{"[", "2", "]"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"Abs", "[", 
    RowBox[{"Fourier", "[", "dA", "]"}], "]"}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6550188819527454`*^9, 3.6550188822608094`*^9}, {
  3.655018981605054*^9, 3.655018988806538*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.006944444444444445], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxdXHd4jNn3D8uKHnVDlLBB9NGD4MMq0aMHwSCRImTSJFInySQz6dNFH2SJ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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->{{0, 1462.}, {0, 0.002823420588471141}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.655193439477107*^9, 3.655194176262427*^9, 
  3.655195546855053*^9, 3.655196299748657*^9, 3.6551972537612934`*^9, 
  3.655197686670616*^9, 3.6551981730058365`*^9, 3.6552475839310365`*^9, 
  3.655247941995087*^9, 3.6552490871337185`*^9, 3.6552493058333387`*^9, 
  3.6552531731260834`*^9, 3.65526501248676*^9, 3.655268701095306*^9, 
  3.655291204905681*^9, 3.655291255150933*^9, 
  3.655294649844385*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"Abs", "[", 
    RowBox[{"Fourier", "[", "dA", "]"}], "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ";;", "20"}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.655197119116824*^9, 3.655197152109555*^9}, {
  3.655198214162234*^9, 3.6551982353965654`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.019444444444444445`],
      AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQEf7OXnLDaYJxdqDxVw6Hqxrm+WZiKUz+GgfdOL
eccbmLyAw57lD+6syo6C8kUcPC/bSBukhkP5Eg4fTCeIHuyKhfJlHKZ2tlrO
3R8A5Ss4fO29pMsmqQjlKzks4nySpKKYDuWrOIjuCduUoh4H5as5zOKZPmmx
B8w9Gg6brJ6bxMm5QPlaDh1dHIu67FKhfB2HXeGX/m619Yfy9RyKhCNrprLa
QvkGDn+1V7GrshlC+YYOf1zZOp1kYe43cpC49VLV/q8BlG/skOaq4tcoBXO/
iYN25xXd1bt87QFcBkuk
      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->{{0., 20.}, {0, 0.002823420588471141}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.655197125788185*^9, 3.6551971534768343`*^9}, 
   3.655197261213814*^9, 3.6551976951953545`*^9, 3.655198178634987*^9, {
   3.6551982215777464`*^9, 3.655198237055905*^9}, 3.6552475891911106`*^9, 
   3.6552479469250937`*^9, 3.655248669575529*^9, 3.6552490930659275`*^9, 
   3.6552493116475224`*^9, 3.6552531731730933`*^9, 3.655265020307359*^9, 
   3.655268707650644*^9, 3.6552912101137457`*^9, 3.655291260067935*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{3.6552472671033974`*^9}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.655018973608406*^9, 3.655019055026183*^9}, {
   3.655019099502348*^9, 3.6550191119979224`*^9}, {3.655194245939642*^9, 
   3.6551942949556417`*^9}, 3.655194349131694*^9, {3.6551943994099517`*^9, 
   3.6551944901904726`*^9}, 3.6551945335033092`*^9, {3.655194619030759*^9, 
   3.655194647349536*^9}, 3.655194722351838*^9, 3.6551955618301077`*^9, 
   3.6552472797949886`*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"data", "=", "dA"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"f", "=", 
     RowBox[{"Abs", "[", 
      RowBox[{"Fourier", "[", "data", "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"n", "=", 
     RowBox[{"Length", "[", "data", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "findPeriod", "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"findPeriod", "[", 
     RowBox[{"data_", ",", "threshold_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"fs", ",", "s1", ",", 
        RowBox[{"s", "=", 
         RowBox[{"{", "}"}]}], ",", "i", ",", "a0f", ",", "af", ",", "pf", 
        ",", "pos", ",", "fr", ",", "frpos", ",", "fdata", ",", "fdatac", ",",
         "n", ",", "per"}], "}"}], ",", 
      RowBox[{
       RowBox[{"n", "=", 
        RowBox[{"Length", "[", "data", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"fs", "=", 
        RowBox[{"Fourier", "[", "data", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"s1", "=", 
        RowBox[{"Drop", "[", 
         RowBox[{"fs", ",", 
          RowBox[{"-", 
           RowBox[{"Floor", "[", 
            RowBox[{
             RowBox[{"Length", "[", "fs", "]"}], "/", "2"}], "]"}]}]}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "1"}], ",", 
         RowBox[{"i", "<", 
          RowBox[{"Length", "[", "s1", "]"}]}], ",", 
         RowBox[{"i", "++"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Abs", "[", "fs", "]"}], "[", 
             RowBox[{"[", 
              RowBox[{"i", "+", "1"}], "]"}], "]"}], ">", "threshold"}], ",", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"s", ",", 
             RowBox[{"i", "+", "1"}]}], "]"}]}], "]"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"a0f", "=", 
        RowBox[{
         RowBox[{"Abs", "[", 
          RowBox[{"fs", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "]"}], "/", 
         RowBox[{"Sqrt", "[", "n", "]"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"af", "=", 
        RowBox[{
         RowBox[{"2", "/", 
          RowBox[{"Sqrt", "[", "n", "]"}]}], " ", 
         RowBox[{
          RowBox[{"Abs", "[", "fs", "]"}], "[", 
          RowBox[{"[", "s", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"pf", "=", 
        RowBox[{
         RowBox[{"Arg", "[", "fs", "]"}], "[", 
         RowBox[{"[", "s", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"a0f", ",", 
         RowBox[{"Transpose", "[", 
          RowBox[{"{", 
           RowBox[{"s", ",", "af", ",", "pf"}], "}"}], "]"}]}], "}"}]}]}], 
     "]"}]}], "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"Clear", "[", "reconstruct", "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"reconstruct", "[", 
     RowBox[{"data_", ",", "fp_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "n", "}"}], ",", 
      RowBox[{
       RowBox[{"n", "=", 
        RowBox[{"Length", "[", "data", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"ListLinePlot", "[", 
          RowBox[{"data", ",", 
           RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}], ",", 
         RowBox[{"Plot", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"fp", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "+", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"fp", "[", 
                RowBox[{"[", 
                 RowBox[{"2", ",", "j", ",", "2"}], "]"}], "]"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"2", " ", "Pi", " ", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"fp", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "j", ",", "1"}], "]"}], "]"}], "-", 
                    "1"}], ")"}], "/", "n"}], " ", "t"}], "-", 
                 RowBox[{"fp", "[", 
                  RowBox[{"[", 
                   RowBox[{"2", ",", "j", ",", "3"}], "]"}], "]"}]}], "]"}]}],
               ",", 
              RowBox[{"{", 
               RowBox[{"j", ",", "1", ",", 
                RowBox[{"Length", "[", 
                 RowBox[{"fp", "[", 
                  RowBox[{"[", "2", "]"}], "]"}], "]"}]}], "}"}]}], "]"}]}], 
           ",", 
           RowBox[{"{", 
            RowBox[{"t", ",", "0", ",", "n"}], "}"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], "]"}]}]}], 
     "]"}]}]}]}]], "Input",
 CellChangeTimes->{
  3.655019299736609*^9, {3.655197314428671*^9, 3.6551973762242785`*^9}, {
   3.655247711710105*^9, 3.655247719397674*^9}, 3.6552479590305643`*^9, 
   3.6552531468877287`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{
   RowBox[{"Sort", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"findPeriod", "[", 
       RowBox[{"data", ",", "0.002"}], "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"#1", "[", 
        RowBox[{"[", "2", "]"}], "]"}], ">", 
       RowBox[{"#2", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<Freq\>\"", ",", "\"\<Amp\>\"", ",", "\"\<Phase\>\""}], 
       "}"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.654980213709733*^9, 3.655193492360897*^9, 3.655249232025279*^9, {
   3.6552493418206787`*^9, 3.6552493497272916`*^9}}],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Freq\"\>",
       HoldForm], 
      TagBox["\<\"Amp\"\>",
       HoldForm], 
      TagBox["\<\"Phase\"\>",
       HoldForm]},
     {"9", "0.00014768346951039754`", 
      RowBox[{"-", "2.903383954382567`"}]},
     {"13", "0.0001356465804712962`", "1.0587255021189352`"},
     {"619", "0.00012538125009275479`", 
      RowBox[{"-", "0.026676878517286572`"}]},
     {"166", "0.00011928072397456392`", "0.1434030475039355`"},
     {"210", "0.00011885980910365538`", "3.0755773256009795`"},
     {"167", "0.00011628364511753227`", "1.2424223061333741`"},
     {"730", "0.00011275179499326426`", 
      RowBox[{"-", "0.3973123003114611`"}]},
     {"11", "0.00011035810617303823`", "0.4046672843264969`"},
     {"299", "0.00011030041668379497`", "2.323495125067856`"},
     {"2", "0.00010958403450713857`", 
      RowBox[{"-", "1.0322002635029206`"}]},
     {"229", "0.00010800953452225169`", "2.36252210160025`"},
     {"514", "0.00010745845654030037`", "0.951114679221524`"},
     {"161", "0.00010646470365429504`", 
      RowBox[{"-", "1.3414902178880845`"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, TableHeadings -> {None, {"Freq", "Amp", "Phase"}}]]]], "Output",
 CellChangeTimes->{{3.655193468566043*^9, 3.6551934936231537`*^9}, 
   3.655194201874651*^9, 3.655195576316065*^9, 3.655196330702976*^9, 
   3.6551972849226513`*^9, 3.655197383189701*^9, 3.6551982541784*^9, 
   3.6552475988850875`*^9, 3.655247728849603*^9, 3.6552479636735725`*^9, 
   3.655248678705392*^9, 3.6552491086771145`*^9, 3.655249232518379*^9, {
   3.655249328149889*^9, 3.655249350297408*^9}, 3.65525317326311*^9, 
   3.6552650312315845`*^9, 3.6552687160053487`*^9, 3.65529121744724*^9, 
   3.655291266116173*^9, 3.655294650046426*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Mean", "[", "data", "]"}]], "Input",
 CellChangeTimes->{
  3.6552484882175283`*^9, {3.6552487882257347`*^9, 3.6552487914013824`*^9}}],

Cell[BoxData["0.00003371258771144481`"], "Output",
 CellChangeTimes->{3.6552484888966656`*^9, 3.655248791914487*^9, 
  3.655249112171826*^9, 3.6552493559745674`*^9, 3.6552531734041395`*^9, 
  3.6552912706200886`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"n", "/", "13"}], "]"}]], "Input",
 CellChangeTimes->{{3.655249124206281*^9, 3.65524913713792*^9}, {
  3.655249361362666*^9, 3.655249362371872*^9}}],

Cell[BoxData["112.46153846153847`"], "Output",
 CellChangeTimes->{{3.6552491265097513`*^9, 3.655249137693035*^9}, {
   3.655249358310066*^9, 3.6552493629649935`*^9}, 3.6552531734771547`*^9, 
   3.655291272267424*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pos1", "=", "9"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"pos2", "=", "13"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"per1", " ", "=", " ", 
   RowBox[{"N", "[", 
    RowBox[{"n", "/", 
     RowBox[{"(", 
      RowBox[{"pos1", "-", "2", "+", 
       RowBox[{"2", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"n", "-", "pos1", "-", "1"}], ")"}], "/", "n"}], ")"}]}]}],
       ")"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"per2", " ", "=", " ", 
   RowBox[{"N", "[", 
    RowBox[{"n", "/", 
     RowBox[{"(", 
      RowBox[{"pos2", "-", "2", "+", 
       RowBox[{"2", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"n", "-", "pos2", "-", "1"}], ")"}], "/", "n"}], ")"}]}]}],
       ")"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pdata", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"N", "[", 
      RowBox[{
       RowBox[{"Mean", "[", "data", "]"}], " ", "+", 
       RowBox[{"0.00014768346951039754`", "*", 
        RowBox[{"Sin", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"2", " ", 
            RowBox[{"\[Pi]", " ", "/", "per1"}]}], ")"}], 
          RowBox[{"(", 
           RowBox[{"x", " ", "+", 
            RowBox[{"2.903383954382567`", "*", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"per1", "/", "2"}], " ", "\[Pi]"}], " ", ")"}]}]}], 
           ")"}]}], "]"}]}], "+", 
       RowBox[{"0.0001356465804712962`", "*", 
        RowBox[{"Sin", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"2", " ", 
            RowBox[{"\[Pi]", " ", "/", "per2"}]}], ")"}], 
          RowBox[{"(", 
           RowBox[{"x", " ", "-", 
            RowBox[{"1.0587255021189352`", "*", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"per2", "/", "2"}], " ", "\[Pi]"}], " ", ")"}]}]}], 
           ")"}]}], "]"}]}]}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", " ", "n"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{"pdata", ",", 
   RowBox[{"{", 
    RowBox[{"2009", ",", "7", ",", "1"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.0005"}], ",", "0.0005"}], "}"}]}], ",", 
   RowBox[{"GridLines", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"mercuryretrogrades", ",", "None"}], "}"}]}]}], 
  RowBox[{"(*", 
   RowBox[{",", 
    RowBox[{"Filling", "\[Rule]", "Axis"}]}], "*)"}], "]"}]}], "Input",
 CellChangeTimes->{{3.655193682777746*^9, 3.655193700710404*^9}, {
   3.655193735110422*^9, 3.655193781920973*^9}, {3.655193813567429*^9, 
   3.655193822317215*^9}, {3.6551939106122284`*^9, 3.6551939403582973`*^9}, {
   3.655194773510276*^9, 3.655194836153055*^9}, 3.6551948789017773`*^9, {
   3.655194958968112*^9, 3.6551949926509843`*^9}, 3.655195038902421*^9, 
   3.6551951210751853`*^9, 3.6551951550061073`*^9, {3.655195191910638*^9, 
   3.655195430059224*^9}, {3.655195629684951*^9, 3.655195632873602*^9}, {
   3.6551956755893164`*^9, 3.6551956802742724`*^9}, {3.6551957486222167`*^9, 
   3.655195769899558*^9}, {3.6551958025262136`*^9, 3.6551958722424374`*^9}, {
   3.6551963866043777`*^9, 3.6551964095240536`*^9}, {3.655196452224765*^9, 
   3.655196454663263*^9}, {3.6551965271920605`*^9, 3.655196591427164*^9}, 
   3.655196621634328*^9, {3.655196667905768*^9, 3.655196752602048*^9}, 
   3.6551968259920197`*^9, 3.6551969117005067`*^9, {3.655197422336686*^9, 
   3.6551975288444157`*^9}, {3.655198291467005*^9, 3.6551985427452707`*^9}, {
   3.655198572770396*^9, 3.655198588247555*^9}, 3.655198619229875*^9, {
   3.655198677892844*^9, 3.655198757359056*^9}, {3.6551987878082685`*^9, 
   3.6551988500449667`*^9}, {3.6551989009453506`*^9, 3.655198920219283*^9}, {
   3.655198952229814*^9, 3.655198966119647*^9}, {3.65519906460174*^9, 
   3.6551990809770803`*^9}, {3.6551991366024303`*^9, 3.655199160359276*^9}, {
   3.655199241943921*^9, 3.655199268520343*^9}, {3.6552476092462006`*^9, 
   3.6552476821990843`*^9}, {3.6552477613852406`*^9, 
   3.6552477707221456`*^9}, {3.655247811987564*^9, 3.6552478167325325`*^9}, {
   3.655247986527173*^9, 3.655248312235624*^9}, {3.6552483954085927`*^9, 
   3.655248442912284*^9}, {3.6552485037346935`*^9, 3.6552485062131987`*^9}, {
   3.6552485861935177`*^9, 3.655248643070121*^9}, {3.655248692031109*^9, 
   3.6552486953387856`*^9}, 3.6552487346428027`*^9, {3.655248912027993*^9, 
   3.655249023364708*^9}, {3.655249152709097*^9, 3.655249216846182*^9}, {
   3.6552493680150228`*^9, 3.655249607200822*^9}, {3.655249646805901*^9, 
   3.6552496874091854`*^9}, {3.6552497230154495`*^9, 
   3.6552497619673977`*^9}, {3.655249803940961*^9, 3.655249849457247*^9}, {
   3.655250058706937*^9, 3.655250111581725*^9}, {3.655250195005745*^9, 
   3.6552502345228066`*^9}, 3.655250275311128*^9, 3.6552503958997316`*^9, {
   3.655250661658951*^9, 3.6552506670140433`*^9}, {3.6552507231845045`*^9, 
   3.655250773272722*^9}, {3.6552643332859707`*^9, 3.6552643384570265`*^9}, {
   3.6552650758576884`*^9, 3.655265152872402*^9}, {3.6552652083187127`*^9, 
   3.655265301085639*^9}, {3.6552653314798417`*^9, 3.655265378404415*^9}, {
   3.6552654098978405`*^9, 3.6552654894940796`*^9}, 3.655265543989196*^9, {
   3.6552655844944615`*^9, 3.6552657556893883`*^9}, {3.655265787429865*^9, 
   3.655265884738717*^9}, 3.655265928138571*^9, {3.655266214747045*^9, 
   3.655266229349024*^9}, {3.6552664017401953`*^9, 3.6552664335546856`*^9}, {
   3.6552664916825447`*^9, 3.6552665352394314`*^9}, {3.6552666095505915`*^9, 
   3.6552666844288673`*^9}, {3.655266789571319*^9, 3.655266807226921*^9}, {
   3.65526686314133*^9, 3.6552669187616763`*^9}, {3.6552670466517677`*^9, 
   3.6552670907077575`*^9}, {3.6552671268461304`*^9, 3.655267150264908*^9}, {
   3.655267182359456*^9, 3.6552672455803547`*^9}, {3.6552676694878387`*^9, 
   3.65526768763054*^9}, 3.6552683568450727`*^9, {3.6552683884635243`*^9, 
   3.6552684051839347`*^9}, {3.6552684632517824`*^9, 3.655268483869988*^9}, {
   3.6552687221265974`*^9, 3.65526884776423*^9}, {3.6552689587448716`*^9, 
   3.6552689864165177`*^9}, {3.65526902381815*^9, 3.6552690358876114`*^9}, {
   3.6552690916049786`*^9, 3.655269114091566*^9}, {3.655286318730809*^9, 
   3.6552866248022523`*^9}, {3.655286667104884*^9, 3.655286668008068*^9}, {
   3.6552941501904473`*^9, 3.655294296384272*^9}, {3.655294327267574*^9, 
   3.655294330281188*^9}, {3.655294371377572*^9, 3.655294383561059*^9}, {
   3.655294619745244*^9, 3.6552946238910894`*^9}, {3.655294711296923*^9, 
   3.655294759755809*^9}, {3.6552948612415147`*^9, 3.655294886030571*^9}, {
   3.655295370406393*^9, 3.6552953955695276`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt3Htcy98fB/CV0kWYyvVbmhRJl5XcUtmSJKqVe6ghuWeUS0kWuVUyd3Ib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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{3.4534228500000005`*^9, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->
   FrontEndValueCache[{{Automatic, Automatic}, {Charting`FindScaledTicks[
       (Charting`getDateTicks[Automatic, {Automatic}, 
        Map[DateList, {
          SlotSequence[1]}], 0]& )[
        SlotSequence[1]], {Identity, Identity}]& , Charting`ScaledFrameTicks[
       (ReplaceAll[
        Charting`getDateTicks[Automatic, {Automatic}, 
         Map[DateList, {
           SlotSequence[1]}], 0], Blank[String] :> Spacer[{0, 0}]]& )[
        SlotSequence[1]], {Identity, Identity}]& }}, {{
     Automatic, Automatic}, {{{3.4712928*^9, 
        FormBox["\"2010\"", TraditionalForm], {0.01, 0.}}, {3.5028288*^9, 
        FormBox["\"2011\"", TraditionalForm], {0.01, 0.}}, {3.5343648*^9, 
        FormBox["\"2012\"", TraditionalForm], {0.01, 0.}}, {3.5659872*^9, 
        FormBox["\"2013\"", TraditionalForm], {0.01, 0.}}, {3.4553952*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.463344*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4712928*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4790688*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4869312*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.49488*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5028288*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5106048*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5184672*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.526416*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5343648*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5422272*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5500896*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5580384*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5659872*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5737632*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5816256*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}}, {{3.4712928*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}}, {3.5028288*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}}, {3.5343648*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}}, {3.5659872*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}}, {3.4553952*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.463344*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4712928*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4790688*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4869312*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.49488*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5028288*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5106048*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5184672*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.526416*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5343648*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5422272*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5500896*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5580384*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5659872*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5737632*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5816256*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}}}}],
  GridLines->{CompressedData["
1:eJxTTMoPSmVkYGBQZwCDBWWLXjoC6QlvloLphClbwfSDjp1guuDmSYh85Vkw
LfDrNpi+4HofTDvMfAeRT/4Ephs4mF+B5S+xgemGWlEw7XBSAkwrzFMH0wsm
aYPpA4k2YFpAxwFMf2DwB9MJLR1geoNPEIT/PQHCP5gCMX9CKZgOaK0E0wZR
EPUflnZDzA+YBTH/w1yIvqnrIOq6NkHk7x6EmKt5FEw/WHkZTDN4XQfTE2Y9
h7ir/zVE3uw3xN41/145AgC0j28l
    "], None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->{{3.4553952*^9, 3.5816256*^9}, {-0.0005, 0.0005}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{None, Automatic}]], "Output",
 CellChangeTimes->{
  3.655266685394064*^9, 3.6552668082251244`*^9, {3.6552668662759676`*^9, 
   3.6552668927713747`*^9}, 3.655266928088579*^9, 3.6552670925081253`*^9, {
   3.6552671326073046`*^9, 3.655267150775011*^9}, {3.6552671833276606`*^9, 
   3.6552672462754946`*^9}, 3.655267691384307*^9, {3.6552683693606267`*^9, 
   3.655268407730454*^9}, {3.6552684703102217`*^9, 3.6552684850892487`*^9}, {
   3.6552688392544937`*^9, 3.655268855025711*^9}, {3.6552689646801057`*^9, 
   3.65526898716267*^9}, {3.6552690248473587`*^9, 3.655269036581769*^9}, {
   3.655269092632188*^9, 3.6552691148057117`*^9}, {3.655286326133319*^9, 
   3.65528637089545*^9}, {3.6552864039451933`*^9, 3.655286625699435*^9}, 
   3.655286668847238*^9, 3.6552912742798347`*^9, 3.6552946502464676`*^9, {
   3.655294716511986*^9, 3.6552947605659857`*^9}, 3.6552948876989126`*^9, 
   3.6552954048824263`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"%", ",", 
   RowBox[{"ImageSize", "\[Rule]", "Full"}]}], "]"}]], "Input",
 CellChangeTimes->{3.655250788769884*^9},
 NumberMarks->False],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt3Htcy98fB/CV0kWYyvVbmhRJl5XcUtmSJKqVe6ghuWeUS0kWuVUyd3Ib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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{3.4534228500000005`*^9, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->
   FrontEndValueCache[{{Automatic, Automatic}, {Charting`FindScaledTicks[
       (Charting`getDateTicks[Automatic, {Automatic}, 
        Map[DateList, {
          SlotSequence[1]}], 0]& )[
        SlotSequence[1]], {Identity, Identity}]& , Charting`ScaledFrameTicks[
       (ReplaceAll[
        Charting`getDateTicks[Automatic, {Automatic}, 
         Map[DateList, {
           SlotSequence[1]}], 0], Blank[String] :> Spacer[{0, 0}]]& )[
        SlotSequence[1]], {Identity, Identity}]& }}, {{
     Automatic, Automatic}, {{{3.4712928*^9, 
        FormBox["\"2010\"", TraditionalForm], {0.01, 0.}}, {3.5028288*^9, 
        FormBox["\"2011\"", TraditionalForm], {0.01, 0.}}, {3.5343648*^9, 
        FormBox["\"2012\"", TraditionalForm], {0.01, 0.}}, {3.5659872*^9, 
        FormBox["\"2013\"", TraditionalForm], {0.01, 0.}}, {3.4553952*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.463344*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4712928*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4790688*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4869312*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.49488*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5028288*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5106048*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5184672*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.526416*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5343648*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5422272*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5500896*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5580384*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5659872*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5737632*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5816256*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}}, {{3.4712928*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}}, {3.5028288*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}}, {3.5343648*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}}, {3.5659872*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.01, 0.}}, {3.4553952*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.463344*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4712928*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4790688*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.4869312*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.49488*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5028288*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5106048*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5184672*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.526416*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5343648*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5422272*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5500896*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5580384*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5659872*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5737632*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}, {3.5816256*^9, 
        FormBox[
         InterpretationBox[
          StyleBox[
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}}}}}],
  GridLines->{CompressedData["
1:eJxTTMoPSmVkYGBQZwCDBWWLXjoC6QlvloLphClbwfSDjp1guuDmSYh85Vkw
LfDrNpi+4HofTDvMfAeRT/4Ephs4mF+B5S+xgemGWlEw7XBSAkwrzFMH0wsm
aYPpA4k2YFpAxwFMf2DwB9MJLR1geoNPEIT/PQHCP5gCMX9CKZgOaK0E0wZR
EPUflnZDzA+YBTH/w1yIvqnrIOq6NkHk7x6EmKt5FEw/WHkZTDN4XQfTE2Y9
h7ir/zVE3uw3xN41/145AgC0j28l
    "], None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->Full,
  Method->{},
  PlotRange->{{3.4553952*^9, 3.5816256*^9}, {-0.0005, 0.0005}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{None, Automatic}]], "Output",
 CellChangeTimes->{
  3.6552504246676025`*^9, 3.6552507892469807`*^9, 3.6552668442254686`*^9, 
   3.6552669332106233`*^9, 3.655267255716422*^9, 3.6552684433577237`*^9, 
   3.655268490260292*^9, 3.655268884845794*^9, 3.6552689932279224`*^9, {
   3.6552690998096523`*^9, 3.6552691188945446`*^9}, 3.655286646268634*^9, 
   3.65528668953146*^9, 3.6552946933062515`*^9, 3.6552947695718117`*^9, 
   3.655294906204687*^9, 3.6552954139112687`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Max", "[", "pdata", "]"}], "/", 
  RowBox[{"Mean", "[", "tsA", "]"}]}]], "Input",
 CellChangeTimes->{{3.6552677618006735`*^9, 3.655267816504833*^9}, {
  3.6552678632603726`*^9, 3.655267924469861*^9}, {3.6552679740159693`*^9, 
  3.655267992558752*^9}, {3.655268042132866*^9, 3.65526804411627*^9}, {
  3.6552681186774826`*^9, 3.6552681269801755`*^9}}],

Cell[BoxData["0.02191660991331903`"], "Output",
 CellChangeTimes->{
  3.6552677801224127`*^9, 3.6552678651397557`*^9, 3.6552679264792705`*^9, {
   3.6552679801612225`*^9, 3.6552679935839596`*^9}, 3.655268044957441*^9, {
   3.655268120121776*^9, 3.655268128555497*^9}, 3.655268905561022*^9, 
   3.655269062141966*^9, 3.65526917048307*^9, 3.655286873667025*^9, 
   3.655294931880926*^9, 3.6553097339696517`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{2544, 1357},
WindowMargins->{{-8, Automatic}, {Automatic, 0}},
Magnification:>1.5 Inherited,
FrontEndVersion->"10.3 for Microsoft Windows (64-bit) (October 9, 2015)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 958, 16, 152, "Text"],
Cell[1519, 38, 125, 1, 79, "Text"],
Cell[1647, 41, 197, 4, 45, "Input"],
Cell[CellGroupData[{
Cell[1869, 49, 156, 2, 95, "Chapter"],
Cell[2028, 53, 162, 3, 45, "Text"],
Cell[2193, 58, 393, 10, 45, "Input"],
Cell[2589, 70, 160, 3, 45, "Input"],
Cell[2752, 75, 224, 4, 45, "Input"],
Cell[2979, 81, 3432, 75, 394, "Input"],
Cell[6414, 158, 259, 4, 45, "Input"],
Cell[6676, 164, 132, 2, 45, "Input"],
Cell[6811, 168, 76, 2, 45, "Input"],
Cell[6890, 172, 142, 2, 45, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7069, 179, 216, 3, 95, "Chapter"],
Cell[7288, 184, 106, 2, 45, "Input"],
Cell[7397, 188, 55, 1, 45, "Input"],
Cell[7455, 191, 17047, 322, 1032, "Input"],
Cell[CellGroupData[{
Cell[24527, 517, 99, 1, 97, "Subsection"],
Cell[24629, 520, 65, 1, 67, "Input"],
Cell[24697, 523, 123, 2, 67, "Input"],
Cell[24823, 527, 203, 3, 67, "Input"],
Cell[25029, 532, 234, 7, 67, "Input"],
Cell[CellGroupData[{
Cell[25288, 543, 129, 2, 67, "Input"],
Cell[25420, 547, 127, 2, 66, "Output"]
}, Open  ]],
Cell[25562, 552, 508, 8, 67, "Input"],
Cell[26073, 562, 226, 4, 67, "Input"],
Cell[26302, 568, 130, 2, 67, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26469, 575, 224, 4, 138, "Subchapter"],
Cell[CellGroupData[{
Cell[26718, 583, 435, 8, 67, "Input"],
Cell[27156, 593, 10095, 258, 246, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37288, 856, 209, 3, 67, "Input"],
Cell[37500, 861, 222, 3, 66, "Output"]
}, Open  ]],
Cell[37737, 867, 156, 3, 67, "Input"],
Cell[37896, 872, 1406, 32, 112, "Input"],
Cell[CellGroupData[{
Cell[39327, 908, 339, 8, 67, "Input"],
Cell[39669, 918, 11202, 297, 288, "Output"]
}, Open  ]],
Cell[50886, 1218, 169, 3, 67, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[51104, 1227, 397, 5, 142, "Chapter"],
Cell[51504, 1234, 764, 14, 67, "Input"],
Cell[52271, 1250, 691, 14, 67, "Input"],
Cell[52965, 1266, 567, 12, 67, "Input"],
Cell[53535, 1280, 353, 5, 67, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[53925, 1290, 97, 1, 142, "Chapter"],
Cell[54025, 1293, 4292, 99, 243, "Input"],
Cell[58320, 1394, 809, 11, 67, "Input"],
Cell[CellGroupData[{
Cell[59154, 1409, 240, 4, 67, "Input"],
Cell[59397, 1415, 31873, 612, 151, "Output"]
}, Open  ]],
Cell[91285, 2030, 218, 5, 67, "Input"],
Cell[91506, 2037, 216, 5, 67, "Input"],
Cell[91725, 2044, 188, 3, 67, "Input"],
Cell[91916, 2049, 96, 1, 67, "Input"],
Cell[CellGroupData[{
Cell[92037, 2054, 96, 1, 138, "Subchapter"],
Cell[92136, 2057, 114, 2, 67, "Text"],
Cell[CellGroupData[{
Cell[92275, 2063, 384, 11, 67, "Input"],
Cell[92662, 2076, 31871, 612, 151, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[124570, 2693, 282, 7, 67, "Input"],
Cell[124855, 2702, 30980, 597, 151, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[155872, 3304, 187, 4, 67, "Input"],
Cell[156062, 3310, 74161, 1363, 541, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[230260, 4678, 184, 5, 67, "Input"],
Cell[230447, 4685, 294331, 4975, 2244, 73962, 1361, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[524815, 9665, 1870, 43, 112, "Input"],
Cell[526688, 9710, 26773, 529, 151, "Output"],
Cell[553464, 10241, 35429, 688, 526, "Output"]
}, Open  ]],
Cell[588908, 10932, 240, 8, 67, "Input"],
Cell[CellGroupData[{
Cell[589173, 10944, 320, 7, 67, "Input"],
Cell[589496, 10953, 36902, 617, 522, 16939, 289, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[626435, 11575, 329, 8, 67, "Input"],
Cell[626767, 11585, 1596, 36, 522, "Output"]
}, Open  ]],
Cell[628378, 11624, 70, 1, 67, "Input"],
Cell[628451, 11627, 420, 6, 67, "Input"],
Cell[628874, 11635, 5040, 133, 765, "Input"],
Cell[CellGroupData[{
Cell[633939, 11772, 795, 23, 67, "Input"],
Cell[634737, 11797, 2396, 53, 552, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[637170, 11855, 157, 3, 67, "Input"],
Cell[637330, 11860, 216, 3, 66, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[637583, 11868, 192, 4, 67, "Input"],
Cell[637778, 11874, 216, 3, 66, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[638031, 11882, 6730, 133, 286, "Input"],
Cell[644764, 12017, 35518, 686, 520, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[680319, 12708, 184, 5, 67, "Input"],
Cell[680506, 12715, 35100, 681, 2223, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[715643, 13401, 384, 7, 67, "Input"],
Cell[716030, 13410, 409, 6, 66, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
